import React, { createContext, useState, useEffect, useRef, Fragment, useLayoutEffect } from 'react';
import { createUseStyles, createTheming } from 'react-jss';
import parser from 'html-react-parser';
import { CSSTransition } from 'react-transition-group';
import keys from 'lodash-es/keys';
import debounce from 'lodash-es/debounce';
import isEmpty from 'validator/lib/isEmpty';
import { makeAutoObservable } from 'mobx';
import { getStorage, ref, listAll, getDownloadURL } from 'firebase/storage';
import axios from 'axios';
import jsep from 'jsep';
import moment from 'moment';
import { useStripe, PaymentRequestButtonElement, Elements } from '@stripe/react-stripe-js';
import { Frames, CardNumber, ExpiryDate, Cvv } from 'frames-react';

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var SFProText = "85b4043974a2a3be.otf";

var body1 = {
  color: function color(_ref) {
    var palette = _ref.theme.palette;
    return palette.black;
  },
  fontSize: '16px',
  lineHeight: '24px',
  fontWeight: 400,
  fontFamily: 'SF Pro Text',
  margin: 0
};

var h3 = /*#__PURE__*/_extends({}, body1, {
  fontWeight: 600,
  color: function color(_ref2) {
    var palette = _ref2.theme.palette;
    return palette.dark_black;
  }
});

var h4 = /*#__PURE__*/_extends({}, h3, {
  fontSize: '14px',
  lineHeight: '18px'
});

var h2 = {
  fontWeight: 600,
  margin: 0,
  fontFamily: 'SF Pro Text',
  fontSize: '22px',
  lineHeight: '30px',
  color: function color(_ref3) {
    var palette = _ref3.theme.palette;
    return palette.dark_black;
  }
};
var label = {
  margin: 0,
  fontFamily: 'SF Pro Text',
  fontWeight: 400,
  fontSize: '12px',
  lineHeight: '18px',
  color: function color(_ref4) {
    var palette = _ref4.theme.palette;
    return palette.dark_black;
  }
};
var title = {
  padding: 0,
  fontWeight: 600,
  fontSize: 16,
  fontFamily: 'SF Pro Text',
  lineHeight: '24px',
  textAlign: 'center',
  letterSpacing: '-0.0024em',
  margin: 0
};

var bigTitle = /*#__PURE__*/_extends({}, title, {
  fontSize: 34,
  lineHeight: '40px'
});

var useStyles = /*#__PURE__*/createUseStyles({
  '@font-face': {
    fontFamily: "SF Pro Text",
    src: "url('" + SFProText + "') format(\"opentype\")"
  },
  body1: body1,
  h2: h2,
  h3: h3,
  h4: h4,
  label: label,
  title: title,
  bigTitle: bigTitle
});

var palette = {
  boxShadow: '0 0 0 0.2rem rgb(145 156 248 / 50%)',
  primary: '#4B46EC',
  primary_dark: '#1d17ef',
  light: '#F0F0FF',
  light_hover: '#d9d9f7',
  black: '#121620',
  dark_black: '#232323',
  white: '#ffffff',
  extra_light: '#dee5f9',
  gray: '#f0f0f0',
  light_gray: '#c7c7c7',
  gray_200: '#8e8e93',
  gray_300: '#C5C5D1',
  error: '#FF5758',
  gray_400: '#E0E3EB',
  gray_500: '#868C99'
};

var font = {
  font16Medium: {
    fontSize: '16px',
    fontWeight: 400,
    lineHeight: '24px'
  },
  font16Bold: {
    fontSize: '16px',
    fontWeight: 600,
    lineHeight: '24px'
  },
  font32Medium: {
    fontSize: '32px',
    fontWeight: 400
  },
  font24Medium: {
    fontSize: '24px',
    fontWeight: 400
  },
  font20Medium: {
    fontSize: '20px',
    lineHeight: '26px'
  },
  font18Medium: {
    fontSize: '18px'
  },
  font14Medium: {
    fontSize: '14px',
    lineHeight: '18px'
  },
  font12Medium: {
    fontSize: '12px',
    lineHeight: '16px'
  }
};

// node modules
var defaultTheme = {
  palette: palette,
  font: font
};
var ThemeContext = /*#__PURE__*/createContext(defaultTheme);
var theming = /*#__PURE__*/createTheming(ThemeContext);

var Typography = function Typography(_ref) {
  var className = _ref.className,
      variant = _ref.variant,
      children = _ref.children,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["className", "variant", "children"]);

  var classes = useStyles({
    theme: theming.useTheme()
  });
  var variantClassName = classes[variant] ? classes[variant] : classes.body1;
  var typClassName = variantClassName + " " + className;
  return React.createElement("p", Object.assign({
    className: typClassName
  }, otherProps), children);
};

// node modules
var useStyles$1 = /*#__PURE__*/createUseStyles({
  root: {
    outline: 'none',
    border: 'none',
    background: 'none',
    fontSize: 16,
    padding: '18px',
    cursor: 'pointer',
    transition: 'all .3s ease',
    minWidth: 150,
    '@media (max-width: 365px)': {
      minWidth: 136
    },
    position: 'relative',
    '-webkit-tap-highlight-color': 'rgba(0,0,0,0)',
    '&>p': {
      lineHeight: '20px'
    }
  },
  disabledClass: {
    cursor: 'not-allowed',
    color: function color(_ref) {
      var palette = _ref.theme.palette;
      return [[palette.black], '!important'];
    },
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return [[palette.light_gray], '!important'];
    }
  },
  centeredLabel: {
    textAlign: 'center',
    width: '100%'
  },
  loader: {
    width: 20,
    height: 20
  }
});

var useDelayAction = function useDelayAction() {
  var _useState = useState(true),
      actionAvailable = _useState[0],
      setActionAvailability = _useState[1];

  return {
    availabilityWatcher: function availabilityWatcher(action, delay) {
      if (!actionAvailable) return;
      action();
      setActionAvailability(false);
      setTimeout(function () {
        return setActionAvailability(true);
      }, delay);
    }
  };
};

var img = "data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' style='margin: auto%3b display: block%3b' width='118px' height='118px' viewBox='0 0 100 100' preserveAspectRatio='xMidYMid'%3e %3ccircle cx='92' cy='50' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.9090909090909091s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.9090909090909091s'%3e%3c/animate%3e %3c/circle%3e%3ccircle cx='85.33264837890961' cy='72.7069143331351' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.8181818181818182s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.8181818181818182s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='67.44743054607923' cy='88.20454380488977' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.7272727272727273s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.7272727272727273s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='44.02277679252203' cy='91.57250055899918' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.6363636363636364s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.6363636363636364s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='22.49584917429803' cy='81.74148212287885' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.5454545454545454s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.5454545454545454s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='9.701295108191111' cy='61.83276738734005' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.45454545454545453s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.45454545454545453s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='9.701295108191104' cy='38.167232612659966' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.36363636363636365s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.36363636363636365s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='22.495849174298023' cy='18.258517877121157' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.2727272727272727s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.2727272727272727s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='44.02277679252202' cy='8.427499441000826' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.18181818181818182s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.18181818181818182s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='67.44743054607922' cy='11.79545619511022' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.09090909090909091s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.09090909090909091s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='85.33264837890961' cy='27.293085666864908' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='0s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='0s'%3e%3c/animate%3e%3c/circle%3e%3c/svg%3e";

var TypographyVariants;

(function (TypographyVariants) {
  TypographyVariants["body1"] = "body1";
  TypographyVariants["h3"] = "h3";
  TypographyVariants["h2"] = "h2";
  TypographyVariants["h4"] = "h4";
  TypographyVariants["label"] = "label";
  TypographyVariants["body2"] = "body2";
  TypographyVariants["title"] = "title";
  TypographyVariants["bigTitle"] = "bigTitle";
})(TypographyVariants || (TypographyVariants = {}));

var SimpleButton = function SimpleButton(_ref) {
  var _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      label = _ref.label,
      width = _ref.width,
      disabled = _ref.disabled,
      _ref$centered = _ref.centered,
      centered = _ref$centered === void 0 ? false : _ref$centered,
      onClick = _ref.onClick,
      children = _ref.children,
      delayNextClick = _ref.delayNextClick,
      loading = _ref.loading,
      _ref$textTransform = _ref.textTransform,
      textTransform = _ref$textTransform === void 0 ? 'none' : _ref$textTransform,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["className", "label", "width", "disabled", "centered", "onClick", "children", "delayNextClick", "loading", "textTransform"]);

  var _useStyles = useStyles$1({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      disabledClass = _useStyles.disabledClass,
      centeredLabel = _useStyles.centeredLabel,
      loader = _useStyles.loader;

  var btnClassName = root + " " + className + " " + (disabled && disabledClass);

  var _useDelayAction = useDelayAction(),
      availabilityWatcher = _useDelayAction.availabilityWatcher;

  var handleClick = function handleClick() {
    if (disabled || loading) return;
    if (onClick) availabilityWatcher(onClick, delayNextClick || 500);
  };

  return React.createElement("button", Object.assign({
    onClick: handleClick,
    style: {
      width: width,
      textTransform: textTransform
    },
    className: btnClassName
  }, otherProps), loading ? React.createElement("img", {
    src: img,
    className: loader,
    alt: "loader"
  }) : React.createElement(React.Fragment, null, label ? React.createElement(Typography, {
    variant: TypographyVariants.title,
    className: centered ? centeredLabel : ''
  }, label) : null, children));
};

var DEFAULT_MULTI_CLICK_PROTECTOR_DELAY = 350;

var timer = null;
var useMultiClickProtector = function useMultiClickProtector(delay) {
  if (delay === void 0) {
    delay = DEFAULT_MULTI_CLICK_PROTECTOR_DELAY;
  }

  useEffect(function () {
    return function () {
      clearTimeout(timer);
      timer = null;
    };
  }, []);

  var handleMultiClickProtector = function handleMultiClickProtector(cb) {
    return function () {
      if (timer) return;
      timer = setTimeout(function () {
        timer = null;
      }, delay);
      cb();
    };
  };

  return {
    handleMultiClickProtector: handleMultiClickProtector
  };
};

// node modules
var useStyles$2 = /*#__PURE__*/createUseStyles({
  root: {
    borderRadius: '.5rem',
    transition: function transition(_ref) {
      var animationTime = _ref.theme.animationTime;
      return "background-color " + animationTime + "ms, color " + animationTime + "ms";
    },
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.light;
    },
    color: function color(_ref3) {
      var palette = _ref3.theme.palette;
      return palette.black;
    }
  },
  rootSelected: {
    background: function background(_ref4) {
      var palette = _ref4.theme.palette;
      return palette.primary;
    },
    color: function color() {
      return "#ffffff";
    },
    '&:active': {
      boxShadow: function boxShadow(_ref5) {
        var palette = _ref5.theme.palette;
        return palette.boxShadow;
      }
    }
  }
});

var SelectButton = function SelectButton(_ref) {
  var className = _ref.className,
      _ref$selected = _ref.selected,
      selected = _ref$selected === void 0 ? false : _ref$selected,
      children = _ref.children,
      _ref$centered = _ref.centered,
      centered = _ref$centered === void 0 ? false : _ref$centered,
      _ref$multiClickProtec = _ref.multiClickProtector,
      multiClickProtector = _ref$multiClickProtec === void 0 ? true : _ref$multiClickProtec,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick,
      _ref$multiClickProtec2 = _ref.multiClickProtectorDelay,
      multiClickProtectorDelay = _ref$multiClickProtec2 === void 0 ? DEFAULT_MULTI_CLICK_PROTECTOR_DELAY : _ref$multiClickProtec2,
      _ref$animationTime = _ref.animationTime,
      animationTime = _ref$animationTime === void 0 ? DEFAULT_MULTI_CLICK_PROTECTOR_DELAY : _ref$animationTime,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["className", "selected", "children", "centered", "multiClickProtector", "onClick", "multiClickProtectorDelay", "animationTime"]);

  var _useStyles = useStyles$2({
    theme: _extends({}, theming.useTheme(), {
      animationTime: animationTime
    })
  }),
      root = _useStyles.root,
      rootSelected = _useStyles.rootSelected;

  var _useMultiClickProtect = useMultiClickProtector(multiClickProtectorDelay),
      handleMultiClickProtector = _useMultiClickProtect.handleMultiClickProtector;

  var selectedClass = selected ? rootSelected : '';
  var selectBtnClass = root + " " + selectedClass + " " + className;
  var handleClick = multiClickProtector ? handleMultiClickProtector(onClick) : onClick;
  return React.createElement(SimpleButton, Object.assign({
    onClick: handleClick,
    centered: centered,
    className: selectBtnClass
  }, otherProps), children);
};

var img$1 = "data:image/svg+xml,%3csvg viewBox='0 0 18 14' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cstyle%3e path %7b color: %23066fde %7d %3c/style%3e %3cpath d='M17 1.67407L6 12.6741L1 7.67407' stroke='currentColor' stroke-width='2' stroke-linecap='round' stroke-linejoin='round'/%3e%3c/svg%3e";

var alignment = {
  center: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center'
  },
  betweenCenter: {
    display: 'flex',
    justifyContent: 'space-between',
    alignItems: 'center'
  },
  rowCenter: {
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center'
  }
};

var useStyles$3 = /*#__PURE__*/createUseStyles({
  root: /*#__PURE__*/_extends({}, alignment.betweenCenter),
  checkWrapper: /*#__PURE__*/_extends({
    borderRadius: '50%'
  }, alignment.center, {
    marginLeft: 8,
    minWidth: 24,
    width: 24,
    height: 24,
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.white;
    },
    position: 'absolute',
    right: '18px'
  }),
  checkIconCl: {
    width: 12
  },
  childrenStyle: {
    paddingRight: '32px'
  },
  centeredChildren: {
    width: '100%',
    paddingLeft: '32px'
  }
});

var CheckButton = function CheckButton(_ref) {
  var _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$selected = _ref.selected,
      selected = _ref$selected === void 0 ? false : _ref$selected,
      _ref$centered = _ref.centered,
      centered = _ref$centered === void 0 ? false : _ref$centered,
      children = _ref.children,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["label", "className", "selected", "centered", "children"]);

  var _useStyles = useStyles$3({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      checkWrapper = _useStyles.checkWrapper,
      checkIconCl = _useStyles.checkIconCl,
      childrenStyle = _useStyles.childrenStyle,
      centeredChildren = _useStyles.centeredChildren;

  var checkBtnClass = root + " " + className;
  return React.createElement(SelectButton, Object.assign({
    centered: centered,
    selected: selected,
    label: '',
    className: checkBtnClass
  }, otherProps), React.createElement("div", {
    className: childrenStyle + " " + (centered ? centeredChildren : '')
  }, children || label), React.createElement("div", {
    className: checkWrapper
  }, selected && React.createElement("img", {
    className: checkIconCl,
    src: img$1,
    alt: ""
  })));
};

var img$2 = "data:image/svg+xml,%3csvg viewBox='0 0 18 14' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cstyle%3e path %7b color: white %7d %3c/style%3e %3cpath d='M17 1.67407L6 12.6741L1 7.67407' stroke='currentColor' stroke-width='2' stroke-linecap='round' stroke-linejoin='round'/%3e%3c/svg%3e";

var useStyles$4 = /*#__PURE__*/createUseStyles({
  root: /*#__PURE__*/_extends({}, alignment.betweenCenter),
  checkWrapper: /*#__PURE__*/_extends({
    borderRadius: '50%'
  }, alignment.center, {
    marginLeft: 8,
    minWidth: 24,
    width: 24,
    height: 24,
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.light;
    },
    position: 'absolute',
    right: '18px'
  }),
  checkIconCl: {
    width: 12
  },
  childrenStyle: {
    paddingRight: '32px'
  },
  centeredChildren: {
    width: '100%',
    paddingLeft: '32px'
  },
  activeCheckWrapper: {
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.primary;
    }
  }
});

var CheckButtonPrimary = function CheckButtonPrimary(_ref) {
  var _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$selected = _ref.selected,
      selected = _ref$selected === void 0 ? false : _ref$selected,
      _ref$centered = _ref.centered,
      centered = _ref$centered === void 0 ? false : _ref$centered,
      _ref$iconColor = _ref.iconColor,
      iconColor = _ref$iconColor === void 0 ? 'white' : _ref$iconColor,
      children = _ref.children,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["label", "className", "selected", "centered", "iconColor", "children"]);

  var _useStyles = useStyles$4({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      checkWrapper = _useStyles.checkWrapper,
      checkIconCl = _useStyles.checkIconCl,
      childrenStyle = _useStyles.childrenStyle,
      centeredChildren = _useStyles.centeredChildren,
      activeCheckWrapper = _useStyles.activeCheckWrapper;

  var checkBtnClass = root + " " + className;
  return React.createElement(SelectButton, Object.assign({
    centered: centered,
    selected: selected,
    label: '',
    className: checkBtnClass
  }, otherProps), React.createElement("div", {
    className: childrenStyle + " " + (centered ? centeredChildren : '')
  }, children || label), React.createElement("div", {
    className: checkWrapper + " " + (selected ? activeCheckWrapper : '')
  }, selected && React.createElement("img", {
    className: checkIconCl,
    src: iconColor === 'blue' ? img$1 : img$2,
    alt: ""
  })));
};

// node modules
var useStyles$5 = /*#__PURE__*/createUseStyles({
  root: {
    borderRadius: '2em',
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.primary;
    },
    color: function color(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.light;
    },
    transition: 'background .3s, color .3s, box-shadow 2s',
    '&:hover': {
      background: function background(_ref3) {
        var palette = _ref3.theme.palette;
        return palette.primary_dark;
      }
    },
    '&:active': {
      boxShadow: function boxShadow(_ref4) {
        var palette = _ref4.theme.palette;
        return palette.boxShadow;
      }
    }
  }
});

var PrimaryButton = function PrimaryButton(_ref) {
  var _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      children = _ref.children,
      _ref$multiClickProtec = _ref.multiClickProtector,
      multiClickProtector = _ref$multiClickProtec === void 0 ? true : _ref$multiClickProtec,
      _ref$multiClickProtec2 = _ref.multiClickProtectorDelay,
      multiClickProtectorDelay = _ref$multiClickProtec2 === void 0 ? DEFAULT_MULTI_CLICK_PROTECTOR_DELAY : _ref$multiClickProtec2,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["className", "label", "children", "multiClickProtector", "multiClickProtectorDelay", "onClick"]);

  var _useMultiClickProtect = useMultiClickProtector(multiClickProtectorDelay),
      handleMultiClickProtector = _useMultiClickProtect.handleMultiClickProtector;

  var theme = theming.useTheme();

  var _useStyles = useStyles$5({
    theme: theme
  }),
      root = _useStyles.root;

  var primaryBtnClassName = root + " " + className;
  var handleClick = multiClickProtector ? handleMultiClickProtector(onClick) : onClick;
  return React.createElement(SimpleButton, Object.assign({
    onClick: handleClick,
    className: primaryBtnClassName,
    label: label
  }, otherProps), children);
};

// node modules
var useStyles$6 = /*#__PURE__*/createUseStyles({
  block: {
    position: 'fixed',
    width: '100%',
    left: 0,
    top: 0,
    padding: '0.5rem 2rem',
    boxSizing: 'border-box',
    display: 'flex',
    justifyContent: 'flex-end',
    alignItems: 'center',
    zIndex: 1,
    backgroundColor: '#066FDE',
    lineHeight: '1.5rem',
    fontSize: '1rem',
    fontStyle: 'normal',
    opacity: 0.8
  },
  typography: {
    textOverflow: 'ellipsis',
    maxWidth: '300px',
    overflow: 'hidden',
    color: 'white',
    lineHeight: '1.5rem',
    fontSize: '1rem',
    fontStyle: 'normal',
    fontWeight: 700
  },
  imgWrapper: {
    width: '2rem',
    height: '2rem',
    color: '#066FDE',
    marginLeft: '.75rem',
    borderRadius: '50%',
    backgroundColor: '#fff',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    fontWeight: 600,
    textTransform: 'uppercase'
  }
});

// node modules
var Header = function Header(_ref) {
  var img = _ref.img,
      label = _ref.label;

  var _useStyles = useStyles$6(),
      block = _useStyles.block,
      typography = _useStyles.typography,
      imgWrapper = _useStyles.imgWrapper;

  return React.createElement("div", {
    className: block
  }, React.createElement(Typography, {
    variant: TypographyVariants.h4,
    className: typography
  }, label), img ? typeof img === 'string' ? React.createElement("img", {
    src: img,
    className: imgWrapper
  }) : {
    img: img
  } : React.createElement("div", {
    className: imgWrapper
  }, typeof label === 'string' ? label[0] : ''));
};

var img$3 = "data:image/svg+xml,%3csvg width='23' height='14' viewBox='0 0 23 14' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M21.6161 0.450918C20.9883 -0.211053 20.1996 -0.10737 19.5366 0.52202L8.75873 10.8412L3.39961 5.42612C2.76194 4.77188 1.68996 4.33711 1.03516 4.97487C0.380914 5.61198 0.764157 6.5081 1.40128 7.16234L7.57427 13.5001C7.89776 13.8325 8.32769 14 8.75873 14C9.1677 14 9.57667 13.849 9.8969 13.5464L21.6366 2.41304C22.2991 1.78468 22.2449 1.11345 21.6161 0.450918Z' fill='%23202B47'/%3e%3c/svg%3e";

var img$4 = "data:image/svg+xml,%3csvg width='17' height='16' viewBox='0 0 17 16' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M0.607422 1.77734L2.3852 -0.000434061L16.6074 14.2218L14.8296 15.9996L0.607422 1.77734Z' fill='%23202B47'/%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M16.6074 1.77734L14.8296 -0.000434061L0.607422 14.2218L2.3852 15.9996L16.6074 1.77734Z' fill='%23202B47'/%3e%3c/svg%3e";

var useStyles$7 = /*#__PURE__*/createUseStyles({
  wrapper: /*#__PURE__*/_extends({}, alignment.center, {
    border: function border(_ref) {
      var palette = _ref.theme.palette;
      return "2px solid " + palette.gray_300;
    },
    borderBottomLeftRadius: 10,
    borderBottomRightRadius: 10,
    borderTopRightRadius: 10,
    borderTopLeftRadius: 10,
    width: 160,
    paddingBottom: 15,
    paddingTop: 16,
    boxSizing: 'border-box'
  }),
  content: /*#__PURE__*/_extends({}, alignment.rowCenter, {
    width: '100%'
  }),
  icon: {
    marginTop: 12,
    width: 23
  },
  btn: {
    minWidth: 'auto',
    width: 'calc(100% - 28px)',
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.gray_400;
    },
    color: function color(_ref3) {
      var palette = _ref3.theme.palette;
      return palette.gray_500;
    },
    marginTop: 20,
    borderRadius: '10px',
    '& p': {
      fontSize: 14,
      lineHeight: '18px'
    },
    '&:active': {
      background: function background(_ref4) {
        var palette = _ref4.theme.palette;
        return palette.primary;
      },
      color: function color(_ref5) {
        var palette = _ref5.theme.palette;
        return palette.light;
      }
    }
  },
  activeBtn: {
    background: function background(_ref6) {
      var palette = _ref6.theme.palette;
      return palette.primary;
    },
    color: function color(_ref7) {
      var palette = _ref7.theme.palette;
      return palette.light;
    },
    '&:active': {
      background: function background(_ref8) {
        var palette = _ref8.theme.palette;
        return palette.gray_400;
      },
      color: function color(_ref9) {
        var palette = _ref9.theme.palette;
        return palette.gray_500;
      }
    }
  },
  activeImg: {
    width: 16
  },
  typClass: {
    marginTop: 12,
    color: function color(_ref10) {
      var palette = _ref10.theme.palette;
      return palette.gray_500;
    },
    fontWeight: 400,
    fontSize: '14px'
  },
  activeTotalSavingTitle: {
    fontSize: 16,
    lineHeight: '24px'
  },
  priceWrapperActive: {
    fontWeight: 600
  },
  priceWrapper: {
    display: 'flex',
    alignItems: 'flex-end',
    fontSize: 16,
    lineHeight: '22px',
    fontWeight: 600
  },
  wrapperActive: {
    borderColor: function borderColor(_ref11) {
      var palette = _ref11.theme.palette;
      return palette.primary;
    },
    position: 'relative'
  },
  activePopUp: /*#__PURE__*/_extends({}, alignment.center, {
    position: 'absolute',
    top: -33,
    left: -2,
    borderTopLeftRadius: '10px',
    borderTopRightRadius: '10px',
    lineHeight: '14px',
    fontWeight: 600,
    background: function background(_ref12) {
      var palette = _ref12.theme.palette;
      return palette.primary;
    },
    height: 32,
    width: 'calc(100% + 4px)',
    color: function color(_ref13) {
      var palette = _ref13.theme.palette;
      return palette.white;
    }
  }),
  priceTextStyle: {
    fontSize: '16px',
    lineHeight: '24px',
    fontWeight: 600
  }
});

// node modules
var PriceBlock = function PriceBlock(_ref) {
  var totalSavingText = _ref.totalSavingText,
      btnLabel = _ref.btnLabel,
      active = _ref.active,
      price = _ref.price,
      term = _ref.term,
      priceText = _ref.priceText,
      savingPrice = _ref.savingPrice,
      trialTitle = _ref.trialTitle,
      _ref$currency = _ref.currency,
      currency = _ref$currency === void 0 ? '$' : _ref$currency,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick,
      _ref$trialIcon = _ref.trialIcon,
      trialIcon = _ref$trialIcon === void 0 ? true : _ref$trialIcon,
      _ref$label = _ref.label,
      label = _ref$label === void 0 ? 'POPULAR' : _ref$label;

  var _useStyles = useStyles$7({
    theme: theming.useTheme()
  }),
      wrapper = _useStyles.wrapper,
      icon = _useStyles.icon,
      content = _useStyles.content,
      btn = _useStyles.btn,
      activeBtn = _useStyles.activeBtn,
      activeImg = _useStyles.activeImg,
      typClass = _useStyles.typClass,
      priceWrapper = _useStyles.priceWrapper,
      priceWrapperActive = _useStyles.priceWrapperActive,
      wrapperActive = _useStyles.wrapperActive,
      activePopUp = _useStyles.activePopUp,
      priceTextStyle = _useStyles.priceTextStyle,
      activeTotalSavingTitle = _useStyles.activeTotalSavingTitle;

  return React.createElement("div", {
    className: wrapper + " " + (active ? wrapperActive : '') + " " + className
  }, React.createElement("div", {
    className: content
  }, React.createElement(Typography, {
    className: priceWrapper + " " + (active ? priceWrapperActive : ''),
    variant: TypographyVariants.body1
  }, currency, price, term && React.createElement(Typography, {
    variant: TypographyVariants.body2
  }, "/", term)), priceText && React.createElement(Typography, {
    className: priceTextStyle,
    variant: TypographyVariants.body2
  }, " ", priceText), React.createElement(Typography, {
    className: typClass,
    variant: TypographyVariants.h4
  }, totalSavingText || 'Total savings'), React.createElement(Typography, {
    className: active ? activeTotalSavingTitle : '',
    variant: TypographyVariants.title
  }, currency, savingPrice), React.createElement(Typography, {
    className: typClass,
    variant: TypographyVariants.h4
  }, trialTitle), trialIcon ? React.createElement("img", {
    className: icon + " " + (active ? activeImg : ''),
    src: active ? img$4 : img$3,
    alt: ""
  }) : React.createElement(Typography, {
    className: priceTextStyle,
    variant: TypographyVariants.body2
  }, " ", active ? 'no' : 'yes'), React.createElement(SimpleButton, {
    onClick: onClick,
    className: btn + " " + (active ? activeBtn : ''),
    label: btnLabel
  })), active && React.createElement(Typography, {
    className: activePopUp,
    variant: TypographyVariants.label
  }, label));
};

var useStyles$8 = /*#__PURE__*/createUseStyles({
  wrapper: /*#__PURE__*/_extends({}, alignment.center, {
    border: function border(_ref) {
      var palette = _ref.theme.palette;
      return "2px solid " + palette.gray_300;
    },
    borderRadius: 10,
    width: 160,
    boxSizing: 'border-box',
    padding: '16px 12px',
    marginRight: '3.5px',
    '& p': {
      '&:first-child': {
        fontSize: '22px',
        fontWeight: '600',
        lineHeight: '24px'
      },
      '&:last-child': {
        fontSize: '16px',
        fontWeight: '600',
        lineHeight: '24px',
        margin: 0
      }
    }
  }),
  content: /*#__PURE__*/_extends({}, alignment.rowCenter, {
    width: '100%'
  }),
  icon: {
    marginTop: 12,
    width: 23
  },
  btn: {
    minWidth: 'auto',
    width: '100%',
    background: '#f0f0f0',
    color: function color(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.primary;
    },
    marginTop: 20,
    borderRadius: '10px',
    height: '56px',
    padding: 0,
    '& p': {
      fontSize: 14,
      lineHeight: '18px'
    },
    '&:active': {
      background: function background(_ref3) {
        var palette = _ref3.theme.palette;
        return palette.primary;
      },
      color: function color(_ref4) {
        var palette = _ref4.theme.palette;
        return palette.light;
      }
    }
  },
  activeBtn: {
    background: function background(_ref5) {
      var palette = _ref5.theme.palette;
      return palette.primary;
    },
    color: function color(_ref6) {
      var palette = _ref6.theme.palette;
      return palette.light;
    },
    '&:active': {
      background: function background(_ref7) {
        var palette = _ref7.theme.palette;
        return palette.gray_400;
      },
      color: function color(_ref8) {
        var palette = _ref8.theme.palette;
        return palette.gray_500;
      }
    }
  },
  activeImg: {
    width: 16
  },
  typClass: {
    marginTop: 12,
    color: function color(_ref9) {
      var palette = _ref9.theme.palette;
      return palette.gray_500;
    }
  },
  activeTotalSavingTitle: {
    fontSize: 22,
    lineHeight: '30px'
  },
  priceWrapperActive: {
    fontWeight: 600
  },
  priceWrapper: {
    display: 'flex',
    alignItems: 'flex-end',
    fontSize: 28,
    lineHeight: '34px'
  },
  wrapperActive: {
    borderColor: function borderColor(_ref10) {
      var palette = _ref10.theme.palette;
      return palette.primary;
    },
    position: 'relative',
    borderRadius: 0,
    borderBottomRightRadius: '10px',
    borderBottomLeftRadius: '10px'
  },
  activePopUp: /*#__PURE__*/_extends({}, alignment.center, {
    position: 'absolute',
    top: -33,
    left: -2,
    borderTopLeftRadius: '10px',
    borderTopRightRadius: '10px',
    lineHeight: '14px',
    fontSize: '12px !important',
    fontWeight: 600,
    background: function background(_ref11) {
      var palette = _ref11.theme.palette;
      return palette.primary;
    },
    height: 32,
    width: 'calc(100% + 4px)',
    color: function color(_ref12) {
      var palette = _ref12.theme.palette;
      return palette.white;
    }
  }),
  priceTextStyle: {
    fontSize: '16px',
    lineHeight: '24px',
    fontWeight: 600
  }
});

// node modules
var PriceBlockHint = function PriceBlockHint(_ref) {
  var btnLabel = _ref.btnLabel,
      active = _ref.active,
      price = _ref.price,
      term = _ref.term,
      priceText = _ref.priceText,
      savingPrice = _ref.savingPrice,
      trialTitle = _ref.trialTitle,
      _ref$currency = _ref.currency,
      currency = _ref$currency === void 0 ? '$' : _ref$currency,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick,
      _ref$trialIcon = _ref.trialIcon,
      trialIcon = _ref$trialIcon === void 0 ? true : _ref$trialIcon,
      _ref$label = _ref.label,
      label = _ref$label === void 0 ? 'POPULAR' : _ref$label;

  var _useStyles = useStyles$8({
    theme: theming.useTheme()
  }),
      wrapper = _useStyles.wrapper,
      icon = _useStyles.icon,
      content = _useStyles.content,
      btn = _useStyles.btn,
      activeBtn = _useStyles.activeBtn,
      activeImg = _useStyles.activeImg,
      typClass = _useStyles.typClass,
      priceWrapper = _useStyles.priceWrapper,
      priceWrapperActive = _useStyles.priceWrapperActive,
      wrapperActive = _useStyles.wrapperActive,
      activePopUp = _useStyles.activePopUp,
      priceTextStyle = _useStyles.priceTextStyle;

  return React.createElement("div", {
    className: wrapper + " " + (active ? wrapperActive : '') + " " + className
  }, React.createElement("div", {
    className: content
  }, React.createElement(Typography, {
    className: priceWrapper + " " + (active ? priceWrapperActive : ''),
    variant: TypographyVariants.body1
  }, currency, price, term && React.createElement(Typography, {
    variant: TypographyVariants.body2
  }, "/", term)), priceText && React.createElement(Typography, {
    className: priceTextStyle,
    variant: TypographyVariants.body2
  }, " ", priceText), React.createElement(Typography, {
    className: typClass,
    variant: TypographyVariants.h4
  }, "Total savings"), React.createElement(Typography, {
    variant: TypographyVariants.title
  }, currency, savingPrice), React.createElement(Typography, {
    className: typClass,
    variant: TypographyVariants.h4
  }, trialTitle), trialIcon ? React.createElement("img", {
    className: icon + " " + (active ? activeImg : ''),
    src: active ? img$4 : img$3,
    alt: ""
  }) : React.createElement(Typography, {
    className: priceTextStyle,
    variant: TypographyVariants.body2
  }, " ", active ? 'no' : 'yes'), React.createElement(SimpleButton, {
    onClick: onClick,
    className: btn + " " + (active ? activeBtn : ''),
    label: btnLabel
  })), active && React.createElement(Typography, {
    className: activePopUp,
    variant: TypographyVariants.label
  }, label));
};

var useStyles$9 = /*#__PURE__*/createUseStyles({
  root: /*#__PURE__*/_extends({}, alignment.center, {
    position: 'fixed',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
    background: 'rgba(85, 84, 85, 0.8);',
    zIndex: 10000
  })
});

// node modules
var DialogContent = function DialogContent(_ref) {
  var children = _ref.children,
      _ref$open = _ref.open,
      open = _ref$open === void 0 ? false : _ref$open,
      _ref$rootClassName = _ref.rootClassName,
      rootClassName = _ref$rootClassName === void 0 ? '' : _ref$rootClassName;

  var _useStyles = useStyles$9(),
      root = _useStyles.root;

  document.body.style.overflow = open ? 'hidden' : '';
  return open ? React.createElement("div", {
    className: root + " " + rootClassName
  }, children, " ") : null;
};

// node modules
var ModalWindow = function ModalWindow(props) {
  return React.createElement(DialogContent, Object.assign({}, props));
};

var replaceLinks = function replaceLinks(str) {
  return str.replace(/\[([\s\S]*?)]/g, function (_, key) {
    var _key$split = key.split('|'),
        link = _key$split[0],
        linkName = _key$split[1];

    if (link && linkName) {
      return "<a target=\"_blank\" href=\"" + link.trim() + "\">" + linkName.trim() + "</a>";
    }

    return "[" + key + "]";
  });
};

var replaceTags = function replaceTags(_ref) {
  var symbol = _ref[0],
      tag = _ref[1];
  var regExp = new RegExp("\\" + symbol + "([\\s\\S]*?)\\" + symbol, 'g');
  return function (str) {
    return str.replace(regExp, "<" + tag + ">$1</" + tag + ">");
  };
};

// local files
var generateParser = function generateParser(options) {
  var parser = {};
  var tagWrappers = options.tagWrappers,
      brChanger = options.brChanger;

  if (tagWrappers) {
    if (typeof tagWrappers[0] === 'string') {
      parser.tagChangers = [replaceTags(tagWrappers)];
    }

    if (typeof tagWrappers[0] === 'object') {
      // @ts-ignore
      parser.tagChangers = tagWrappers.map(function (wrapper) {
        return replaceTags(wrapper);
      });
    }
  }

  if (brChanger) {
    parser.brChanger = function (s) {
      return s.replace(/\n/g, '<br>');
    };
  }

  return parser;
};

var replaceVariables = function replaceVariables(someStr, options) {
  var variables = options.variables,
      localStorageMode = options.localStorageMode;
  return someStr.replace(/%_([\s\S]*?)_%/g, function (_, key) {
    if (localStorageMode) {
      var valueFromLocalStorage = localStorage.getItem(key);

      if (valueFromLocalStorage) {
        return valueFromLocalStorage;
      }
    }

    if (variables[key]) {
      return variables[key].toString();
    }

    return '_';
  });
};

var setCorrectUppercaseLowercase = function setCorrectUppercaseLowercase(str) {
  var newString = str.replace(/\^_([\s\S]*?)_\^/g, function (_, key) {
    var trimValue = key.trim();
    return trimValue.charAt(0).toLowerCase() + trimValue.slice(1);
  });
  newString = newString.replace(/\^-([\s\S]*?)-\^/g, function (_, key) {
    var trimValue = key.trim();
    return trimValue.charAt(0).toUpperCase() + trimValue.slice(1);
  });
  return newString;
};

// local files
var TextNormalizer = function TextNormalizer(str, options) {
  var newString = str;
  var parser = generateParser(options);
  newString = replaceVariables(newString, options);
  newString = replaceLinks(newString);
  newString = setCorrectUppercaseLowercase(newString);
  if (parser.tagChangers) parser.tagChangers.forEach(function (cb) {
    return newString = cb(newString);
  });
  if (parser.brChanger) newString = parser.brChanger(newString);
  return newString;
};

// node modules
var useStyles$a = /*#__PURE__*/createUseStyles({
  imageWrapper: {},
  slideClass: {
    transition: 'opacity 1s',
    opacity: 0,
    overflow: 'hidden'
  },
  slideShowed: {
    opacity: 1
  },
  typ: {
    textAlign: 'left'
  }
});

// node modules

var waiting = function waiting(delay) {
  return new Promise(function (resolve) {
    setTimeout(resolve, delay);
  });
};

var ELEMENT_DELAY = 3000;
var TIMEOUT_DELAY = 1800;
var Slide = function Slide(_ref) {
  var handleNext = _ref.handleNext,
      content = _ref.content,
      rootSlideClass = _ref.rootSlideClass,
      color = _ref.color;

  var _useStyles = useStyles$a(),
      slideClass = _useStyles.slideClass,
      slideShowed = _useStyles.slideShowed,
      typ = _useStyles.typ,
      imageWrapper = _useStyles.imageWrapper;

  var _useState = useState(false),
      activeClass = _useState[0],
      setActiveClass = _useState[1];

  useEffect(function () {
    var delay = content.delay;
    waiting(delay || ELEMENT_DELAY).then(function () {
      setActiveClass(false);
      setTimeout(handleNext, TIMEOUT_DELAY);
    });
    setActiveClass(true);
  }, [content]);
  var className = slideClass + " " + rootSlideClass + " " + (activeClass ? slideShowed : '');
  return React.createElement("div", {
    className: className
  }, typeof content.value !== 'string' ? React.createElement("div", {
    className: imageWrapper
  }, content.value) : React.createElement(Typography, {
    style: {
      color: content.color || color || null
    },
    variant: content.variant || TypographyVariants.bigTitle,
    className: typ
  }, parser(TextNormalizer(content.value, {
    brChanger: true,
    localStorageMode: true
  }))));
};

// node modules
var useStyles$b = /*#__PURE__*/createUseStyles({
  root: {
    height: function height(_ref) {
      var _height = _ref.height,
          component = _ref.component;
      return component ? _height + "px" : "calc(" + _height + "px - 201px)";
    },
    overflow: 'hidden',
    padding: function padding(_ref2) {
      var component = _ref2.component;
      return component ? '0 32px 0 32px' : '201px 32px 0 32px';
    },
    display: function display(_ref3) {
      var component = _ref3.component;
      return component ? 'flex' : '';
    },
    alignItems: function alignItems(_ref4) {
      var component = _ref4.component;
      return component ? 'center' : '';
    },
    justifyContent: "center"
  },
  '@media (min-width: 1024px)': {
    root: {
      justifyContent: "center",
      display: 'flex'
    }
  }
});

// node modules
var SliderPage = function SliderPage(_ref) {
  var _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$elements = _ref.elements,
      elements = _ref$elements === void 0 ? [] : _ref$elements,
      onFinished = _ref.onFinished,
      background = _ref.background,
      textColor = _ref.textColor,
      slideClass = _ref.slideClass;

  var _useState = useState(0),
      activeSlide = _useState[0],
      setActiveSlide = _useState[1];

  var handleNextSlide = function handleNextSlide() {
    if (activeSlide + 1 === elements.length) {
      if (onFinished) {
        onFinished();
      }
    } else {
      setActiveSlide(activeSlide + 1);
    }
  };

  var _useStyles = useStyles$b({
    height: window.innerHeight,
    component: typeof elements[activeSlide].value !== 'string'
  }),
      root = _useStyles.root;

  return React.createElement("div", {
    className: root + " " + className,
    style: {
      background: background
    }
  }, React.createElement(Slide, {
    rootSlideClass: slideClass,
    color: textColor,
    handleNext: handleNextSlide,
    content: elements[activeSlide]
  }));
};

var buttonInputCleanStyles = {
  border: 'none',
  outline: 'none',
  background: 'none'
};
var labelClassName = {
  color: function color(_ref) {
    var palette = _ref.theme.palette;
    return palette.black;
  },
  position: 'absolute',
  top: 0,
  left: 'calc(.75rem + 1px)',
  fontSize: '.875rem',
  lineHeight: '1.6rem',
  transform: 'translateY(calc(.75rem - 1px))',
  transition: 'all .2s ease',
  pointerEvents: 'none'
};
var activeLabelClassName = {
  color: function color(_ref2) {
    var palette = _ref2.theme.palette;
    return palette.gray_200;
  },
  fontSize: '.75rem',
  lineHeight: '1.8rem',
  transform: 'translateY(0)'
};
var labelWrapperRoot = {
  position: 'relative',
  border: function border(_ref3) {
    var palette = _ref3.theme.palette;
    return "1px solid " + palette.light_gray;
  },
  borderRadius: '.625rem',
  boxSizing: 'border-box'
};
var inputSelectCommonStylesProps = /*#__PURE__*/_extends({}, buttonInputCleanStyles, {
  all: 'unset',
  display: 'block',
  width: '100%',
  padding: '20px 0 5px .75rem',
  boxSizing: 'border-box',
  fontSize: '1rem',
  lineHeight: '1rem',
  borderRadius: '.625rem'
});
var disabled = {
  cursor: 'not-allowed',
  opacity: .4
};
var errorClass = {
  borderColor: function borderColor(_ref4) {
    var palette = _ref4.theme.palette;
    return palette.error;
  }
};

var ADORNMENT_WIDTH = 40;
var useStyles$c = /*#__PURE__*/createUseStyles({
  '@font-face': {
    fontFamily: "SF Pro Text",
    src: "url('" + SFProText + "') format(\"opentype\")"
  },
  root: /*#__PURE__*/_extends({}, labelWrapperRoot, {
    display: 'flex',
    paddingRight: 16
  }),
  input: /*#__PURE__*/_extends({}, inputSelectCommonStylesProps, {
    width: function width(_ref) {
      var adornmentEnd = _ref.adornmentEnd,
          adornmentStart = _ref.adornmentStart;
      return "calc(100% - " + (adornmentStart ? ADORNMENT_WIDTH : 0) + "px - " + (adornmentEnd ? ADORNMENT_WIDTH : 0) + "px)";
    },
    textAlign: 'left',
    fontFamily: 'SF Pro Text',
    '-webkit-tap-highlight-color': 'transparent'
  }),
  inputAdorned: {
    left: '30px !important'
  },
  inputAdornedActive: {
    left: '32px !important'
  },
  unlabeled: {
    padding: '12px 0 12px .75rem'
  },
  labelClass: /*#__PURE__*/_extends({}, labelClassName),
  active: /*#__PURE__*/_extends({}, activeLabelClassName),
  disabledClass: /*#__PURE__*/_extends({}, disabled),
  errorClass: /*#__PURE__*/_extends({}, errorClass),
  typeWrapper: /*#__PURE__*/_extends({}, alignment.center, {
    paddingLeft: 11,
    whiteSpace: 'nowrap',
    width: 40
  }),
  typeWrapperStart: /*#__PURE__*/_extends({}, alignment.center, {
    paddingRight: 11
  }),
  clearIconClass: {
    cursor: 'pointer',
    paddingLeft: 11
  }
});

var img$5 = "data:image/svg+xml,%3csvg width='14' height='14' viewBox='0 0 14 14' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cpath fill-rule='evenodd' clip-rule='evenodd' d='M7 14C10.866 14 14 10.866 14 7C14 3.13401 10.866 0 7 0C3.13401 0 0 3.13401 0 7C0 10.866 3.13401 14 7 14ZM3.99988 4.7074L4.70698 4.00029L7.18201 6.47531L9.65703 4.00029L10.3641 4.7074L7.88911 7.18242L10.3638 9.65714L9.65673 10.3643L7.18201 7.88953L4.70728 10.3643L4.00017 9.65714L6.4749 7.18242L3.99988 4.7074Z' fill='%23C7C7C7'/%3e%3c/svg%3e";

var Input = function Input(_ref) {
  var _ref$error = _ref.error,
      error = _ref$error === void 0 ? false : _ref$error,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      labelClassName = _ref.labelClassName,
      rootClassName = _ref.rootClassName,
      onChange = _ref.onChange,
      label = _ref.label,
      value = _ref.value,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      adornmentEnd = _ref.adornmentEnd,
      adornmentStart = _ref.adornmentStart,
      closeIcon = _ref.closeIcon,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["error", "type", "disabled", "labelClassName", "rootClassName", "inputClassName", "onChange", "label", "value", "onFocus", "onBlur", "adornmentEnd", "adornmentStart", "closeIcon", "autoFocus"]);

  var _useStyles = useStyles$c({
    theme: theming.useTheme(),
    adornmentEnd: adornmentEnd,
    adornmentStart: adornmentStart
  }),
      root = _useStyles.root,
      labelClass = _useStyles.labelClass,
      active = _useStyles.active,
      input = _useStyles.input,
      unlabeled = _useStyles.unlabeled,
      disabledClass = _useStyles.disabledClass,
      errorClass = _useStyles.errorClass,
      typeWrapper = _useStyles.typeWrapper,
      clearIconClass = _useStyles.clearIconClass,
      inputAdorned = _useStyles.inputAdorned,
      inputAdornedActive = _useStyles.inputAdornedActive;

  var inputEl = useRef({});

  var _useState = useState(false),
      activeClass = _useState[0],
      setActiveClass = _useState[1];

  var handleFocus = function handleFocus(e) {
    if (disabled) return;
    setActiveClass(true);

    if (onFocus) {
      onFocus(e);
    }
  };

  var handleBlur = function handleBlur(e) {
    setActiveClass(!!e.target.value);

    if (onBlur) {
      onBlur(e);
    }
  };

  var handleChange = function handleChange(e) {
    if (onChange) {
      onChange(e);
    }
  };

  var handleClean = function handleClean() {
    var evt = new Event('change');
    var current = inputEl.current;
    current.value = '';

    var event = _extends({}, evt, {
      target: current,
      currentTarget: current
    });

    if (onChange) {
      onChange(event);
    }

    current.focus();
  };

  var adornmentClass = '';

  if (adornmentStart) {
    adornmentClass = inputAdorned + " " + (!!value || activeClass ? inputAdornedActive : '');
  }

  var classNameLabel = labelClass + " " + labelClassName + " " + (!!value || activeClass ? active : '') + " " + adornmentClass;
  var rootClass = root + " " + rootClassName + " " + (disabled ? disabledClass : '') + " " + (error ? errorClass : '');
  var inputClass = input + " " + (!label ? unlabeled : '');
  return React.createElement("div", {
    className: rootClass
  }, adornmentStart && React.createElement("div", {
    className: typeWrapper
  }, React.createElement(Typography, {
    variant: TypographyVariants.body1
  }, adornmentStart)), label && React.createElement(Typography, {
    variant: TypographyVariants.body2,
    className: classNameLabel
  }, label), React.createElement("input", Object.assign({
    ref: inputEl,
    type: type,
    disabled: disabled,
    onBlur: handleBlur,
    onFocus: handleFocus,
    className: inputClass,
    value: value,
    onChange: handleChange
  }, otherProps)), adornmentEnd && React.createElement("div", {
    className: typeWrapper
  }, React.createElement(Typography, {
    variant: TypographyVariants.body1
  }, adornmentEnd)), closeIcon && value && React.createElement("img", {
    className: clearIconClass,
    onClick: handleClean,
    src: img$5,
    alt: ""
  }));
};

// node modules
var useStyles$d = /*#__PURE__*/createUseStyles({
  wrapper: {
    position: 'relative',
    height: 48,
    borderRadius: '.5rem',
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.light_gray;
    }
  },
  text: {
    position: 'absolute',
    top: '50%',
    left: '50%',
    transform: 'translate(-50%, -50%)',
    color: function color(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.white;
    },
    zIndex: 1
  },
  childBar: {
    maxWidth: '100%',
    position: 'absolute',
    left: 0,
    top: 0,
    height: '100%',
    borderRadius: '.5rem',
    background: function background(_ref3) {
      var palette = _ref3.theme.palette;
      return palette.primary;
    },
    transition: 'width .3s'
  }
});

// node modules
var ProgressBar = function ProgressBar(_ref) {
  var percents = _ref.percents,
      className = _ref.className;

  var _useStyles = useStyles$d({
    theme: theming.useTheme()
  }),
      wrapper = _useStyles.wrapper,
      childBar = _useStyles.childBar,
      text = _useStyles.text;

  var width = "calc(100% * " + percents / 100 + ")";
  return React.createElement("div", {
    className: wrapper + " " + className
  }, React.createElement("span", {
    className: text
  }, percents, " %"), React.createElement("div", {
    className: childBar,
    style: {
      width: width
    }
  }));
};

var useStyles$e = /*#__PURE__*/createUseStyles({
  progressWrapper: {
    position: 'relative',
    height: 8,
    borderRadius: '1.875rem',
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.gray;
    }
  },
  progress: {
    maxWidth: '100%',
    position: 'absolute',
    left: 0,
    top: 0,
    height: '100%',
    borderRadius: '1.875rem',
    transition: 'width .3s'
  },
  counter: {
    minWidth: '50px',
    textAlign: 'right'
  },
  infoWrapper: /*#__PURE__*/_extends({
    marginBottom: 8
  }, alignment.betweenCenter),
  backBtn: {
    marginTop: 14
  }
});

var img$6 = "data:image/svg+xml,%3csvg width='32' height='32' viewBox='0 0 32 32' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3crect x='32' y='32' width='32' height='32' rx='16' transform='rotate(-180 32 32)' fill='%23EFF2FD'/%3e %3cpath fill-rule='evenodd' clip-rule='evenodd' d='M18.7071 21.7071C18.3166 22.0976 17.6834 22.0976 17.2929 21.7071L12.2929 16.7071C11.9024 16.3166 11.9024 15.6834 12.2929 15.2929L17.2929 10.2929C17.6834 9.90237 18.3166 9.90237 18.7071 10.2929C19.0976 10.6834 19.0976 11.3166 18.7071 11.7071L14.4142 16L18.7071 20.2929C19.0976 20.6834 19.0976 21.3166 18.7071 21.7071Z' fill='%23858DA5' stroke='%23858DA5' stroke-linecap='round' stroke-linejoin='round'/%3e%3c/svg%3e";

// node modules
var ProgressBarThin = function ProgressBarThin(_ref) {
  var _ref$percents = _ref.percents,
      percents = _ref$percents === void 0 ? 0 : _ref$percents,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? palette.primary : _ref$color,
      _ref$completed = _ref.completed,
      completed = _ref$completed === void 0 ? true : _ref$completed,
      title = _ref.title,
      className = _ref.className,
      _ref$backButton = _ref.backButton,
      backButton = _ref$backButton === void 0 ? false : _ref$backButton,
      handleBack = _ref.handleBack,
      _ref$hideTitle = _ref.hideTitle,
      hideTitle = _ref$hideTitle === void 0 ? false : _ref$hideTitle;

  var _useStyles = useStyles$e({
    theme: theming.useTheme()
  }),
      progressWrapper = _useStyles.progressWrapper,
      progress = _useStyles.progress,
      infoWrapper = _useStyles.infoWrapper,
      counter = _useStyles.counter,
      backBtn = _useStyles.backBtn;

  var width = "calc(100% * " + percents / 100 + ")";
  var variant = completed ? TypographyVariants.body2 : TypographyVariants.h3;
  return React.createElement("div", {
    className: className
  }, !hideTitle && React.createElement("div", {
    className: infoWrapper
  }, React.createElement(Typography, {
    variant: variant,
    style: {
      color: color
    }
  }, title), React.createElement(Typography, {
    className: counter,
    variant: variant,
    style: {
      color: color
    }
  }, percents, " %")), React.createElement("div", {
    className: progressWrapper
  }, React.createElement("div", {
    className: progress,
    style: {
      background: color,
      width: width
    }
  })), backButton && React.createElement("img", {
    className: backBtn,
    onClick: handleBack,
    src: img$6,
    alt: ""
  }));
};

var img$7 = "data:image/svg+xml,%3csvg width='8' height='8' viewBox='0 0 8 8' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M7.76011 0.821284C8.04296 1.05699 8.08117 1.47737 7.84546 1.76022L3.40102 7.09355C3.27436 7.24555 3.08672 7.33343 2.88887 7.33343C2.69102 7.33343 2.50339 7.24555 2.37672 7.09355L0.154502 4.42689C-0.0812074 4.14404 -0.0429918 3.72366 0.239859 3.48795C0.522711 3.25224 0.943087 3.29046 1.1788 3.57331L2.88887 5.6254L6.82117 0.906642C7.05688 0.62379 7.47725 0.585574 7.76011 0.821284Z' fill='white'/%3e%3c/svg%3e";

// node modules
var getCorrectInput = function getCorrectInput(i, steps, percents) {
  if (!i) return '';
  if (i / steps * 100 <= percents) return React.createElement("img", {
    style: {
      width: 7,
      marginLeft: '.5px'
    },
    src: img$7,
    alt: ""
  });
  return i;
};
var getCorrectColor = function getCorrectColor(i, steps, percents, colors, backgroundColor) {
  if (i / steps * 100 <= percents) {
    return !colors[i - 1] ? colors[i] : colors[i - 1];
  }

  return backgroundColor || palette.gray_400;
};
var getIndexColorToTitle = function getIndexColorToTitle(correctPercents, steps, colors) {
  var index = Math.floor(steps * correctPercents / 100);

  if (index === colors.length) {
    index = index - 1;
  }

  return index;
};

var createUniqIdGenerator = function createUniqIdGenerator() {
  var number = 0;
  return function () {
    return "id--" + number++;
  };
};

var uniqIdGenerator = /*#__PURE__*/createUniqIdGenerator();

var img$8 = "data:image/svg+xml,%3csvg width='24' height='24' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M14.7071 17.7071C14.3166 18.0976 13.6834 18.0976 13.2929 17.7071L8.29289 12.7071C7.90237 12.3166 7.90237 11.6834 8.29289 11.2929L13.2929 6.29289C13.6834 5.90237 14.3166 5.90237 14.7071 6.29289C15.0976 6.68342 15.0976 7.31658 14.7071 7.70711L10.4142 12L14.7071 16.2929C15.0976 16.6834 15.0976 17.3166 14.7071 17.7071Z' fill='%23858DA5'/%3e%3c/svg%3e";

var useStyles$f = /*#__PURE__*/createUseStyles({
  wrapper: {
    width: '100%',
    minWidth: 200,
    position: 'relative',
    height: 6,
    marginBottom: 17
  },
  cercle: /*#__PURE__*/_extends({
    fontFamily: 'SF Pro Text',
    position: 'absolute',
    top: '50%',
    transform: 'translate(-50%, -50%)',
    width: 16,
    height: 16,
    borderRadius: '50%'
  }, alignment.center, {
    fontSize: 10,
    boxSizing: 'border-box',
    lineHeight: 0,
    color: function color(_ref) {
      var palette = _ref.theme.palette;
      return palette.black;
    }
  }),
  bar: {
    position: 'absolute',
    top: '50%',
    transform: 'translate(0, -50%)',
    height: 8
  },
  coverBlock: /*#__PURE__*/_extends({
    position: 'absolute',
    top: '50%',
    transform: 'translate(0, -50%)',
    right: 0,
    width: '100%',
    height: 8
  }, alignment.center, {
    transition: 'width .3s',
    minWidth: 0
  }),
  thinBlock: {
    width: '100%',
    height: 6
  },
  root: {
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center'
  },
  paddingWrapper: {
    padding: '5px 8px 0',
    position: 'relative'
  },
  backBtn: {
    position: 'absolute',
    top: 25,
    left: -6
  },
  '@media screen and (min-width: 768px)': {
    backBtn: {
      position: 'absolute',
      top: 25,
      left: 0
    }
  }
});

// node modules
var ProgressStepper = function ProgressStepper(_ref) {
  var steps = _ref.steps,
      colors = _ref.colors,
      _ref$percents = _ref.percents,
      percents = _ref$percents === void 0 ? 0 : _ref$percents,
      title = _ref.title,
      backgroundColor = _ref.backgroundColor,
      backButton = _ref.backButton,
      handleBack = _ref.handleBack,
      stepperHeight = _ref.stepperHeight;

  var _useStyles = useStyles$f({
    theme: theming.useTheme()
  }),
      wrapper = _useStyles.wrapper,
      cercle = _useStyles.cercle,
      bar = _useStyles.bar,
      coverBlock = _useStyles.coverBlock,
      thinBlock = _useStyles.thinBlock,
      root = _useStyles.root,
      backBtn = _useStyles.backBtn,
      paddingWrapper = _useStyles.paddingWrapper;

  var generatedArray = new Array(steps + 1).fill(true);
  var correctPercents = percents <= 0 || isNaN(percents) ? 1 : percents;
  correctPercents = correctPercents > 100 ? 100 : correctPercents;
  return React.createElement("div", {
    className: paddingWrapper
  }, React.createElement("div", {
    className: root
  }, React.createElement("div", {
    className: wrapper
  }, generatedArray.map(function (_, i) {
    return React.createElement(Fragment, {
      key: uniqIdGenerator()
    }, !!i && React.createElement("span", {
      style: {
        left: 0,
        width: "calc(" + i + "/" + steps + " * 100%)",
        background: colors[i - 1],
        zIndex: steps + 1 - i,
        height: stepperHeight
      },
      className: bar
    }), React.createElement("span", {
      style: {
        left: "calc(" + i + "/" + steps + " * 100%)",
        zIndex: generatedArray.length + 2,
        background: getCorrectColor(i, steps, percents, colors, backgroundColor),
        color: '#202B47'
      },
      className: cercle
    }, getCorrectInput(i, steps, correctPercents)));
  }), React.createElement("div", {
    style: {
      zIndex: generatedArray.length + 1,
      width: "calc(100% - " + correctPercents + "%)",
      background: backgroundColor || palette.white,
      height: stepperHeight
    },
    className: coverBlock
  }, React.createElement("div", {
    style: {
      background: backgroundColor || palette.gray_400,
      height: stepperHeight
    },
    className: thinBlock
  }))), React.createElement(Typography, {
    style: {
      color: colors[getIndexColorToTitle(correctPercents, steps, colors)]
    },
    variant: TypographyVariants.h4
  }, title), backButton && React.createElement("img", {
    className: backBtn,
    onClick: handleBack,
    src: img$8,
    alt: ""
  })));
};

var useStyles$g = /*#__PURE__*/createUseStyles({
  wrapper: {
    minWidth: 200
  },
  tabWrapper: /*#__PURE__*/_extends({}, alignment.betweenCenter, {
    height: 32,
    padding: 2,
    borderRadius: 8,
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.light;
    }
  }),
  activeBtn: {
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.white;
    }
  },
  btn: {
    minWidth: 'auto',
    padding: 0,
    height: '100%',
    borderRadius: 8
  }
});

// node modules
var Tab = function Tab(_ref) {
  var list = _ref.list,
      _ref$activeTab = _ref.activeTab,
      activeTab = _ref$activeTab === void 0 ? 0 : _ref$activeTab,
      _ref$width = _ref.width,
      width = _ref$width === void 0 ? '100%' : _ref$width,
      _ref$contentClass = _ref.contentClass,
      contentClass = _ref$contentClass === void 0 ? '' : _ref$contentClass,
      _ref$tabWrapperClass = _ref.tabWrapperClass,
      tabWrapperClass = _ref$tabWrapperClass === void 0 ? '' : _ref$tabWrapperClass,
      _ref$tabClass = _ref.tabClass,
      tabClass = _ref$tabClass === void 0 ? '' : _ref$tabClass,
      tabs = _ref.tabs,
      onChange = _ref.onChange;

  var _useStyles = useStyles$g({
    theme: theming.useTheme()
  }),
      tabWrapper = _useStyles.tabWrapper,
      activeBtn = _useStyles.activeBtn,
      btn = _useStyles.btn,
      wrapper = _useStyles.wrapper;

  var _useState = useState(activeTab),
      currentTab = _useState[0],
      setCurrentTab = _useState[1];

  useEffect(function () {
    setCurrentTab(activeTab);
  }, [activeTab]);
  useEffect(function () {
    if (onChange) onChange(currentTab);
  }, [currentTab]);
  if (tabs != null && tabs.length) return React.createElement("div", {
    className: wrapper,
    style: {
      width: width
    }
  }, React.createElement("div", {
    className: tabWrapper + " " + tabWrapperClass
  }, tabs.map(function (title, i) {
    var className = (i === currentTab ? activeBtn : '') + " " + btn + " " + tabClass;
    return React.createElement(SimpleButton, {
      key: uniqIdGenerator(),
      className: className,
      width: "calc(100% / " + tabs.length + " )",
      onClick: function onClick() {
        return setCurrentTab(i);
      },
      label: React.createElement(Typography, {
        variant: TypographyVariants.label
      }, title)
    });
  })));
  return React.createElement("div", {
    className: wrapper,
    style: {
      width: width
    }
  }, React.createElement("div", {
    className: tabWrapper + " " + tabWrapperClass
  }, list.map(function (_ref2, i) {
    var title = _ref2.title;
    var className = (i === currentTab ? activeBtn : '') + " " + btn + " " + tabClass;
    return React.createElement(SimpleButton, {
      key: uniqIdGenerator(),
      className: className,
      width: "calc(100% / " + list.length + " )",
      onClick: function onClick() {
        return setCurrentTab(i);
      },
      label: React.createElement(Typography, {
        variant: TypographyVariants.label
      }, title)
    });
  })), React.createElement("div", {
    className: contentClass
  }, list[currentTab].Content));
};

function IsJsonString(str) {
  try {
    JSON.parse(str);
  } catch (e) {
    return false;
  }

  return true;
}

var UPDATE_STORAGE_EVENT = 'onStoreUpdated';

var createUpdateStorageCustomEvent = function createUpdateStorageCustomEvent(value, keyEvent) {
  return new CustomEvent(UPDATE_STORAGE_EVENT, {
    detail: {
      value: value,
      keyEvent: keyEvent
    }
  });
};

var getDefaultValue = function getDefaultValue(key, defaultValue) {
  var data = localStorage.getItem(key);

  if (data) {
    if (IsJsonString(data)) {
      return JSON.parse(data);
    } else {
      return data;
    }
  } else {
    return defaultValue;
  }
};

var useLocalStorage = function useLocalStorage(_ref) {
  var key = _ref.key,
      defaultValue = _ref.defaultValue;

  var _useState = useState(getDefaultValue(key, defaultValue)),
      pageValue = _useState[0],
      setPageValue = _useState[1];

  useEffect(function () {
    window.addEventListener(UPDATE_STORAGE_EVENT, function (e) {
      if (key === e.detail.keyEvent) {
        setPageValue(e.detail.value);
      }
    });
    return function () {
      window.removeEventListener(UPDATE_STORAGE_EVENT, function (e) {
        if (key === e.detail.keyEvent) {
          setPageValue(e.detail.value);
        }
      });
    };
  }, [key]);
  useEffect(function () {
    if (typeof pageValue === 'object') {
      localStorage.setItem(key, JSON.stringify(pageValue) || '');
    } else {
      localStorage.setItem(key, typeof pageValue === 'boolean' ? pageValue : pageValue || '');
    }

    window.dispatchEvent(createUpdateStorageCustomEvent(pageValue, key));
  }, [pageValue, key]);
  return {
    pageValue: pageValue,
    setPageValue: setPageValue
  };
};

var HOME_ROUTE = "/";

var getLastVisitedPage = function getLastVisitedPage(availableRoutersList) {
  return availableRoutersList[availableRoutersList.length - 1];
};

var isNotStartedPageAndNotIncludeInList = function isNotStartedPageAndNotIncludeInList(availableRoutersList, pathname, startPage) {
  return !availableRoutersList.includes(pathname) && startPage.current.pathname !== pathname;
};

var useAccessPageChecking = function useAccessPageChecking(pathname) {
  var startPage = useRef({
    pathname: pathname
  });

  var _useState = useState(false),
      routerAvailable = _useState[0],
      doRouterAvailable = _useState[1];

  var _useLocalStorage = useLocalStorage({
    key: "available_routes",
    defaultValue: ["/"]
  }),
      availableRoutersList = _useLocalStorage.pageValue,
      addAvailableRoute = _useLocalStorage.setPageValue;

  useEffect(function () {
    if (availableRoutersList != null && availableRoutersList.includes(pathname)) {
      doRouterAvailable(true);
    } else if (pathname === HOME_ROUTE && !(availableRoutersList != null && availableRoutersList.includes(pathname))) {
      addAvailableRoute([pathname]);
      doRouterAvailable(true);
    } else {
      window.location.pathname = getLastVisitedPage(availableRoutersList);
    }
  }, []);
  useEffect(function () {
    if (isNotStartedPageAndNotIncludeInList(availableRoutersList, pathname, startPage)) {
      addAvailableRoute([].concat(availableRoutersList, [pathname]));
    }
  }, [pathname]);
  return {
    routerAvailable: routerAvailable
  };
};

var COUNTRIES_USING_EUR_GBP = {
  'AT': 'EUR',
  'BE': 'EUR',
  'CY': 'EUR',
  'EE': 'EUR',
  'FI': 'EUR',
  'FR': 'EUR',
  'DE': 'EUR',
  'GR': 'EUR',
  'IE': 'EUR',
  'IT': 'EUR',
  'LV': 'EUR',
  'LT': 'EUR',
  'LU': 'EUR',
  'MT': 'EUR',
  'NL': 'EUR',
  'PT': 'EUR',
  'SK': 'EUR',
  'SI': 'EUR',
  'ES': 'EUR',
  'GB': 'GBP'
};

var getChangedUsdToEurGbp = function getChangedUsdToEurGbp(_ref) {
  var _ref2;

  var pricesUSD = _ref.pricesUSD,
      pricesEurGbp = _ref.pricesEurGbp;
  return _ref2 = {}, _ref2[pricesUSD.trialPay_1] = pricesEurGbp == null ? void 0 : pricesEurGbp.trialPay_1, _ref2[pricesUSD.trialPay_5] = pricesEurGbp == null ? void 0 : pricesEurGbp.trialPay_5, _ref2[pricesUSD.trialPay_9] = pricesEurGbp == null ? void 0 : pricesEurGbp.trialPay_9, _ref2[pricesUSD.trialPay_13] = pricesEurGbp == null ? void 0 : pricesEurGbp.trialPay_13, _ref2[pricesUSD.planPrice] = pricesEurGbp == null ? void 0 : pricesEurGbp.planPrice, _ref2[pricesUSD.oldPlanPrice] = pricesEurGbp == null ? void 0 : pricesEurGbp.oldPlanPrice, _ref2[pricesUSD.basicPlan] = pricesEurGbp == null ? void 0 : pricesEurGbp.basicPlan, _ref2;
};

var getChangedUsd = function getChangedUsd(_ref3) {
  var _ref4;

  var pricesUSD = _ref3.pricesUSD;
  return _ref4 = {}, _ref4[pricesUSD.trialPay_1] = pricesUSD.trialPay_1, _ref4[pricesUSD.trialPay_5] = pricesUSD.trialPay_5, _ref4[pricesUSD.trialPay_9] = pricesUSD.trialPay_9, _ref4[pricesUSD.trialPay_13] = pricesUSD.trialPay_13, _ref4[pricesUSD.planPrice] = pricesUSD.planPrice, _ref4[pricesUSD.oldPlanPrice] = pricesUSD.oldPlanPrice, _ref4[pricesUSD.basicPlan] = pricesUSD.basicPlan, _ref4;
};

var getChangedCurrencies = function getChangedCurrencies(props) {
  return {
    USD: getChangedUsd(props),
    EUR: getChangedUsdToEurGbp(props),
    GBP: getChangedUsdToEurGbp(props)
  };
};
var CURRENCY_LABELS = {
  USD: '$',
  GBP: '£',
  EUR: '€'
};

var useCurrencyPricing = function useCurrencyPricing(props) {
  var pricesUSD = props.pricesUSD;

  var _useLocalStorage = useLocalStorage({
    key: 'utm_country',
    defaultValue: ''
  }),
      pageValue = _useLocalStorage.pageValue; //@ts-ignore


  var currency = COUNTRIES_USING_EUR_GBP[pageValue] || 'USD'; //@ts-ignore

  var currencyLabel = CURRENCY_LABELS[currency] || '$';
  var changedUSD = getChangedCurrencies(props); //@ts-ignore

  var changedPrices = changedUSD[currency];
  return {
    basicPrices: pricesUSD,
    changedPrices: changedPrices,
    currencyLabel: currencyLabel,
    currency: currency
  };
};

// node modules
var useStyles$h = /*#__PURE__*/createUseStyles({
  enter: {
    opacity: 0,
    transform: 'translateX(20px)'
  },
  enterActive: {
    opacity: 1,
    transform: 'translateX(0)',
    transition: function transition(_ref) {
      var timeout = _ref.theme.timeout;
      return "opacity " + timeout + "ms, transform " + timeout + "ms";
    },
    transitionTimingFunction: 'ease-out'
  },
  exit: {
    opacity: 1
  },
  exitActive: {
    opacity: 0,
    transform: 'translate(20px)',
    transition: function transition(_ref2) {
      var timeout = _ref2.theme.timeout;
      return "opacity " + timeout + "ms, transform " + timeout + "ms";
    }
  }
});

var TransitionShowing = function TransitionShowing(_ref) {
  var children = _ref.children,
      delay = _ref.delay,
      disabled = _ref.disabled,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["children", "delay", "disabled"]);

  var timeout = otherProps.timeout,
      className = otherProps.className;

  var _useState = useState(false),
      showed = _useState[0],
      setShowed = _useState[1];

  var classes = useStyles$h({
    theme: {
      timeout: timeout
    }
  });
  useEffect(function () {
    if (!disabled && delay !== undefined) {
      setTimeout(function () {
        return setShowed(true);
      }, delay);
    }
  }, []);
  if (disabled) return children;
  return React.createElement(CSSTransition, Object.assign({}, otherProps, {
    "in": showed,
    unmountOnExit: true,
    classNames: _extends({}, classes)
  }), React.createElement("div", {
    className: className || ''
  }, children));
};

var useStyles$i = /*#__PURE__*/createUseStyles({
  root: {
    opacity: 0,
    transition: function transition(_ref) {
      var timeout = _ref.theme.timeout;
      return "opacity " + timeout + "ms";
    }
  },
  showed: {
    opacity: 1
  }
});

var OpacityShowing = function OpacityShowing(_ref) {
  var _ref$delay = _ref.delay,
      delay = _ref$delay === void 0 ? 0 : _ref$delay,
      _ref$timeout = _ref.timeout,
      timeout = _ref$timeout === void 0 ? 0 : _ref$timeout,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      children = _ref.children;

  var _useState = useState(false),
      active = _useState[0],
      setActive = _useState[1];

  var _useStyles = useStyles$i({
    theme: {
      timeout: timeout
    }
  }),
      root = _useStyles.root,
      showed = _useStyles.showed;

  useEffect(function () {
    if (!disabled) {
      setTimeout(function () {
        setActive(true);
      }, delay);
    }
  }, []);
  return React.createElement("div", {
    className: root + " " + (active || disabled ? showed : '')
  }, children);
};

var animations = {
  transition: TransitionShowing,
  opacity: OpacityShowing
};
var AnimationWrapper = function AnimationWrapper(_ref) {
  var _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'transition' : _ref$type,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["type"]);

  // @ts-ignore
  var Component = animations[type] || React.createElement(React.Fragment, null, otherProps.children);
  return React.createElement(Component, Object.assign({}, otherProps));
};

// node modules
var typeValidator = {
  emptyString: function emptyString(value) {
    return !isEmpty(value);
  },
  email: function email(value) {
    return !value.includes('@');
  }
};
var validator = {
  maxLength: function maxLength(value, options) {
    return value.toString().trim().length > options.value;
  },
  minLength: function minLength(value, options) {
    return value.toString().trim().length < options.value;
  },
  // @ts-ignore
  type: function type(value, _ref) {
    var _type = _ref.value;
    return typeValidator[_type](value);
  }
};
var numberValidator = {
  moreThen: function moreThen(value, options) {
    return !(value > options.value);
  },
  lessThen: function lessThen(value, options) {
    return !(value < options.value);
  },
  equal: function equal(value, options) {
    return value !== options.value;
  }
};

// node modules
var useStyles$j = /*#__PURE__*/createUseStyles({
  errorMessageClass: {
    textAlign: 'left',
    padding: '3px 0',
    color: function color(_ref) {
      var palette = _ref.theme.palette;
      return palette.error;
    },
    marginTop: '8px'
  },
  validatedInputWrapper: {
    width: '100%'
  },
  hidden: {
    display: "none"
  }
});

var NUMBER_TYPE = 'number';
var numberKeys = {
  lessThen: true,
  moreThen: true,
  equal: true
};
var ValidatedInput = function ValidatedInput(_ref) {
  var toggleValidationListener = _ref.toggleValidationListener,
      onError = _ref.onError,
      onChange = _ref.onChange,
      _ref$validationQuery = _ref.validationQuery,
      validationQuery = _ref$validationQuery === void 0 ? {
    type: 'emptyString'
  } : _ref$validationQuery,
      _ref$errorDelay = _ref.errorDelay,
      errorDelay = _ref$errorDelay === void 0 ? false : _ref$errorDelay,
      _ref$errorDelayTime = _ref.errorDelayTime,
      errorDelayTime = _ref$errorDelayTime === void 0 ? 300 : _ref$errorDelayTime,
      _ref$rootValidatedInp = _ref.rootValidatedInputClass,
      rootValidatedInputClass = _ref$rootValidatedInp === void 0 ? '' : _ref$rootValidatedInp,
      onBlur = _ref.onBlur,
      autoFocus = _ref.autoFocus,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["toggleValidationListener", "errorText", "onError", "onChange", "validationQuery", "errorDelay", "errorDelayTime", "rootValidatedInputClass", "onBlur", "autoFocus"]);

  var touched = useRef(Boolean(otherProps.value));

  var _useStyles = useStyles$j({
    theme: theming.useTheme()
  }),
      errorMessageClass = _useStyles.errorMessageClass,
      validatedInputWrapper = _useStyles.validatedInputWrapper,
      hidden = _useStyles.hidden;

  var _useState = useState([]),
      errors = _useState[0],
      setErrors = _useState[1];

  var type = validationQuery.type; // @ts-ignore

  var isNumberType = Boolean(type && type.value === NUMBER_TYPE);

  var toggleError = function toggleError(errors) {
    if (onError) onError(Boolean(errors.length));
    setErrors(errors);
  };

  var _useRef = useRef(debounce(toggleError, errorDelayTime)),
      delayedToggleError = _useRef.current;

  var handleBlur = function handleBlur(e) {
    if (!touched.current) {
      touched.current = true;
      var _e$target$value = e.target.value,
          value = _e$target$value === void 0 ? '' : _e$target$value;
      if (!isNumberType) validate(value);else validateNumber(value);
    }

    if (onBlur) {
      onBlur(e);
    }
  };

  var validate = function validate(value) {
    var errors = keys(validationQuery).reduce(function (err, key) {
      // @ts-ignore
      var paramValidator = validator[key];

      if (paramValidator) {
        // @ts-ignore
        var param = validationQuery[key]; // @ts-ignore

        var error = paramValidator(value, param); // @ts-ignore

        if (error) err.push(param);
      }

      return err;
    }, []);
    if (errorDelay) delayedToggleError(errors);else toggleError(errors);
  };

  var validateNumber = function validateNumber(value) {
    var errors = keys(type).reduce(function (err, key) {
      // @ts-ignore
      var isCorrectKey = Boolean(numberKeys[key]);

      if (isCorrectKey) {
        // @ts-ignore
        var param = type[key]; // @ts-ignore

        var error = numberValidator[key](Number(value), param); // @ts-ignore

        if (error) err.push(param);
      }

      return err;
    }, []);
    if (errorDelay) delayedToggleError(errors);else toggleError(errors);
  };

  var handleChange = function handleChange(e) {
    if (!touched.current) {
      touched.current = true;
    } // @ts-ignore


    var value = e.target.value;
    if (!isNumberType) validate(value);else validateNumber(value);
    if (onChange) onChange(e);
  };

  var handleKeyDown = function handleKeyDown(e) {
    var onKeyDown = otherProps.onKeyDown;
    if (onKeyDown) onKeyDown(e);
    if (!isNumberType) return;
    var regexp = /[0-9]/;
    var isBackspace = e.key === 'Backspace';
    var isNotNumber = !regexp.test(e.key) && !isBackspace;
    if (isNotNumber) e.preventDefault();
  };

  useEffect(function () {
    if (touched.current) {
      var _otherProps$value = otherProps.value,
          value = _otherProps$value === void 0 ? "" : _otherProps$value;
      if (!isNumberType) validate(value);else validateNumber(value);
    }
  }, [toggleValidationListener]);
  var isErrorMessageExist = errors[0] && errors[0].errorMessage;
  return React.createElement("div", {
    className: validatedInputWrapper + " " + rootValidatedInputClass
  }, React.createElement(Input, Object.assign({
    autoFocus: autoFocus,
    onBlur: handleBlur,
    onKeyDown: handleKeyDown,
    onChange: handleChange,
    error: Boolean(errors[0])
  }, isNumberType ? {
    pattern: "[0-9]*"
  } : {}, otherProps)), React.createElement(Typography, {
    className: errorMessageClass + " " + (isErrorMessageExist ? '' : hidden),
    variant: TypographyVariants.label
  }, errors[0] ? errors[0].errorMessage : '1'));
};

var img$9 = "data:image/svg+xml,%3csvg width='22' height='24' viewBox='0 0 22 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M1 0V24' stroke='%23C7C7C7'/%3e%3cpath d='M15.1235 15.9932L20.4266 10.7432H9.82039L15.1235 15.9932Z' fill='%238E8E93'/%3e%3c/svg%3e";

var useStyles$k = /*#__PURE__*/createUseStyles({
  '@font-face': {
    fontFamily: "SF Pro Text",
    src: "url('" + SFProText + "') format(\"opentype\")"
  },
  root: /*#__PURE__*/_extends({}, labelWrapperRoot, {
    height: 45
  }),
  labelClass: /*#__PURE__*/_extends({}, labelClassName),
  selectClass: /*#__PURE__*/_extends({}, inputSelectCommonStylesProps, {
    color: 'transparent',
    transition: 'color .5s ease-out .2s',
    paddingRight: 30,
    fontFamily: "SF Pro Text"
  }),
  active: /*#__PURE__*/_extends({}, activeLabelClassName),
  activeSelect: {
    color: function color(_ref) {
      var palette = _ref.theme.palette;
      return palette.black;
    }
  },
  arrowWrapper: /*#__PURE__*/_extends({}, alignment.center, {
    position: 'absolute',
    right: 4,
    height: 23,
    width: 30,
    top: '50%',
    transform: 'translate(0, -50%)',
    zIndex: -1
  }),
  disabledClass: /*#__PURE__*/_extends({}, disabled),
  errorClass: /*#__PURE__*/_extends({}, errorClass),
  hideFirstOption: {
    display: "none"
  }
});

var defaultValue = {
  value: '',
  displayValue: ''
};
var Select = function Select(_ref) {
  var _ref$error = _ref.error,
      error = _ref$error === void 0 ? false : _ref$error,
      _ref$rootClassName = _ref.rootClassName,
      rootClassName = _ref$rootClassName === void 0 ? '' : _ref$rootClassName,
      _ref$selectClassName = _ref.selectClassName,
      selectClassName = _ref$selectClassName === void 0 ? '' : _ref$selectClassName,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? [] : _ref$options,
      placeholder = _ref.placeholder,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? defaultValue : _ref$value,
      onChange = _ref.onChange,
      disabled = _ref.disabled,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["error", "rootClassName", "selectClassName", "options", "placeholder", "value", "onChange", "disabled"]);

  var selectedValue = value.value;

  var _useStyles = useStyles$k({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      labelClass = _useStyles.labelClass,
      selectClass = _useStyles.selectClass,
      active = _useStyles.active,
      activeSelect = _useStyles.activeSelect,
      arrowWrapper = _useStyles.arrowWrapper,
      disabledClass = _useStyles.disabledClass,
      errorClass = _useStyles.errorClass,
      hideFirstOption = _useStyles.hideFirstOption;

  var rootClass = root + " " + rootClassName + " " + (disabled ? disabledClass : '') + " " + (error ? errorClass : '');
  var labelClassName = labelClass + " " + (selectedValue !== '' ? active : '');
  var selectRootClassName = selectClass + " " + selectClassName + " " + (selectedValue ? activeSelect : '');

  var handleChange = function handleChange(e) {
    if (onChange) {
      onChange(e);
    }
  };

  return React.createElement("div", {
    className: rootClass
  }, placeholder && React.createElement(Typography, {
    variant: TypographyVariants.body2,
    className: labelClassName
  }, placeholder), React.createElement("div", {
    className: arrowWrapper
  }, React.createElement("img", {
    src: img$9,
    alt: ""
  })), React.createElement("select", Object.assign({
    disabled: disabled,
    onChange: handleChange,
    value: selectedValue,
    className: selectRootClassName
  }, otherProps), React.createElement("option", {
    disabled: true,
    className: hideFirstOption
  }), React.createElement("option", {
    disabled: true,
    value: ""
  }, placeholder), options.map(function (_ref2) {
    var value = _ref2.value,
        displayValue = _ref2.displayValue;
    return React.createElement("option", {
      key: value,
      value: value
    }, displayValue);
  })));
};

var img$a = "data:image/svg+xml,%3csvg width='20' height='21' viewBox='0 0 20 21' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cg clip-path='url(%23clip0)'%3e %3cpath d='M14.9935 6.7192C14.6856 6.3946 14.1724 6.3803 13.8473 6.68893L8.67105 11.5979L6.20215 9.06299C5.88945 8.74217 5.37676 8.73514 5.05566 9.04787C4.73484 9.36029 4.72808 9.87354 5.04051 10.1944L8.06754 13.3022C8.22617 13.4652 8.43699 13.5473 8.64836 13.5473C8.84891 13.5473 9.04945 13.4733 9.20648 13.3249L14.9632 7.86545C15.2881 7.55733 15.3018 7.04409 14.9935 6.7192Z' fill='%2397C75A'/%3e %3cpath d='M10 0.00708008C4.48594 0.00708008 0 4.49302 0 10.0071C0 15.5211 4.48594 20.0071 10 20.0071C15.5141 20.0071 20 15.5211 20 10.0071C20 4.49302 15.5141 0.00708008 10 0.00708008ZM10 18.3855C5.38027 18.3855 1.6216 14.6271 1.6216 10.0071C1.6216 5.38735 5.38023 1.62868 10 1.62868C14.62 1.62868 18.3784 5.38731 18.3784 10.0071C18.3784 14.6271 14.62 18.3855 10 18.3855Z' fill='%2397C75A'/%3e %3c/g%3e %3cdefs%3e %3cclipPath id='clip0'%3e %3crect width='20' height='20' fill='white' transform='translate(0 0.00708008)'/%3e %3c/clipPath%3e %3c/defs%3e%3c/svg%3e";

var img$b = "data:image/svg+xml,%3csvg width='20' height='21' viewBox='0 0 20 21' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cpath d='M19.25 10.0071C19.25 15.1157 15.1086 19.2571 10 19.2571C4.89137 19.2571 0.75 15.1157 0.75 10.0071C0.75 4.89845 4.89137 0.75708 10 0.75708C15.1086 0.75708 19.25 4.89845 19.25 10.0071Z' stroke='%23CF382F' stroke-width='1.5' stroke-linecap='round' stroke-linejoin='round'/%3e %3cpath d='M10 6.00708V10.0071' stroke='%23CF382F' stroke-width='1.5' stroke-linecap='round' stroke-linejoin='round'/%3e %3cpath d='M10 14.0071H10.01' stroke='%23CF382F' stroke-width='1.5' stroke-linecap='round' stroke-linejoin='round'/%3e%3c/svg%3e";

// node modules
var useStyles$l = /*#__PURE__*/createUseStyles({
  block: {
    border: function border(_ref) {
      var variant = _ref.variant;
      return "1px solid " + (variant ? '#CF382F' : '#97C75A');
    },
    background: function background(_ref2) {
      var variant = _ref2.variant;
      return variant ? '#FBEBEB' : '#F0F8E6';
    },
    display: 'flex',
    padding: '12px 17px',
    width: '100%',
    alignItems: 'flex-start',
    boxSizing: 'border-box',
    borderRadius: '10px'
  },
  typography: {
    textAlign: 'left',
    letterSpacing: '0.0008em',
    color: '#121620',
    fontWeight: 'normal',
    marginLeft: '10px',
    width: '100%'
  }
});

// node modules
var InfoBlock = function InfoBlock(_ref) {
  var variant = _ref.variant,
      text = _ref.text,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className;

  var _useStyles = useStyles$l({
    variant: variant === 'error'
  }),
      block = _useStyles.block,
      typography = _useStyles.typography;

  var blockClassName = block + " " + className;
  return React.createElement("div", {
    className: blockClassName
  }, React.createElement("img", {
    src: variant === 'error' ? img$b : img$a,
    alt: "icon"
  }), React.createElement(Typography, {
    variant: TypographyVariants.h4,
    className: typography
  }, text));
};

// node modules
var ThemeProvider = function ThemeProvider(_ref) {
  var theme = _ref.theme,
      children = _ref.children;
  var ThemeProvider = theming.ThemeProvider;
  return React.createElement(ThemeProvider, {
    theme: theme || defaultTheme
  }, children);
};

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var runtime_1 = createCommonjsModule(function (module) {
/**
 * Copyright (c) 2014-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var runtime = (function (exports) {

  var Op = Object.prototype;
  var hasOwn = Op.hasOwnProperty;
  var undefined$1; // More compressible than void 0.
  var $Symbol = typeof Symbol === "function" ? Symbol : {};
  var iteratorSymbol = $Symbol.iterator || "@@iterator";
  var asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator";
  var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";

  function define(obj, key, value) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
    return obj[key];
  }
  try {
    // IE 8 has a broken Object.defineProperty that only works on DOM objects.
    define({}, "");
  } catch (err) {
    define = function(obj, key, value) {
      return obj[key] = value;
    };
  }

  function wrap(innerFn, outerFn, self, tryLocsList) {
    // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
    var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;
    var generator = Object.create(protoGenerator.prototype);
    var context = new Context(tryLocsList || []);

    // The ._invoke method unifies the implementations of the .next,
    // .throw, and .return methods.
    generator._invoke = makeInvokeMethod(innerFn, self, context);

    return generator;
  }
  exports.wrap = wrap;

  // Try/catch helper to minimize deoptimizations. Returns a completion
  // record like context.tryEntries[i].completion. This interface could
  // have been (and was previously) designed to take a closure to be
  // invoked without arguments, but in all the cases we care about we
  // already have an existing method we want to call, so there's no need
  // to create a new function object. We can even get away with assuming
  // the method takes exactly one argument, since that happens to be true
  // in every case, so we don't have to touch the arguments object. The
  // only additional allocation required is the completion record, which
  // has a stable shape and so hopefully should be cheap to allocate.
  function tryCatch(fn, obj, arg) {
    try {
      return { type: "normal", arg: fn.call(obj, arg) };
    } catch (err) {
      return { type: "throw", arg: err };
    }
  }

  var GenStateSuspendedStart = "suspendedStart";
  var GenStateSuspendedYield = "suspendedYield";
  var GenStateExecuting = "executing";
  var GenStateCompleted = "completed";

  // Returning this object from the innerFn has the same effect as
  // breaking out of the dispatch switch statement.
  var ContinueSentinel = {};

  // Dummy constructor functions that we use as the .constructor and
  // .constructor.prototype properties for functions that return Generator
  // objects. For full spec compliance, you may wish to configure your
  // minifier not to mangle the names of these two functions.
  function Generator() {}
  function GeneratorFunction() {}
  function GeneratorFunctionPrototype() {}

  // This is a polyfill for %IteratorPrototype% for environments that
  // don't natively support it.
  var IteratorPrototype = {};
  IteratorPrototype[iteratorSymbol] = function () {
    return this;
  };

  var getProto = Object.getPrototypeOf;
  var NativeIteratorPrototype = getProto && getProto(getProto(values([])));
  if (NativeIteratorPrototype &&
      NativeIteratorPrototype !== Op &&
      hasOwn.call(NativeIteratorPrototype, iteratorSymbol)) {
    // This environment has a native %IteratorPrototype%; use it instead
    // of the polyfill.
    IteratorPrototype = NativeIteratorPrototype;
  }

  var Gp = GeneratorFunctionPrototype.prototype =
    Generator.prototype = Object.create(IteratorPrototype);
  GeneratorFunction.prototype = Gp.constructor = GeneratorFunctionPrototype;
  GeneratorFunctionPrototype.constructor = GeneratorFunction;
  GeneratorFunction.displayName = define(
    GeneratorFunctionPrototype,
    toStringTagSymbol,
    "GeneratorFunction"
  );

  // Helper for defining the .next, .throw, and .return methods of the
  // Iterator interface in terms of a single ._invoke method.
  function defineIteratorMethods(prototype) {
    ["next", "throw", "return"].forEach(function(method) {
      define(prototype, method, function(arg) {
        return this._invoke(method, arg);
      });
    });
  }

  exports.isGeneratorFunction = function(genFun) {
    var ctor = typeof genFun === "function" && genFun.constructor;
    return ctor
      ? ctor === GeneratorFunction ||
        // For the native GeneratorFunction constructor, the best we can
        // do is to check its .name property.
        (ctor.displayName || ctor.name) === "GeneratorFunction"
      : false;
  };

  exports.mark = function(genFun) {
    if (Object.setPrototypeOf) {
      Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
    } else {
      genFun.__proto__ = GeneratorFunctionPrototype;
      define(genFun, toStringTagSymbol, "GeneratorFunction");
    }
    genFun.prototype = Object.create(Gp);
    return genFun;
  };

  // Within the body of any async function, `await x` is transformed to
  // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
  // `hasOwn.call(value, "__await")` to determine if the yielded value is
  // meant to be awaited.
  exports.awrap = function(arg) {
    return { __await: arg };
  };

  function AsyncIterator(generator, PromiseImpl) {
    function invoke(method, arg, resolve, reject) {
      var record = tryCatch(generator[method], generator, arg);
      if (record.type === "throw") {
        reject(record.arg);
      } else {
        var result = record.arg;
        var value = result.value;
        if (value &&
            typeof value === "object" &&
            hasOwn.call(value, "__await")) {
          return PromiseImpl.resolve(value.__await).then(function(value) {
            invoke("next", value, resolve, reject);
          }, function(err) {
            invoke("throw", err, resolve, reject);
          });
        }

        return PromiseImpl.resolve(value).then(function(unwrapped) {
          // When a yielded Promise is resolved, its final value becomes
          // the .value of the Promise<{value,done}> result for the
          // current iteration.
          result.value = unwrapped;
          resolve(result);
        }, function(error) {
          // If a rejected Promise was yielded, throw the rejection back
          // into the async generator function so it can be handled there.
          return invoke("throw", error, resolve, reject);
        });
      }
    }

    var previousPromise;

    function enqueue(method, arg) {
      function callInvokeWithMethodAndArg() {
        return new PromiseImpl(function(resolve, reject) {
          invoke(method, arg, resolve, reject);
        });
      }

      return previousPromise =
        // If enqueue has been called before, then we want to wait until
        // all previous Promises have been resolved before calling invoke,
        // so that results are always delivered in the correct order. If
        // enqueue has not been called before, then it is important to
        // call invoke immediately, without waiting on a callback to fire,
        // so that the async generator function has the opportunity to do
        // any necessary setup in a predictable way. This predictability
        // is why the Promise constructor synchronously invokes its
        // executor callback, and why async functions synchronously
        // execute code before the first await. Since we implement simple
        // async functions in terms of async generators, it is especially
        // important to get this right, even though it requires care.
        previousPromise ? previousPromise.then(
          callInvokeWithMethodAndArg,
          // Avoid propagating failures to Promises returned by later
          // invocations of the iterator.
          callInvokeWithMethodAndArg
        ) : callInvokeWithMethodAndArg();
    }

    // Define the unified helper method that is used to implement .next,
    // .throw, and .return (see defineIteratorMethods).
    this._invoke = enqueue;
  }

  defineIteratorMethods(AsyncIterator.prototype);
  AsyncIterator.prototype[asyncIteratorSymbol] = function () {
    return this;
  };
  exports.AsyncIterator = AsyncIterator;

  // Note that simple async functions are implemented on top of
  // AsyncIterator objects; they just return a Promise for the value of
  // the final result produced by the iterator.
  exports.async = function(innerFn, outerFn, self, tryLocsList, PromiseImpl) {
    if (PromiseImpl === void 0) PromiseImpl = Promise;

    var iter = new AsyncIterator(
      wrap(innerFn, outerFn, self, tryLocsList),
      PromiseImpl
    );

    return exports.isGeneratorFunction(outerFn)
      ? iter // If outerFn is a generator, return the full iterator.
      : iter.next().then(function(result) {
          return result.done ? result.value : iter.next();
        });
  };

  function makeInvokeMethod(innerFn, self, context) {
    var state = GenStateSuspendedStart;

    return function invoke(method, arg) {
      if (state === GenStateExecuting) {
        throw new Error("Generator is already running");
      }

      if (state === GenStateCompleted) {
        if (method === "throw") {
          throw arg;
        }

        // Be forgiving, per 25.3.3.3.3 of the spec:
        // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
        return doneResult();
      }

      context.method = method;
      context.arg = arg;

      while (true) {
        var delegate = context.delegate;
        if (delegate) {
          var delegateResult = maybeInvokeDelegate(delegate, context);
          if (delegateResult) {
            if (delegateResult === ContinueSentinel) continue;
            return delegateResult;
          }
        }

        if (context.method === "next") {
          // Setting context._sent for legacy support of Babel's
          // function.sent implementation.
          context.sent = context._sent = context.arg;

        } else if (context.method === "throw") {
          if (state === GenStateSuspendedStart) {
            state = GenStateCompleted;
            throw context.arg;
          }

          context.dispatchException(context.arg);

        } else if (context.method === "return") {
          context.abrupt("return", context.arg);
        }

        state = GenStateExecuting;

        var record = tryCatch(innerFn, self, context);
        if (record.type === "normal") {
          // If an exception is thrown from innerFn, we leave state ===
          // GenStateExecuting and loop back for another invocation.
          state = context.done
            ? GenStateCompleted
            : GenStateSuspendedYield;

          if (record.arg === ContinueSentinel) {
            continue;
          }

          return {
            value: record.arg,
            done: context.done
          };

        } else if (record.type === "throw") {
          state = GenStateCompleted;
          // Dispatch the exception by looping back around to the
          // context.dispatchException(context.arg) call above.
          context.method = "throw";
          context.arg = record.arg;
        }
      }
    };
  }

  // Call delegate.iterator[context.method](context.arg) and handle the
  // result, either by returning a { value, done } result from the
  // delegate iterator, or by modifying context.method and context.arg,
  // setting context.delegate to null, and returning the ContinueSentinel.
  function maybeInvokeDelegate(delegate, context) {
    var method = delegate.iterator[context.method];
    if (method === undefined$1) {
      // A .throw or .return when the delegate iterator has no .throw
      // method always terminates the yield* loop.
      context.delegate = null;

      if (context.method === "throw") {
        // Note: ["return"] must be used for ES3 parsing compatibility.
        if (delegate.iterator["return"]) {
          // If the delegate iterator has a return method, give it a
          // chance to clean up.
          context.method = "return";
          context.arg = undefined$1;
          maybeInvokeDelegate(delegate, context);

          if (context.method === "throw") {
            // If maybeInvokeDelegate(context) changed context.method from
            // "return" to "throw", let that override the TypeError below.
            return ContinueSentinel;
          }
        }

        context.method = "throw";
        context.arg = new TypeError(
          "The iterator does not provide a 'throw' method");
      }

      return ContinueSentinel;
    }

    var record = tryCatch(method, delegate.iterator, context.arg);

    if (record.type === "throw") {
      context.method = "throw";
      context.arg = record.arg;
      context.delegate = null;
      return ContinueSentinel;
    }

    var info = record.arg;

    if (! info) {
      context.method = "throw";
      context.arg = new TypeError("iterator result is not an object");
      context.delegate = null;
      return ContinueSentinel;
    }

    if (info.done) {
      // Assign the result of the finished delegate to the temporary
      // variable specified by delegate.resultName (see delegateYield).
      context[delegate.resultName] = info.value;

      // Resume execution at the desired location (see delegateYield).
      context.next = delegate.nextLoc;

      // If context.method was "throw" but the delegate handled the
      // exception, let the outer generator proceed normally. If
      // context.method was "next", forget context.arg since it has been
      // "consumed" by the delegate iterator. If context.method was
      // "return", allow the original .return call to continue in the
      // outer generator.
      if (context.method !== "return") {
        context.method = "next";
        context.arg = undefined$1;
      }

    } else {
      // Re-yield the result returned by the delegate method.
      return info;
    }

    // The delegate iterator is finished, so forget it and continue with
    // the outer generator.
    context.delegate = null;
    return ContinueSentinel;
  }

  // Define Generator.prototype.{next,throw,return} in terms of the
  // unified ._invoke helper method.
  defineIteratorMethods(Gp);

  define(Gp, toStringTagSymbol, "Generator");

  // A Generator should always return itself as the iterator object when the
  // @@iterator function is called on it. Some browsers' implementations of the
  // iterator prototype chain incorrectly implement this, causing the Generator
  // object to not be returned from this call. This ensures that doesn't happen.
  // See https://github.com/facebook/regenerator/issues/274 for more details.
  Gp[iteratorSymbol] = function() {
    return this;
  };

  Gp.toString = function() {
    return "[object Generator]";
  };

  function pushTryEntry(locs) {
    var entry = { tryLoc: locs[0] };

    if (1 in locs) {
      entry.catchLoc = locs[1];
    }

    if (2 in locs) {
      entry.finallyLoc = locs[2];
      entry.afterLoc = locs[3];
    }

    this.tryEntries.push(entry);
  }

  function resetTryEntry(entry) {
    var record = entry.completion || {};
    record.type = "normal";
    delete record.arg;
    entry.completion = record;
  }

  function Context(tryLocsList) {
    // The root entry object (effectively a try statement without a catch
    // or a finally block) gives us a place to store values thrown from
    // locations where there is no enclosing try statement.
    this.tryEntries = [{ tryLoc: "root" }];
    tryLocsList.forEach(pushTryEntry, this);
    this.reset(true);
  }

  exports.keys = function(object) {
    var keys = [];
    for (var key in object) {
      keys.push(key);
    }
    keys.reverse();

    // Rather than returning an object with a next method, we keep
    // things simple and return the next function itself.
    return function next() {
      while (keys.length) {
        var key = keys.pop();
        if (key in object) {
          next.value = key;
          next.done = false;
          return next;
        }
      }

      // To avoid creating an additional object, we just hang the .value
      // and .done properties off the next function object itself. This
      // also ensures that the minifier will not anonymize the function.
      next.done = true;
      return next;
    };
  };

  function values(iterable) {
    if (iterable) {
      var iteratorMethod = iterable[iteratorSymbol];
      if (iteratorMethod) {
        return iteratorMethod.call(iterable);
      }

      if (typeof iterable.next === "function") {
        return iterable;
      }

      if (!isNaN(iterable.length)) {
        var i = -1, next = function next() {
          while (++i < iterable.length) {
            if (hasOwn.call(iterable, i)) {
              next.value = iterable[i];
              next.done = false;
              return next;
            }
          }

          next.value = undefined$1;
          next.done = true;

          return next;
        };

        return next.next = next;
      }
    }

    // Return an iterator with no values.
    return { next: doneResult };
  }
  exports.values = values;

  function doneResult() {
    return { value: undefined$1, done: true };
  }

  Context.prototype = {
    constructor: Context,

    reset: function(skipTempReset) {
      this.prev = 0;
      this.next = 0;
      // Resetting context._sent for legacy support of Babel's
      // function.sent implementation.
      this.sent = this._sent = undefined$1;
      this.done = false;
      this.delegate = null;

      this.method = "next";
      this.arg = undefined$1;

      this.tryEntries.forEach(resetTryEntry);

      if (!skipTempReset) {
        for (var name in this) {
          // Not sure about the optimal order of these conditions:
          if (name.charAt(0) === "t" &&
              hasOwn.call(this, name) &&
              !isNaN(+name.slice(1))) {
            this[name] = undefined$1;
          }
        }
      }
    },

    stop: function() {
      this.done = true;

      var rootEntry = this.tryEntries[0];
      var rootRecord = rootEntry.completion;
      if (rootRecord.type === "throw") {
        throw rootRecord.arg;
      }

      return this.rval;
    },

    dispatchException: function(exception) {
      if (this.done) {
        throw exception;
      }

      var context = this;
      function handle(loc, caught) {
        record.type = "throw";
        record.arg = exception;
        context.next = loc;

        if (caught) {
          // If the dispatched exception was caught by a catch block,
          // then let that catch block handle the exception normally.
          context.method = "next";
          context.arg = undefined$1;
        }

        return !! caught;
      }

      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        var record = entry.completion;

        if (entry.tryLoc === "root") {
          // Exception thrown outside of any try block that could handle
          // it, so set the completion value of the entire function to
          // throw the exception.
          return handle("end");
        }

        if (entry.tryLoc <= this.prev) {
          var hasCatch = hasOwn.call(entry, "catchLoc");
          var hasFinally = hasOwn.call(entry, "finallyLoc");

          if (hasCatch && hasFinally) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            } else if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else if (hasCatch) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            }

          } else if (hasFinally) {
            if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else {
            throw new Error("try statement without catch or finally");
          }
        }
      }
    },

    abrupt: function(type, arg) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc <= this.prev &&
            hasOwn.call(entry, "finallyLoc") &&
            this.prev < entry.finallyLoc) {
          var finallyEntry = entry;
          break;
        }
      }

      if (finallyEntry &&
          (type === "break" ||
           type === "continue") &&
          finallyEntry.tryLoc <= arg &&
          arg <= finallyEntry.finallyLoc) {
        // Ignore the finally entry if control is not jumping to a
        // location outside the try/catch block.
        finallyEntry = null;
      }

      var record = finallyEntry ? finallyEntry.completion : {};
      record.type = type;
      record.arg = arg;

      if (finallyEntry) {
        this.method = "next";
        this.next = finallyEntry.finallyLoc;
        return ContinueSentinel;
      }

      return this.complete(record);
    },

    complete: function(record, afterLoc) {
      if (record.type === "throw") {
        throw record.arg;
      }

      if (record.type === "break" ||
          record.type === "continue") {
        this.next = record.arg;
      } else if (record.type === "return") {
        this.rval = this.arg = record.arg;
        this.method = "return";
        this.next = "end";
      } else if (record.type === "normal" && afterLoc) {
        this.next = afterLoc;
      }

      return ContinueSentinel;
    },

    finish: function(finallyLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.finallyLoc === finallyLoc) {
          this.complete(entry.completion, entry.afterLoc);
          resetTryEntry(entry);
          return ContinueSentinel;
        }
      }
    },

    "catch": function(tryLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc === tryLoc) {
          var record = entry.completion;
          if (record.type === "throw") {
            var thrown = record.arg;
            resetTryEntry(entry);
          }
          return thrown;
        }
      }

      // The context.catch method must only be called with a location
      // argument that corresponds to a known catch block.
      throw new Error("illegal catch attempt");
    },

    delegateYield: function(iterable, resultName, nextLoc) {
      this.delegate = {
        iterator: values(iterable),
        resultName: resultName,
        nextLoc: nextLoc
      };

      if (this.method === "next") {
        // Deliberately forget the last sent value so that we don't
        // accidentally pass it on to the delegate.
        this.arg = undefined$1;
      }

      return ContinueSentinel;
    }
  };

  // Regardless of whether this script is executing as a CommonJS module
  // or not, return the runtime object so that we can declare the variable
  // regeneratorRuntime in the outer scope, which allows this module to be
  // injected easily by `bin/regenerator --include-runtime script.js`.
  return exports;

}(
  // If this script is executing as a CommonJS module, use module.exports
  // as the regeneratorRuntime namespace. Otherwise create a new empty
  // object. Either way, the resulting object will be used to initialize
  // the regeneratorRuntime variable at the top of this file.
   module.exports 
));

try {
  regeneratorRuntime = runtime;
} catch (accidentalStrictMode) {
  // This module should not be running in strict mode, so the above
  // assignment should always work unless something is misconfigured. Just
  // in case runtime.js accidentally runs in strict mode, we can escape
  // strict mode using a global Function call. This could conceivably fail
  // if a Content Security Policy forbids using Function, but in that case
  // the proper solution is to fix the accidental strict mode problem. If
  // you've misconfigured your bundler to force strict mode and applied a
  // CSP to forbid Function, and you're not willing to fix either of those
  // problems, please detail your unique predicament in a GitHub issue.
  Function("r", "regeneratorRuntime = r")(runtime);
}
});

var PreloadImg = /*#__PURE__*/function () {
  function PreloadImg(listOfFolders, bucket, firebase) {
    var _this = this;

    this.img = {};
    this.loadedDestination = [];

    this.getLinkFromConfig = function (config) {
      var _config$thumbnails, _config$thumbnails$im;

      return config == null ? void 0 : (_config$thumbnails = config.thumbnails) == null ? void 0 : (_config$thumbnails$im = _config$thumbnails.img) == null ? void 0 : _config$thumbnails$im.path;
    };

    this.getImage = function (path) {
      if (!path) return;
      if (!_this.img[path]) void _this.loadImage(path);
      return _this.img[path];
    };

    this.startPreloadImage = /*#__PURE__*/function () {
      var _ref = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee(config, destination) {
        var link;
        return runtime_1.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.prev = 0;
                link = _this.getLinkFromConfig(config);

                if (!(!link || _this.img[link])) {
                  _context.next = 4;
                  break;
                }

                return _context.abrupt("return");

              case 4:
                _context.next = 6;
                return _this.loadImage(link);

              case 6:
                _this.loadedDestination = [].concat(_this.loadedDestination, [destination]);
                _context.next = 12;
                break;

              case 9:
                _context.prev = 9;
                _context.t0 = _context["catch"](0);
                _this.loadedDestination = [].concat(_this.loadedDestination);

              case 12:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, null, [[0, 9]]);
      }));

      return function (_x, _x2) {
        return _ref.apply(this, arguments);
      };
    }();

    this.storage = getStorage(firebase);
    var listOfPathToImages = listOfFolders.map( /*#__PURE__*/function () {
      var _ref2 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee2(folder) {
        var listRef, _yield$listAll, items;

        return runtime_1.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                listRef = ref(_this.storage, bucket + "/" + folder);
                _context2.next = 3;
                return listAll(listRef);

              case 3:
                _yield$listAll = _context2.sent;
                items = _yield$listAll.items;
                return _context2.abrupt("return", items.map(function (item) {
                  return item.fullPath;
                }));

              case 6:
              case "end":
                return _context2.stop();
            }
          }
        }, _callee2);
      }));

      return function (_x3) {
        return _ref2.apply(this, arguments);
      };
    }());
    Promise.all(listOfPathToImages).then(function (res) {
      var flattedList = res.flat();
      flattedList.map(function (link) {
        return _this.loadImage(link);
      });
    });
    makeAutoObservable(this);
  }

  var _proto = PreloadImg.prototype;

  _proto.loadImage = /*#__PURE__*/function () {
    var _loadImage = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee3(path) {
      var _res, url, res, loading;

      return runtime_1.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              _context3.prev = 0;

              if (!(!path || this.img[path])) {
                _context3.next = 3;
                break;
              }

              return _context3.abrupt("return");

            case 3:
              _context3.next = 5;
              return getDownloadURL(ref(this.storage, path));

            case 5:
              url = _context3.sent;

              if (!path.includes('.json')) {
                _context3.next = 12;
                break;
              }

              _context3.next = 9;
              return axios.get(url);

            case 9:
              res = _context3.sent;
              _context3.next = 14;
              break;

            case 12:
              loading = new Image();
              loading.src = url;

            case 14:
              this.img[path] = ((_res = res) == null ? void 0 : _res.data) || url;
              _context3.next = 20;
              break;

            case 17:
              _context3.prev = 17;
              _context3.t0 = _context3["catch"](0);
              this.img[path] = {};

            case 20:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3, this, [[0, 17]]);
    }));

    function loadImage(_x4) {
      return _loadImage.apply(this, arguments);
    }

    return loadImage;
  }();

  return PreloadImg;
}();

var LocalStorageService = /*#__PURE__*/function () {
  function LocalStorageService() {}

  var _proto = LocalStorageService.prototype;

  _proto.getItem = function getItem(name) {
    return localStorage.getItem(name);
  };

  _proto.setItem = function setItem(name, value) {
    localStorage.setItem(name, value);
    window.dispatchEvent(createUpdateStorageCustomEvent(value, name));
  };

  _proto.intitWatchVP = function intitWatchVP(watchingLocalStoradgeKey) {
    return function (watchers) {
      window.addEventListener(UPDATE_STORAGE_EVENT, function (e) {
        if (watchingLocalStoradgeKey === e.detail.keyEvent) {
          watchers.forEach(function (watcher) {
            return watcher(e.detail.value);
          });
        }
      });
    };
  };

  _proto.getLocalStorageData = function getLocalStorageData(keys) {
    var storageData = keys.reduce(function (data, key) {
      try {
        var value = localStorage.getItem(key);
        data[key] = JSON.parse(value);
      } catch (_unused) {
        data[key] = localStorage.getItem(key);
      }

      return data;
    }, {});
    return storageData;
  };

  return LocalStorageService;
}();

var localStorageService = /*#__PURE__*/new LocalStorageService();

function evaluateExpressionTree(tree) {
  // #TODO here we able extend or logic for transpile string logical expression to real one

  /* tslint:disable triple-equals*/
  if (tree.type == 'Literal') {
    return tree.value;
    /* tslint:disable triple-equals*/
  } else if (tree.type == 'LogicalExpression') {
    /* tslint:disable triple-equals*/
    if (tree.operator == '&&') {
      return evaluateExpressionTree(tree.left) && evaluateExpressionTree(tree.right);
    } else {
      return evaluateExpressionTree(tree.left) || evaluateExpressionTree(tree.right);
    }
    /* tslint:disable triple-equals*/

  } else if (tree.type == 'BinaryExpression') {
    /* tslint:disable triple-equals*/
    if (tree.operator == '==') {
      /* tslint:disable triple-equals*/
      return evaluateExpressionTree(tree.left) == evaluateExpressionTree(tree.right);
    }
  } else {
    // Unexpected node parsed
    return null;
  }
}

//#TODO move destination service to library, because this is very sensetive logic.
var DestinationService = function DestinationService(parser) {
  var _this = this;

  this.parser = function (params) {
    return params;
  };

  this.isExpressionHasLogicalOperators = function (expression) {
    return /&&|<=|>=|<|>|!=|==|&|!|\|{1,2}/gi.test(expression);
  };

  this.parse = function (_ref) {
    var destination = _ref.destination;

    var parsedString = _this.parser(destination);

    if (!_this.isExpressionHasLogicalOperators(parsedString)) return destination;
    return evaluateExpressionTree(jsep(parsedString)) || destination;
  };

  if (parser) this.parser = parser;
};

var storageListener = function storageListener(action) {
  window.addEventListener(UPDATE_STORAGE_EVENT, function (e) {
    var _e$detail, _e$detail2;

    action({
      key: e == null ? void 0 : (_e$detail = e.detail) == null ? void 0 : _e$detail.keyEvent,
      value: e == null ? void 0 : (_e$detail2 = e.detail) == null ? void 0 : _e$detail2.value
    });
  });
};

var versionWatcher = function versionWatcher(version, cb) {
  var currentVersion = localStorage.getItem('_v');

  if (!currentVersion || version != currentVersion) {
    localStorage.clear();
    localStorage.setItem('_v', version);
    cb();
  }
};

var MAX_YEARS = 121;
var MAX_DAYS_IN_MONTH = 31;
var FEBRUARY_MONTH_FORMAT = '2';
var lastDays = {
  '29': true,
  '30': true,
  '31': true
};

var getDays = function getDays(days) {
  if (days === void 0) {
    days = MAX_DAYS_IN_MONTH;
  }

  return new Array(days).fill(true).map(function (_, i) {
    return {
      value: i + 1,
      displayValue: i + 1
    };
  });
};

var getMonths = function getMonths() {
  return moment.months().map(function (month, i) {
    return {
      value: i + 1,
      displayValue: month
    };
  });
};

var getYears = function getYears() {
  var year = moment().year() - 1;
  return new Array(MAX_YEARS).fill(true).reduce(function (arr, _, i) {
    var value = year - i;
    arr.push({
      value: value,
      displayValue: value
    });
    return arr;
  }, []);
};

var getDefaultDataConfig = function getDefaultDataConfig() {
  return {
    months: getMonths(),
    years: getYears(),
    defaultDays: getDays()
  };
};
var getDaysInMonth = function getDaysInMonth(month, year) {
  return !year ? getDays(moment(month).daysInMonth()) : getDays(moment(year + "-" + month, 'YYYY-MM').daysInMonth());
};
var getCorrectFebruaryDay = function getCorrectFebruaryDay(day, year) {
  // @ts-ignore
  var fabDay = lastDays[day] ? getDaysInMonth(FEBRUARY_MONTH_FORMAT, year).length : day;
  return {
    value: fabDay,
    displayValue: fabDay
  };
};
var parseTimestemp = function parseTimestemp(timestemp) {
  var _moment$format$split = moment(timestemp).format("L").split('/'),
      m = _moment$format$split[0],
      d = _moment$format$split[1],
      y = _moment$format$split[2];

  return {
    day: Number(d).toString(),
    month: Number(m).toString(),
    year: Number(y).toString()
  };
};
var parseTimestempHours = function parseTimestempHours(timestemp) {
  var _moment$format$split2 = moment(timestemp).format('MM/DD/YYYY hh:mm A').split(' '),
      hours = _moment$format$split2[1],
      time = _moment$format$split2[2];

  return {
    hours: hours && Number(hours.split(':')[0]).toString(),
    minutes: hours && Number(hours.split(':')[1]).toString(),
    time: time
  };
};
var paresHoursToTimestempWithDate = function paresHoursToTimestempWithDate(_ref) {
  var dateOfBirth = _ref.dateOfBirth,
      hours = _ref.hours,
      minutes = _ref.minutes,
      time = _ref.time;
  return moment(moment(dateOfBirth).format('L') + " " + hours + ":" + minutes + " " + time, "MM/DD/YYYY HH:mm A").format('x');
};
var parseHoursToTimestemp = function parseHoursToTimestemp(_ref2) {
  var hours = _ref2.hours,
      minutes = _ref2.minutes,
      time = _ref2.time;
  return moment(hours + ":" + minutes + " " + time, 'HH:mm A').format('x');
};

var useDateOfBirth = function useDateOfBirth(date, onDateChanged) {
  var _getDefaultDataConfig = getDefaultDataConfig(),
      months = _getDefaultDataConfig.months,
      years = _getDefaultDataConfig.years,
      defaultDays = _getDefaultDataConfig.defaultDays;

  var _useState = useState(defaultDays),
      days = _useState[0],
      setDays = _useState[1];

  var _useState2 = useState(),
      day = _useState2[0],
      setDay = _useState2[1];

  var _useState3 = useState(),
      month = _useState3[0],
      setMonth = _useState3[1];

  var _useState4 = useState(),
      year = _useState4[0],
      setYear = _useState4[1];

  var handleChooseDay = function handleChooseDay(e) {
    var value = days.find(function (_ref) {
      var value = _ref.value;
      return value.toString() === e.target.value;
    });
    setDay(value);
  };

  var handleChooseMonth = function handleChooseMonth(_ref2) {
    var val = _ref2.target.value;
    var value = months.find(function (_ref3) {
      var value = _ref3.value;
      return value.toString() === val;
    });
    setMonth(value);
    var newDays = getDaysInMonth(val, year == null ? void 0 : year.value);

    if (newDays.length !== days.length) {
      setDays(newDays);

      if (val === FEBRUARY_MONTH_FORMAT && day) {
        var febDay = getCorrectFebruaryDay(day.value, year == null ? void 0 : year.value);
        setDay(febDay);
      }
    }
  };

  var handleChooseYear = function handleChooseYear(_ref4) {
    var val = _ref4.target.value;
    var value = years.find(function (_ref5) {
      var value = _ref5.value;
      return value.toString() === val;
    });

    if ((month == null ? void 0 : month.value.toString()) === FEBRUARY_MONTH_FORMAT) {
      var newDays = getDaysInMonth(FEBRUARY_MONTH_FORMAT, val);

      if (newDays.length !== days.length) {
        setDays(newDays);

        if (day && newDays.length < day.value) {
          setDay(newDays[newDays.length - 1]);
        }
      }
    }

    setYear(value);
  };

  useEffect(function () {
    if (date) {
      var _parseTimestemp = parseTimestemp(date),
          _day = _parseTimestemp.day,
          _month = _parseTimestemp.month,
          _year = _parseTimestemp.year;

      setDay({
        value: _day,
        displayValue: _day
      });
      setMonth({
        value: _month,
        displayValue: _month
      });
      setYear({
        value: _year,
        displayValue: _year
      });
    }
  }, []);
  useEffect(function () {
    if (!day || !month || !year) {
      onDateChanged(null);
      return;
    }

    var unixDate = moment.utc((month == null ? void 0 : month.value) + "/" + (day == null ? void 0 : day.value) + "/" + (year == null ? void 0 : year.value));

    if (onDateChanged) {
      onDateChanged(Number(unixDate));
    }
  }, [year, day, month]);
  return {
    year: year,
    month: month,
    day: day,
    years: years,
    months: months,
    days: days,
    handleChooseDay: handleChooseDay,
    handleChooseMonth: handleChooseMonth,
    handleChooseYear: handleChooseYear
  };
};

var useStyles$m = /*#__PURE__*/createUseStyles({
  selectItem: {
    marginBottom: 12
  }
});

var DateOfBirth = function DateOfBirth(_ref) {
  var date = _ref.date,
      onDateChanged = _ref.onDateChanged,
      rootClass = _ref.rootClass,
      itemClass = _ref.itemClass,
      monthIptProps = _ref.monthIptProps,
      dayIptProps = _ref.dayIptProps,
      yearIptProps = _ref.yearIptProps;

  var _useStyles = useStyles$m(),
      selectItem = _useStyles.selectItem;

  var _useDateOfBirth = useDateOfBirth(date, onDateChanged),
      months = _useDateOfBirth.months,
      years = _useDateOfBirth.years,
      days = _useDateOfBirth.days,
      day = _useDateOfBirth.day,
      year = _useDateOfBirth.year,
      month = _useDateOfBirth.month,
      handleChooseDay = _useDateOfBirth.handleChooseDay,
      handleChooseMonth = _useDateOfBirth.handleChooseMonth,
      handleChooseYear = _useDateOfBirth.handleChooseYear;

  var selectItemClass = selectItem + " " + (itemClass || '');
  return React.createElement("div", {
    className: rootClass || ''
  }, React.createElement(Select, Object.assign({
    rootClassName: selectItemClass,
    onChange: handleChooseMonth,
    value: month,
    placeholder: "Month",
    options: months
  }, monthIptProps)), React.createElement(Select, Object.assign({
    rootClassName: selectItemClass,
    onChange: handleChooseDay,
    value: day,
    placeholder: "Day",
    options: days
  }, dayIptProps)), React.createElement(Select, Object.assign({
    rootClassName: selectItemClass,
    onChange: handleChooseYear,
    value: year,
    placeholder: "Year",
    options: years
  }, yearIptProps)));
};

var useTimeOfBirth = function useTimeOfBirth(_ref) {
  var onTimeChanged = _ref.onTimeChanged,
      dateOfBirth = _ref.dateOfBirth;

  var _useState = useState(''),
      hours = _useState[0],
      setHours = _useState[1];

  var _useState2 = useState(''),
      minutes = _useState2[0],
      setMinutes = _useState2[1];

  var _useState3 = useState(''),
      time = _useState3[0],
      setTime = _useState3[1];

  var _useState4 = useState({
    hours: true,
    minutes: true
  }),
      error = _useState4[0],
      setError = _useState4[1];

  var handleChangeHours = function handleChangeHours(_ref2) {
    var value = _ref2.target.value;
    setHours(value);
  };

  var handleChangeMinutes = function handleChangeMinutes(_ref3) {
    var value = _ref3.target.value;
    setMinutes(value);
  };

  var choosePmTime = function choosePmTime() {
    var newTime = time === PM_TIME ? '' : PM_TIME;
    setTime(newTime);
  };

  var chooseAmTime = function chooseAmTime() {
    var newTime = time === AM_TIME ? '' : AM_TIME;
    setTime(newTime);
  };

  var handleMinuteError = function handleMinuteError(err) {
    setError(_extends({}, error, {
      minutes: err
    }));
  };

  var handleHoursError = function handleHoursError(err) {
    setError(_extends({}, error, {
      hours: err
    }));
  };

  useEffect(function () {
    if (dateOfBirth) {
      var _parseTimestempHours = parseTimestempHours(dateOfBirth),
          _hours = _parseTimestempHours.hours,
          _minutes = _parseTimestempHours.minutes,
          _time = _parseTimestempHours.time;

      console.log(_time);
      var isHours = _hours !== undefined;
      var isMinutes = _minutes !== undefined;

      if (isHours) {
        setHours(_hours);
      }

      if (isMinutes) {
        setMinutes(_minutes);
      }

      setError({
        hours: !isHours,
        minutes: !isMinutes
      });

      if (_time) {
        setTime(_time);
      }
    }
  }, []);
  useEffect(function () {
    var isError = Object.values(error).some(function (err) {
      return err;
    });
    var isInvalid = isError || !hours || !minutes || !time;

    if (isInvalid) {
      onTimeChanged(null);
      return;
    }

    var timestemp = dateOfBirth ? paresHoursToTimestempWithDate({
      dateOfBirth: dateOfBirth,
      hours: hours,
      minutes: minutes,
      time: time
    }) : parseHoursToTimestemp({
      hours: hours,
      minutes: minutes,
      time: time
    });
    onTimeChanged(Number(timestemp));
  }, [hours, minutes, time]);
  return {
    handleChangeHours: handleChangeHours,
    handleChangeMinutes: handleChangeMinutes,
    choosePmTime: choosePmTime,
    chooseAmTime: chooseAmTime,
    hours: hours,
    minutes: minutes,
    time: time,
    handleMinuteError: handleMinuteError,
    handleHoursError: handleHoursError
  };
};

var useStyles$n = /*#__PURE__*/createUseStyles({
  wrapper: {
    display: 'flex'
  },
  inputFirst: {
    marginRight: 8
  },
  buttonRoot: {
    padding: 0,
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    minWidth: 60,
    height: 48,
    marginLeft: 8
  }
});

var PM_TIME = 'PM';
var AM_TIME = 'AM';
var TimeOfBirth = function TimeOfBirth(_ref) {
  var inputClass = _ref.inputClass,
      buttonClass = _ref.buttonClass,
      hoursIptProps = _ref.hoursIptProps,
      minutesIptProps = _ref.minutesIptProps,
      amBtnProps = _ref.amBtnProps,
      pmBtnProps = _ref.pmBtnProps,
      props = _objectWithoutPropertiesLoose(_ref, ["inputClass", "buttonClass", "hoursIptProps", "minutesIptProps", "amBtnProps", "pmBtnProps"]);

  var _useStyles = useStyles$n(),
      wrapper = _useStyles.wrapper,
      buttonRoot = _useStyles.buttonRoot,
      inputFirst = _useStyles.inputFirst;

  var _useTimeOfBirth = useTimeOfBirth(props),
      handleChangeHours = _useTimeOfBirth.handleChangeHours,
      handleChangeMinutes = _useTimeOfBirth.handleChangeMinutes,
      choosePmTime = _useTimeOfBirth.choosePmTime,
      chooseAmTime = _useTimeOfBirth.chooseAmTime,
      handleMinuteError = _useTimeOfBirth.handleMinuteError,
      handleHoursError = _useTimeOfBirth.handleHoursError,
      hours = _useTimeOfBirth.hours,
      minutes = _useTimeOfBirth.minutes,
      time = _useTimeOfBirth.time;

  var buttonRootClass = buttonRoot + " " + (buttonClass || '');
  return React.createElement("div", {
    className: wrapper
  }, React.createElement(ValidatedInput, Object.assign({
    label: "HH",
    rootClassName: inputFirst + " " + (inputClass || ''),
    maxLength: 2,
    onError: handleHoursError,
    validationQuery: {
      type: {
        value: "number",
        moreThen: {
          value: 0,
          errorMessage: 'Incorrect time'
        },
        lessThen: {
          value: 13,
          errorMessage: 'Incorrect time'
        }
      }
    },
    onChange: handleChangeHours,
    value: hours
  }, hoursIptProps)), React.createElement(ValidatedInput, Object.assign({
    label: "MM",
    onError: handleMinuteError,
    rootClassName: inputClass || '',
    maxLength: 2,
    validationQuery: {
      type: {
        value: "number",
        moreThen: {
          value: -1,
          errorMessage: 'Incorrect time'
        },
        lessThen: {
          value: 60,
          errorMessage: 'Incorrect time'
        }
      }
    },
    onChange: handleChangeMinutes,
    value: minutes
  }, minutesIptProps)), React.createElement(SelectButton, Object.assign({
    selected: time === AM_TIME,
    onClick: chooseAmTime,
    className: buttonRootClass,
    label: AM_TIME
  }, amBtnProps)), React.createElement(SelectButton, Object.assign({
    selected: time === PM_TIME,
    onClick: choosePmTime,
    className: buttonRootClass,
    label: PM_TIME
  }, pmBtnProps)));
};

var img$c = "data:image/svg+xml,%3csvg width='40' height='26' viewBox='0 0 40 26' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3crect x='0.571289' y='0.50708' width='38.2857' height='24' rx='3.5' fill='white' stroke='%23C7C7C7'/%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M12.5123 16.6824H10.0603L8.22151 10.3638C8.13424 10.0731 7.94893 9.81616 7.67634 9.69505C6.99608 9.3907 6.24647 9.14849 5.42871 9.02633V8.78306H9.37881C9.92398 8.78306 10.3329 9.14849 10.401 9.57289L11.3551 14.1307L13.8059 8.78306H16.1899L12.5123 16.6824ZM17.5528 16.6824H15.2371L17.144 8.78306H19.4597L17.5528 16.6824ZM22.4557 10.9714C22.5238 10.5459 22.9327 10.3026 23.4098 10.3026C24.1594 10.2416 24.9759 10.3637 25.6574 10.667L26.0663 8.96626C25.3848 8.72299 24.6352 8.60083 23.9549 8.60083C21.7073 8.60083 20.0718 9.695 20.0718 11.2136C20.0718 12.3688 21.2303 12.9754 22.048 13.3408C22.9327 13.7052 23.2735 13.9485 23.2053 14.3129C23.2053 14.8594 22.5238 15.1027 21.8436 15.1027C21.0258 15.1027 20.2081 14.9205 19.4597 14.6162L19.0508 16.318C19.8685 16.6213 20.7532 16.7434 21.571 16.7434C24.0912 16.8034 25.6574 15.7103 25.6574 14.0696C25.6574 12.0034 22.4557 11.8823 22.4557 10.9714ZM33.7621 16.6824L31.9233 8.78306H29.9483C29.5394 8.78306 29.1305 9.02633 28.9942 9.3907L25.5893 16.6824H27.9732L28.449 15.5282H31.3781L31.6507 16.6824H33.7621ZM30.289 10.9106L30.9693 13.8877H29.0624L30.289 10.9106Z' fill='%23172B85'/%3e%3c/svg%3e";

var img$d = "data:image/svg+xml,%3csvg width='40' height='26' viewBox='0 0 40 26' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3crect x='0.857422' y='0.50708' width='38.2857' height='24' rx='3.5' fill='white' stroke='%23C7C7C7'/%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M24.6198 19.2054C28.5208 19.2054 31.6831 16.0807 31.6831 12.2262C31.6831 8.37175 28.5208 5.24707 24.6198 5.24707C22.8715 5.24707 21.2715 5.87473 20.0381 6.91445C18.8048 5.87492 17.2049 5.24738 15.4568 5.24738C11.5559 5.24738 8.39355 8.37206 8.39355 12.2266C8.39355 16.081 11.5559 19.2057 15.4568 19.2057C17.2051 19.2057 18.8051 18.5781 20.0385 17.5383C21.2719 18.5779 22.8717 19.2054 24.6198 19.2054Z' fill='%23ED0006'/%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M20.0381 17.538C21.5568 16.2579 22.5198 14.353 22.5198 12.226C22.5198 10.0989 21.5568 8.19413 20.0381 6.91402C21.2715 5.87441 22.8714 5.24683 24.6196 5.24683C28.5205 5.24683 31.6828 8.37151 31.6828 12.226C31.6828 16.0805 28.5205 19.2052 24.6196 19.2052C22.8714 19.2052 21.2715 18.5776 20.0381 17.538Z' fill='%23F9A000'/%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M20.0383 17.5382C21.557 16.258 22.52 14.3533 22.52 12.2262C22.52 10.0992 21.557 8.19441 20.0383 6.91431C18.5196 8.19441 17.5566 10.0992 17.5566 12.2262C17.5566 14.3533 18.5196 16.258 20.0383 17.5382Z' fill='%23FF5E00'/%3e%3c/svg%3e";

var img$e = "data:image/svg+xml,%3csvg width='40' height='26' viewBox='0 0 40 26' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3crect x='1.14258' y='0.50708' width='38.2857' height='24' rx='3.5' fill='%231F72CD' stroke='%23C7C7C7'/%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M9.31366 8.86157L6 16.4103H9.96691L10.4587 15.2067H11.5828L12.0746 16.4103H16.441V15.4917L16.8301 16.4103H19.0888L19.4779 15.4722V16.4103H28.5589L29.6631 15.2379L30.6971 16.4103L35.3613 16.42L32.0371 12.657L35.3613 8.86157H30.7694L29.6945 10.0122L28.6931 8.86157H18.8141L17.9658 10.81L17.0976 8.86157H13.139V9.74892L12.6986 8.86157H9.31366ZM10.0812 9.93314H12.0149L14.2128 15.0519V9.93314H16.3311L18.0287 13.6033L19.5933 9.93314H21.701V15.3498H20.4185L20.408 11.1053L18.5383 15.3498H17.3911L15.5109 11.1053V15.3498H12.8726L12.3724 14.1355H9.67018L9.17103 15.3488H7.75745L10.0812 9.93314ZM28.0891 9.93314H22.8743V15.3466H28.0084L29.6631 13.5525L31.2581 15.3466H32.9254L30.502 12.6556L32.9254 9.93314H31.3304L29.6841 11.7067L28.0891 9.93314ZM11.0218 10.8504L10.1315 13.0137H11.911L11.0218 10.8504ZM24.1622 12.0433V11.0545V11.0536H27.416L28.8358 12.6349L27.3531 14.2249H24.1622V13.1454H27.0071V12.0433H24.1622Z' fill='white'/%3e%3c/svg%3e";

var img$f = "data:image/svg+xml,%3csvg width='40' height='25' viewBox='0 0 40 25' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3crect x='0.927734' y='0.5' width='38.2857' height='24' rx='3.5' fill='white' stroke='%23C7C7C7'/%3e%3cpath d='M21.7056 14.5831C23.1438 14.5831 24.3097 13.4173 24.3097 11.9791C24.3097 10.5409 23.1438 9.375 21.7056 9.375C20.2674 9.375 19.1016 10.5409 19.1016 11.9791C19.1016 13.4173 20.2674 14.5831 21.7056 14.5831Z' fill='%23F26E21'/%3e%3cpath d='M7.68056 13.2265C7.37371 13.5012 6.97776 13.6203 6.34895 13.6203H6.08805V10.3509H6.34895C6.97767 10.3509 7.35801 10.4622 7.68056 10.7509C8.0168 11.0475 8.21741 11.5066 8.21741 11.981C8.21741 12.4556 8.0168 12.9309 7.68056 13.2265ZM6.54397 9.51367H5.11523V14.4568H6.53679C7.2912 14.4568 7.83649 14.2799 8.31496 13.8862C8.88246 13.4194 9.21937 12.7153 9.21937 11.9875C9.21929 10.5281 8.11994 9.51367 6.54397 9.51367Z' fill='%230B161F'/%3e%3cpath d='M9.66602 14.4568H10.6373V9.51367H9.66602V14.4568Z' fill='%230B161F'/%3e%3cpath d='M13.0165 11.4102C12.4328 11.1954 12.2609 11.0542 12.2609 10.7886C12.2609 10.477 12.5668 10.2398 12.9859 10.2398C13.2775 10.2398 13.5162 10.3583 13.7715 10.6392L14.2787 9.98043C13.8607 9.61672 13.36 9.43164 12.8138 9.43164C11.9325 9.43164 11.2593 10.0395 11.2593 10.8463C11.2593 11.5292 11.5728 11.8773 12.4853 12.2042C12.8665 12.337 13.0603 12.4254 13.1578 12.4857C13.3519 12.612 13.4497 12.7891 13.4497 12.9967C13.4497 13.3976 13.1281 13.6935 12.694 13.6935C12.2306 13.6935 11.8572 13.4642 11.6327 13.0342L11.0059 13.6351C11.4533 14.2863 11.9915 14.5766 12.7321 14.5766C13.7408 14.5766 14.4505 13.9085 14.4505 12.9529C14.451 12.1667 14.1228 11.8108 13.0165 11.4102Z' fill='%230B161F'/%3e%3cpath d='M14.7578 11.9872C14.7578 13.4416 15.9091 14.5682 17.3891 14.5682C17.8079 14.5682 18.166 14.486 18.6076 14.2797V13.1444C18.2185 13.5304 17.8744 13.6857 17.4335 13.6857C16.4544 13.6857 15.7591 12.9813 15.7591 11.9804C15.7591 11.032 16.4766 10.2829 17.3891 10.2829C17.8516 10.2829 18.2035 10.4457 18.6076 10.8389V9.70445C18.1819 9.49006 17.8298 9.40161 17.411 9.40161C15.939 9.40195 14.7578 10.551 14.7578 11.9872Z' fill='%230B161F'/%3e%3cpath d='M26.4857 12.8341L25.155 9.51367H24.0938L26.2098 14.5834H26.7322L28.8854 9.51367H27.8313L26.4857 12.8341Z' fill='%230B161F'/%3e%3cpath d='M29.3281 14.4568H32.0856V13.6203H30.2997V12.2847H32.0172V11.4481H30.2997V10.3509H32.0856V9.51367H29.3281V14.4568Z' fill='%230B161F'/%3e%3cpath d='M33.9802 11.789H33.6971V10.2909H33.9955C34.6021 10.2909 34.9311 10.544 34.9311 11.0249C34.9311 11.5212 34.6021 11.789 33.9802 11.789ZM35.9308 10.9725C35.9308 10.0465 35.2887 9.51367 34.1668 9.51367H32.7246V14.4568H33.6968V12.4703H33.8244L35.1687 14.4568H36.3647L34.7944 12.3743C35.528 12.2262 35.9308 11.7291 35.9308 10.9725Z' fill='%230B161F'/%3e%3c/svg%3e";

var img$g = "data:image/svg+xml,%3csvg width='40' height='25' viewBox='0 0 40 25' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3crect x='0.642578' y='0.5' width='38.2857' height='24' rx='3.5' fill='white' stroke='%23C7C7C7'/%3e%3cg clip-path='url(%23clip0_7977_9960)'%3e%3cpath d='M10.0685 16.9911C12.2444 17.0017 14.2306 15.2205 14.2306 13.0535C14.2306 10.684 12.2444 9.0462 10.0685 9.04688H8.19601C5.99408 9.0462 4.18164 10.6844 4.18164 13.0535C4.18164 15.221 5.99408 17.0017 8.19601 16.9911H10.0685Z' fill='%23006095'/%3e%3cpath d='M9.0319 15.1642V10.8614C9.8986 11.1932 10.5139 12.0306 10.5153 13.0127C10.5139 13.995 9.8986 14.8319 9.0319 15.1642ZM5.89628 13.0127C5.89823 12.0311 6.51252 11.1943 7.37873 10.8615V15.1634C6.51252 14.8309 5.89823 13.9945 5.89628 13.0127ZM8.20546 9.37598C6.19341 9.37666 4.56299 11.0042 4.5625 13.0127C4.56299 15.021 6.19341 16.6482 8.20546 16.6488C10.2182 16.6482 11.8489 15.021 11.8492 13.0127C11.8489 11.0042 10.2182 9.37666 8.20546 9.37598Z' fill='white'/%3e%3cpath d='M15.5067 10.7572C15.5067 10.3815 15.3102 10.4061 15.122 10.4021V10.2936C15.2851 10.3015 15.4524 10.3015 15.616 10.3015C15.7917 10.3015 16.0304 10.2936 16.3403 10.2936C17.4243 10.2936 18.0145 11.0161 18.0145 11.756C18.0145 12.1697 17.7719 13.21 16.2899 13.21C16.0765 13.21 15.8795 13.2017 15.6829 13.2017C15.4946 13.2017 15.3102 13.2057 15.122 13.21V13.1013C15.3729 13.0761 15.4946 13.0678 15.5067 12.7837V10.7572ZM15.917 12.7169C15.917 13.0386 16.1475 13.0761 16.3525 13.0761C17.2569 13.0761 17.5539 12.3951 17.5539 11.7725C17.5539 10.9915 17.0515 10.4275 16.2437 10.4275C16.0718 10.4275 15.9927 10.4397 15.917 10.4442V12.7169ZM18.1613 13.1014H18.2408C18.3578 13.1014 18.4416 13.1014 18.4416 12.9632V11.8311C18.4416 11.6474 18.3789 11.6219 18.2238 11.5389V11.4719C18.4206 11.4131 18.6552 11.3341 18.6718 11.3216C18.7012 11.3049 18.7262 11.3004 18.7472 11.3004C18.7679 11.3004 18.7766 11.3256 18.7766 11.3592V12.9632C18.7766 13.1014 18.8687 13.1014 18.986 13.1014H19.057V13.2101C18.9145 13.2101 18.7679 13.2017 18.6176 13.2017C18.4668 13.2017 18.316 13.2058 18.1613 13.2101V13.1014ZM18.6092 10.6572C18.5002 10.6572 18.4041 10.5569 18.4041 10.4482C18.4041 10.3436 18.5047 10.2473 18.6092 10.2473C18.7178 10.2473 18.8143 10.3354 18.8143 10.4482C18.8143 10.5612 18.722 10.6572 18.6092 10.6572ZM19.4547 11.8561C19.4547 11.7016 19.4085 11.66 19.2122 11.5806V11.5012C19.3919 11.4428 19.5634 11.3882 19.7646 11.3004C19.7771 11.3004 19.7893 11.309 19.7893 11.3422V11.6139C20.0283 11.4428 20.2335 11.3004 20.5143 11.3004C20.8699 11.3004 20.9954 11.5595 20.9954 11.8855V12.9632C20.9954 13.1014 21.0874 13.1014 21.2048 13.1014H21.2801V13.2101C21.1333 13.2101 20.9868 13.2017 20.8365 13.2017C20.6856 13.2017 20.5348 13.2058 20.3842 13.2101V13.1014H20.4594C20.5769 13.1014 20.6602 13.1014 20.6602 12.9632V11.8814C20.6602 11.643 20.5143 11.5262 20.2754 11.5262C20.1415 11.5262 19.928 11.6347 19.7893 11.7267V12.9632C19.7893 13.1014 19.882 13.1014 19.9992 13.1014H20.0745V13.2101C19.928 13.2101 19.7812 13.2017 19.6305 13.2017C19.48 13.2017 19.329 13.2058 19.1785 13.2101V13.1014H19.2541C19.3712 13.1014 19.4547 13.1014 19.4547 12.9632V11.8561ZM21.5984 12.0569C21.5898 12.0946 21.5898 12.1571 21.5984 12.2992C21.623 12.696 21.8791 13.0218 22.2135 13.0218C22.4441 13.0218 22.6244 12.8964 22.7789 12.742L22.8374 12.8005C22.6448 13.0555 22.4061 13.2726 22.0632 13.2726C21.3973 13.2726 21.2635 12.6291 21.2635 12.3618C21.2635 11.5428 21.8158 11.3004 22.1087 11.3004C22.4481 11.3004 22.8126 11.5134 22.8163 11.9563C22.8163 11.9817 22.8163 12.0065 22.8126 12.0318L22.7746 12.0569H21.5984ZM22.3395 11.9231C22.4441 11.9231 22.4563 11.8687 22.4563 11.8186C22.4563 11.6056 22.3267 11.4343 22.0921 11.4343C21.8368 11.4343 21.6611 11.6219 21.6109 11.9231H22.3395ZM22.9129 13.1014H23.0259C23.1427 13.1014 23.2265 13.1014 23.2265 12.9632V11.7894C23.2265 11.66 23.0718 11.6347 23.0089 11.6013V11.5389C23.3145 11.4092 23.482 11.3004 23.5203 11.3004C23.5449 11.3004 23.5573 11.3129 23.5573 11.355V11.7309H23.5662C23.6705 11.568 23.8467 11.3004 24.1019 11.3004C24.2066 11.3004 24.3404 11.3714 24.3404 11.5219C24.3404 11.6347 24.261 11.7353 24.1439 11.7353C24.0136 11.7353 24.0136 11.6347 23.8673 11.6347C23.796 11.6347 23.5617 11.7309 23.5617 11.9817V12.9632C23.5617 13.1014 23.6452 13.1014 23.7626 13.1014H23.9969V13.2101C23.7665 13.2058 23.5913 13.2017 23.4111 13.2017C23.2395 13.2017 23.0636 13.2058 22.9129 13.2101V13.1014ZM24.5245 12.6291C24.5791 12.9048 24.7464 13.1389 25.0522 13.1389C25.2988 13.1389 25.3908 12.9885 25.3908 12.8424C25.3908 12.3492 24.4785 12.5079 24.4785 11.8354C24.4785 11.6012 24.6672 11.3004 25.1274 11.3004C25.2612 11.3004 25.4412 11.3382 25.6044 11.4218L25.6339 11.8476H25.5376C25.4957 11.5847 25.3493 11.4342 25.0813 11.4342C24.9136 11.4342 24.7548 11.5303 24.7548 11.7099C24.7548 12.1991 25.726 12.0484 25.726 12.7043C25.726 12.98 25.5041 13.2727 25.0058 13.2727C24.8384 13.2727 24.6416 13.2141 24.4953 13.1307L24.4491 12.6501L24.5245 12.6291ZM29.5061 11.0497H29.4017C29.322 10.5612 28.9745 10.3646 28.5058 10.3646C28.0242 10.3646 27.3249 10.6862 27.3249 11.6889C27.3249 12.5333 27.9282 13.1389 28.5726 13.1389C28.9869 13.1389 29.3305 12.8549 29.4143 12.416L29.5104 12.441L29.4143 13.051C29.2385 13.16 28.7653 13.2726 28.4888 13.2726C27.5095 13.2726 26.8901 12.6417 26.8901 11.7016C26.8901 10.845 27.656 10.2307 28.4765 10.2307C28.8154 10.2307 29.1421 10.3396 29.4643 10.4525L29.5061 11.0497ZM29.6571 13.1014H29.7363C29.8538 13.1014 29.9376 13.1014 29.9376 12.9632V10.6364C29.9376 10.3646 29.8748 10.3562 29.7158 10.3103V10.2435C29.8831 10.1892 30.059 10.114 30.1469 10.0637C30.1926 10.0388 30.2263 10.0176 30.2387 10.0176C30.2641 10.0176 30.2726 10.0429 30.2726 10.0764V12.9632C30.2726 13.1014 30.3646 13.1014 30.4819 13.1014H30.5526V13.2101C30.4107 13.2101 30.2641 13.2017 30.1134 13.2017C29.9628 13.2017 29.8121 13.2058 29.6571 13.2101V13.1014ZM32.345 12.98C32.345 13.0555 32.3909 13.0594 32.462 13.0594C32.5123 13.0594 32.5749 13.0555 32.6295 13.0555V13.1434C32.4492 13.16 32.1061 13.2477 32.0265 13.2727L32.0054 13.2601V12.9218C31.7546 13.1265 31.5617 13.2727 31.2642 13.2727C31.0384 13.2727 30.8039 13.1265 30.8039 12.7757V11.7059C30.8039 11.5972 30.7873 11.4927 30.5531 11.4719V11.3924C30.704 11.3883 31.0384 11.3633 31.093 11.3633C31.1394 11.3633 31.1394 11.3924 31.1394 11.4844V12.5621C31.1394 12.6877 31.1394 13.0469 31.5033 13.0469C31.6456 13.0469 31.834 12.9383 32.0096 12.7924V11.668C32.0096 11.5847 31.8088 11.5389 31.6584 11.497V11.4218C32.0348 11.3966 32.2696 11.3633 32.3112 11.3633C32.345 11.3633 32.345 11.3924 32.345 11.4386V12.98ZM33.178 11.6013C33.3452 11.4593 33.5714 11.3004 33.8018 11.3004C34.2874 11.3004 34.5801 11.7227 34.5801 12.1779C34.5801 12.7252 34.1784 13.2727 33.5794 13.2727C33.2699 13.2727 33.1067 13.1723 32.9977 13.1265L32.8723 13.2224L32.7847 13.1766C32.8217 12.9301 32.8431 12.6877 32.8431 12.4329V10.6364C32.8431 10.3646 32.78 10.3562 32.621 10.3103V10.2435C32.7889 10.1892 32.9643 10.114 33.0523 10.0637C33.0983 10.0388 33.1316 10.0176 33.1446 10.0176C33.1697 10.0176 33.178 10.0429 33.178 10.0764V11.6013ZM33.178 12.7377C33.178 12.8964 33.3286 13.1642 33.6091 13.1642C34.0571 13.1642 34.2453 12.7252 34.2453 12.3532C34.2453 11.9021 33.9024 11.5262 33.5757 11.5262C33.4205 11.5262 33.2909 11.6266 33.178 11.7227V12.7377ZM15.1172 15.6392H15.1493C15.2311 15.6392 15.3177 15.6282 15.3177 15.5098V14.3188C15.3177 14.2002 15.2311 14.189 15.1493 14.189H15.1172V14.1208C15.2061 14.1208 15.3428 14.1297 15.4547 14.1297C15.5684 14.1297 15.7049 14.1208 15.812 14.1208V14.189H15.78C15.6983 14.189 15.6116 14.2002 15.6116 14.3188V15.5098C15.6116 15.6282 15.6983 15.6392 15.78 15.6392H15.812V15.7077C15.7027 15.7077 15.5657 15.6988 15.4522 15.6988C15.3405 15.6988 15.2061 15.7077 15.1172 15.7077V15.6392ZM17.377 15.2596L17.3815 15.2551V14.4028C17.3815 14.2162 17.2515 14.189 17.1833 14.189H17.1331V14.1208C17.2403 14.1208 17.3451 14.1298 17.452 14.1298C17.5454 14.1298 17.6391 14.1208 17.7322 14.1208V14.189H17.6983C17.6023 14.189 17.4953 14.2072 17.4953 14.4777V15.5123C17.4953 15.5918 17.4976 15.6712 17.5088 15.7417H17.4223L16.2493 14.4366V15.3734C16.2493 15.5712 16.2877 15.6392 16.4633 15.6392H16.5019V15.7077C16.4041 15.7077 16.3063 15.6988 16.2082 15.6988C16.106 15.6988 16.0011 15.7077 15.8985 15.7077V15.6392H15.9304C16.0875 15.6392 16.1353 15.5326 16.1353 15.3509V14.3933C16.1353 14.2662 16.0303 14.189 15.9282 14.189H15.8985V14.1208C15.985 14.1208 16.0738 14.1298 16.1602 14.1298C16.2286 14.1298 16.2948 14.1208 16.3631 14.1208L17.377 15.2596ZM18.0734 14.2344C17.9023 14.2344 17.8959 14.2753 17.8617 14.4411H17.7934C17.8022 14.3775 17.8138 14.314 17.8207 14.2479C17.83 14.1841 17.8343 14.1208 17.8343 14.0549H17.889C17.9074 14.1232 17.9642 14.1208 18.0261 14.1208H19.2011C19.2627 14.1208 19.3195 14.1185 19.3243 14.0502L19.3786 14.0593C19.3698 14.1208 19.3605 14.182 19.3536 14.2435C19.3494 14.3049 19.3494 14.3664 19.3494 14.4276L19.281 14.4528C19.2763 14.3688 19.2649 14.2344 19.1124 14.2344H18.7389V15.4439C18.7389 15.6192 18.8187 15.6392 18.9278 15.6392H18.971V15.7077C18.8823 15.7077 18.7227 15.6988 18.5999 15.6988C18.4632 15.6988 18.3037 15.7077 18.2147 15.7077V15.6392H18.258C18.3837 15.6392 18.4471 15.6281 18.4471 15.4486V14.2344H18.0734ZM19.4514 15.6392H19.4834C19.5654 15.6392 19.652 15.6282 19.652 15.5098V14.3188C19.652 14.2002 19.5654 14.189 19.4834 14.189H19.4514V14.1208C19.5901 14.1208 19.8275 14.1297 20.0185 14.1297C20.2101 14.1297 20.4467 14.1208 20.6015 14.1208C20.5976 14.2184 20.5998 14.3687 20.6064 14.4686L20.5378 14.4869C20.5268 14.3392 20.4996 14.221 20.2602 14.221H19.9439V14.8164H20.2146C20.3512 14.8164 20.381 14.7394 20.3946 14.6163H20.4627C20.4582 14.7052 20.4559 14.7938 20.4559 14.8823C20.4559 14.969 20.4582 15.0552 20.4627 15.1416L20.3946 15.1551C20.381 15.0189 20.3741 14.9302 20.2167 14.9302H19.9439V15.4598C19.9439 15.6076 20.0755 15.6076 20.2213 15.6076C20.4948 15.6076 20.6154 15.5892 20.6838 15.3304L20.7475 15.3461C20.7177 15.4669 20.6905 15.587 20.6703 15.7077C20.5243 15.7077 20.2623 15.6988 20.0576 15.6988C19.8523 15.6988 19.5812 15.7077 19.4514 15.7077V15.6392ZM21.0549 14.3616C21.0549 14.1958 20.9638 14.189 20.893 14.189H20.852V14.1207C20.9249 14.1207 21.0661 14.1298 21.2052 14.1298C21.3417 14.1298 21.4511 14.1207 21.5718 14.1207C21.8586 14.1207 22.114 14.1979 22.114 14.521C22.114 14.7253 21.9774 14.8504 21.7975 14.9212L22.1869 15.5028C22.2507 15.5989 22.2961 15.6259 22.4079 15.6391V15.7077C22.3326 15.7077 22.2597 15.6988 22.1846 15.6988C22.114 15.6988 22.0409 15.7077 21.9706 15.7077C21.7952 15.4781 21.6445 15.2326 21.4966 14.9708H21.3466V15.4576C21.3466 15.6328 21.4284 15.6391 21.533 15.6391H21.5741V15.7077C21.444 15.7077 21.3124 15.6988 21.1824 15.6988C21.0729 15.6988 20.9659 15.7077 20.852 15.7077V15.6391H20.893C20.9776 15.6391 21.0549 15.601 21.0549 15.5168V14.3616ZM21.3466 14.8889H21.4578C21.6858 14.8889 21.8086 14.8027 21.8086 14.5343C21.8086 14.3323 21.6788 14.2027 21.4759 14.2027C21.4075 14.2027 21.3783 14.2096 21.3466 14.2117V14.8889ZM23.9544 15.2596L23.9585 15.2551V14.4028C23.9585 14.2162 23.8289 14.189 23.7606 14.189H23.7106V14.1208C23.8177 14.1208 23.9221 14.1298 24.0294 14.1298C24.123 14.1298 24.2159 14.1208 24.31 14.1208V14.189H24.2756C24.1801 14.189 24.0729 14.2072 24.0729 14.4777V15.5123C24.0729 15.5918 24.075 15.6712 24.0863 15.7417H24L22.8269 14.4366V15.3734C22.8269 15.5712 22.8655 15.6392 23.0409 15.6392H23.0796V15.7077C22.9818 15.7077 22.8838 15.6988 22.786 15.6988C22.6831 15.6988 22.5784 15.7077 22.476 15.7077V15.6392H22.5076C22.665 15.6392 22.7129 15.5326 22.7129 15.3509V14.3933C22.7129 14.2662 22.6081 14.189 22.5057 14.189H22.476V14.1208C22.5623 14.1208 22.6515 14.1298 22.7381 14.1298C22.8058 14.1298 22.8721 14.1208 22.9407 14.1208L23.9544 15.2596ZM24.6763 15.3826C24.6532 15.4598 24.6257 15.5193 24.6257 15.5598C24.6257 15.6282 24.7215 15.6392 24.7965 15.6392H24.822V15.7077C24.7307 15.7028 24.6376 15.6989 24.5458 15.6989C24.464 15.6989 24.3825 15.7028 24.3001 15.7077V15.6392H24.3139C24.4027 15.6392 24.4781 15.587 24.5117 15.4913L24.8766 14.4483C24.9059 14.3641 24.9473 14.2504 24.961 14.166C25.0335 14.1413 25.1248 14.0959 25.1681 14.0686C25.1751 14.0661 25.1791 14.0638 25.1863 14.0638C25.1931 14.0638 25.1973 14.0638 25.2024 14.0708C25.2092 14.0889 25.2156 14.1094 25.223 14.1276L25.6421 15.3167C25.6693 15.3961 25.6964 15.4802 25.7259 15.5487C25.7535 15.6123 25.8013 15.6392 25.8766 15.6392H25.8902V15.7077C25.7877 15.7028 25.6851 15.6989 25.576 15.6989C25.4644 15.6989 25.3502 15.7028 25.234 15.7077V15.6392H25.2593C25.3114 15.6392 25.4006 15.6304 25.4006 15.5734C25.4006 15.544 25.38 15.4827 25.3546 15.4097L25.266 15.1461H24.7489L24.6763 15.3826ZM25.0087 14.3754H25.0041L24.7922 15.0189H25.2179L25.0087 14.3754ZM25.9904 14.2344C25.8195 14.2344 25.8127 14.2753 25.7785 14.4411H25.71C25.719 14.3775 25.7306 14.314 25.7377 14.2479C25.7467 14.1841 25.751 14.1208 25.751 14.0549H25.8059C25.824 14.1232 25.8812 14.1208 25.9424 14.1208H27.118C27.1793 14.1208 27.2361 14.1185 27.2408 14.0502L27.2954 14.0593C27.2866 14.1208 27.2775 14.182 27.2707 14.2435C27.2656 14.3049 27.2656 14.3664 27.2656 14.4276L27.1974 14.4528C27.1933 14.3688 27.1818 14.2344 27.0291 14.2344H26.6555V15.4439C26.6555 15.6192 26.7354 15.6392 26.8445 15.6392H26.8879V15.7077C26.799 15.7077 26.6396 15.6988 26.5166 15.6988C26.3801 15.6988 26.2203 15.7077 26.1315 15.7077V15.6392H26.1748C26.3003 15.6392 26.364 15.6281 26.364 15.4486V14.2344H25.9904ZM27.3794 15.6392H27.4112C27.4935 15.6392 27.5796 15.6282 27.5796 15.5098V14.3188C27.5796 14.2002 27.4935 14.189 27.4112 14.189H27.3794V14.1208C27.4684 14.1208 27.6048 14.1297 27.7163 14.1297C27.8305 14.1297 27.9671 14.1208 28.0743 14.1208V14.189H28.0425C27.9603 14.189 27.8736 14.2002 27.8736 14.3188V15.5098C27.8736 15.6282 27.9603 15.6392 28.0425 15.6392H28.0743V15.7077C27.9649 15.7077 27.8282 15.6988 27.7144 15.6988C27.6026 15.6988 27.4684 15.7077 27.3794 15.7077V15.6392ZM28.9828 14.0868C29.4684 14.0868 29.8554 14.387 29.8554 14.8713C29.8554 15.3942 29.4795 15.7418 28.9945 15.7418C28.5112 15.7418 28.1424 15.4145 28.1424 14.9257C28.1424 14.4529 28.5091 14.0868 28.9828 14.0868ZM29.0172 15.6417C29.4592 15.6417 29.5361 15.2527 29.5361 14.9213C29.5361 14.5889 29.3567 14.1866 28.9784 14.1866C28.5796 14.1866 28.4613 14.5414 28.4613 14.8457C28.4613 15.2527 28.6481 15.6417 29.0172 15.6417ZM31.3903 15.2596L31.395 15.2551V14.4028C31.395 14.2162 31.2648 14.189 31.1964 14.189H31.1471V14.1208C31.2537 14.1208 31.3586 14.1298 31.4653 14.1298C31.5591 14.1298 31.6525 14.1208 31.746 14.1208V14.189H31.7116C31.6161 14.189 31.5088 14.2072 31.5088 14.4777V15.5123C31.5088 15.5918 31.511 15.6712 31.5226 15.7417H31.4361L30.2628 14.4366V15.3734C30.2628 15.5712 30.3016 15.6392 30.4768 15.6392H30.5157V15.7077C30.4177 15.7077 30.3199 15.6988 30.2219 15.6988C30.1194 15.6988 30.0143 15.7077 29.9118 15.7077V15.6392H29.944C30.1014 15.6392 30.1487 15.5326 30.1487 15.3509V14.3933C30.1487 14.2662 30.0445 14.189 29.9415 14.189H29.9118V14.1208C29.9985 14.1208 30.0874 14.1298 30.1738 14.1298C30.2421 14.1298 30.308 14.1208 30.3765 14.1208L31.3903 15.2596ZM32.112 15.3826C32.0896 15.4598 32.062 15.5193 32.062 15.5598C32.062 15.6282 32.1579 15.6392 32.2326 15.6392H32.2581V15.7077C32.1669 15.7028 32.0734 15.6989 31.9822 15.6989C31.9 15.6989 31.8183 15.7028 31.7367 15.7077V15.6392H31.7496C31.8387 15.6392 31.9142 15.587 31.9478 15.4913L32.3128 14.4483C32.3423 14.3641 32.3835 14.2504 32.3967 14.166C32.4698 14.1413 32.5608 14.0959 32.6044 14.0686C32.6109 14.0661 32.6155 14.0638 32.6224 14.0638C32.6292 14.0638 32.6336 14.0638 32.6382 14.0708C32.6451 14.0889 32.6521 14.1094 32.659 14.1276L33.0778 15.3167C33.1051 15.3961 33.1324 15.4802 33.1623 15.5487C33.1896 15.6123 33.2377 15.6392 33.3126 15.6392H33.3265V15.7077C33.2239 15.7028 33.1213 15.6989 33.0118 15.6989C32.9005 15.6989 32.7863 15.7028 32.6701 15.7077V15.6392H32.6953C32.7473 15.6392 32.8368 15.6304 32.8368 15.5734C32.8368 15.544 32.8161 15.4827 32.7907 15.4097L32.7022 15.1461H32.1851L32.112 15.3826ZM32.4449 14.3754H32.4403L32.2281 15.0189H32.6545L32.4449 14.3754ZM33.9005 15.4848C33.9005 15.576 33.9638 15.603 34.0367 15.6123C34.1301 15.6192 34.2326 15.6192 34.3377 15.6077C34.4332 15.5962 34.5152 15.5418 34.5561 15.4848C34.5924 15.4348 34.6129 15.3712 34.6268 15.3211H34.6928C34.6678 15.4507 34.6358 15.5783 34.6083 15.7077C34.4084 15.7077 34.2072 15.6989 34.0073 15.6989C33.8065 15.6989 33.6064 15.7077 33.4059 15.7077V15.6392H33.4373C33.5196 15.6392 33.6087 15.6282 33.6087 15.4871V14.3187C33.6087 14.2002 33.5196 14.189 33.4373 14.189H33.4059V14.1208C33.5263 14.1208 33.645 14.1298 33.7655 14.1298C33.8821 14.1298 33.9958 14.1208 34.112 14.1208V14.189H34.0548C33.9684 14.189 33.9005 14.1915 33.9005 14.3117V15.4848Z' fill='%231A1918'/%3e%3c/g%3e%3cdefs%3e%3cclipPath id='clip0_7977_9960'%3e%3crect width='30.5672' height='8' fill='white' transform='translate(4.14258 9)'/%3e%3c/clipPath%3e%3c/defs%3e%3c/svg%3e";

var useStyles$o = /*#__PURE__*/createUseStyles({
  cardList: {
    display: 'flex',
    width: 213,
    margin: '16px auto 0',
    justifyContent: 'space-between',
    paddingBottom: 16,
    '& img': {
      height: 25
    }
  },
  header: {
    display: 'flex',
    alignItems: 'center',
    flexDirection: 'column',
    borderBottom: '1px solid #C7C7C7'
  },
  divider: {
    height: 1,
    background: '#C7C7C7'
  },
  title: {
    fontSize: 18
  }
});

var CardHeader = function CardHeader() {
  var _useStyles = useStyles$o(),
      cardList = _useStyles.cardList,
      header = _useStyles.header,
      title = _useStyles.title;

  return React.createElement("div", {
    className: header
  }, React.createElement(Typography, {
    className: title,
    variant: TypographyVariants.title
  }, "Credit / Debit Card"), React.createElement("div", {
    className: cardList
  }, React.createElement("img", {
    src: img$c,
    alt: ''
  }), React.createElement("img", {
    src: img$d,
    alt: ''
  }), React.createElement("img", {
    src: img$e,
    alt: ''
  }), React.createElement("img", {
    src: img$g,
    alt: ''
  }), React.createElement("img", {
    src: img$f,
    alt: ''
  })));
};

var useCheckoutForm = function useCheckoutForm(country, onSubmit) {
  var _useState = useState(false),
      loading = _useState[0],
      setLoading = _useState[1];

  var _useState2 = useState(''),
      postalCode = _useState2[0],
      setPostalCode = _useState2[1];

  var _useState3 = useState(''),
      name = _useState3[0],
      setName = _useState3[1];

  var _useState4 = useState(false),
      isValid = _useState4[0],
      toggleValid = _useState4[1];

  var _useState5 = useState(''),
      cardName = _useState5[0],
      setCardName = _useState5[1];

  var _useState6 = useState(''),
      token = _useState6[0],
      setToken = _useState6[1];

  var _useState7 = useState(''),
      errorMsgCard = _useState7[0],
      setErrorCard = _useState7[1];

  var _useState8 = useState(''),
      errorMsgDate = _useState8[0],
      setErrorDate = _useState8[1];

  var _useState9 = useState(''),
      errorMsgCvv = _useState9[0],
      setErrorCvv = _useState9[1];

  var _useState10 = useState(false),
      errorMsgCardEmpty = _useState10[0],
      setErrorCardEmpty = _useState10[1];

  var _useState11 = useState(false),
      errorMsgDateEmpty = _useState11[0],
      setErrorDateEmpty = _useState11[1];

  var _useState12 = useState(false),
      errorMsgCvvEmpty = _useState12[0],
      setErrorCvvEmpty = _useState12[1];

  var _useState13 = useState(''),
      billingPostcode = _useState13[0],
      setBillingPostcode = _useState13[1];

  var _useState14 = useState(false),
      loadedScript = _useState14[0],
      setLoadedScript = _useState14[1];

  var handlePostalCodeChange = function handlePostalCodeChange(_ref) {
    var value = _ref.target.value;
    return setPostalCode(value);
  };

  var handleChangeName = function handleChangeName(_ref2) {
    var value = _ref2.target.value;
    return setName(value);
  };

  var cardValidationChanged = function cardValidationChanged(e) {
    toggleValid(e.isValid);
  };

  var frameValidationChanged = function frameValidationChanged(e) {
    if (e.element === 'card-number' && !e.isValid && !e.isEmpty) {
      setErrorCard('Please enter a valid card number');
      setErrorCardEmpty(true);
    }

    if (e.element === 'expiry-date' && !e.isValid && !e.isEmpty) {
      setErrorDate('Please enter a valid expiry date');
      setErrorDateEmpty(true);
    }

    if (e.element === 'cvv' && !e.isValid && !e.isEmpty) {
      setErrorCvv('Please enter a valid cvv code');
      setErrorCvvEmpty(true);
    }

    if (e.element === 'card-number' && e.isValid || e.element === 'card-number' && e.isEmpty && !e.isValid) {
      setErrorCard('');
      setErrorCardEmpty(false);
    }

    if (e.element === 'expiry-date' && e.isValid || e.element === 'expiry-date' && e.isEmpty && !e.isValid) {
      setErrorDate('');
      setErrorDateEmpty(false);
    }

    if (e.element === 'cvv' && e.isValid || e.element === 'cvv' && e.isEmpty && !e.isValid) {
      setErrorCvv('');
      setErrorCvvEmpty(false);
    }
  };

  var paymentMethodChanged = function paymentMethodChanged(_ref3) {
    var paymentMethod = _ref3.paymentMethod;
    return setCardName(paymentMethod);
  };

  var disabledBtn = !isValid || country === 'US' && !postalCode || !name;

  var handleSubmit = function handleSubmit() {
    if (disabledBtn || loading) {
      return;
    }

    setLoading(true);

    if (token) {
      Frames.enableSubmitForm();
    }

    Frames.submitCard().then(function (_ref4) {
      var token = _ref4.token;
      setToken(token);
      onSubmit({
        token: token,
        name: name,
        postalCode: postalCode,
        type: 'card'
      }).then(function () {
        return setLoading(false);
      });
    });
  };

  useLayoutEffect(function () {
    var script = document.createElement('script');
    script.src = 'https://cdn.checkout.com/js/framesv2.min.js';
    document.head.appendChild(script);

    script.onload = function () {
      setLoadedScript(true);
    };
  }, []);
  return {
    cardName: cardName,
    cardValidationChanged: cardValidationChanged,
    paymentMethodChanged: paymentMethodChanged,
    frameValidationChanged: frameValidationChanged,
    handlePostalCodeChange: handlePostalCodeChange,
    handleChangeName: handleChangeName,
    handleSubmit: handleSubmit,
    name: name,
    country: country,
    postalCode: postalCode,
    loading: loading,
    disabledBtn: disabledBtn,
    errorMsgCard: errorMsgCard,
    errorMsgDate: errorMsgDate,
    errorMsgCvv: errorMsgCvv,
    errorMsgCardEmpty: errorMsgCardEmpty,
    errorMsgDateEmpty: errorMsgDateEmpty,
    errorMsgCvvEmpty: errorMsgCvvEmpty,
    setBillingPostcode: setBillingPostcode,
    billingPostcode: billingPostcode,
    loadedScript: loadedScript
  };
};

var base = {
  fontSize: '16px',
  lineHeight: '18px',
  letterSpacing: '0.0008em',
  fontWeight: 400,
  color: '#121620',
  fontFamily: "'SF Pro Text', system-ui, sans-serif",
  paddingBottom: '4px',
  borderRadius: '10px',
  border: '1px solid #c7c7c7 !important',
  padding: '14px 12px',
  width: '100%',
  height: '100%'
};
var valid = {
  color: '#121620'
};
var placeholder = {
  base: {
    color: '#8E8E93',
    fontSize: '16px',
    fontWeight: 400,
    fontFamily: "'SF Pro Text', system-ui, sans-serif"
  }
};
var focus = {
  fontSize: '16px',
  lineHeight: '18px',
  letterSpacing: '0.0008em',
  fontWeight: 400,
  color: '#121620',
  fontFamily: "'SF Pro Text', system-ui, sans-serif",
  paddingBottom: '4px',
  borderRadius: '10px',
  border: '1px solid #c7c7c7 !important',
  padding: '14px 12px',
  width: '100%',
  height: '100%'
};
var invalid = {
  color: '#FF5758',
  border: '1px solid #FF5758'
};

var img$h = "data:image/svg+xml,%3csvg width='17' height='17' viewBox='0 0 17 17' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M12.6475 8.07568H4.3512C3.69664 8.07568 3.16602 8.67264 3.16602 9.40902V14.0757C3.16602 14.8121 3.69664 15.409 4.3512 15.409H12.6475C13.3021 15.409 13.8327 14.8121 13.8327 14.0757V9.40902C13.8327 8.67264 13.3021 8.07568 12.6475 8.07568Z' fill='white' stroke='white' stroke-width='0.833333' stroke-linecap='round' stroke-linejoin='round'/%3e%3cpath d='M5.16602 8.07568V5.40902C5.16602 4.52496 5.51721 3.67712 6.14233 3.05199C6.76745 2.42687 7.61529 2.07568 8.49935 2.07568C9.3834 2.07568 10.2313 2.42687 10.8564 3.05199C11.4815 3.67712 11.8327 4.52496 11.8327 5.40902V8.07568' stroke='white' stroke-width='0.833333' stroke-linecap='round' stroke-linejoin='round'/%3e%3c/svg%3e";

var img$i = "data:image/svg+xml,%3csvg width='17' height='17' viewBox='0 0 17 17' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cpath d='M12.6475 8.07568H4.3512C3.69664 8.07568 3.16602 8.67264 3.16602 9.40902V14.0757C3.16602 14.8121 3.69664 15.409 4.3512 15.409H12.6475C13.3021 15.409 13.8327 14.8121 13.8327 14.0757V9.40902C13.8327 8.67264 13.3021 8.07568 12.6475 8.07568Z' fill='rgb(18%2c 22%2c 32)' stroke='rgb(18%2c 22%2c 32)' stroke-width='0.833333' stroke-linecap='round' stroke-linejoin='round'/%3e %3cpath d='M5.16602 8.07568V5.40902C5.16602 4.52496 5.51721 3.67712 6.14233 3.05199C6.76745 2.42687 7.61529 2.07568 8.49935 2.07568C9.3834 2.07568 10.2313 2.42687 10.8564 3.05199C11.4815 3.67712 11.8327 4.52496 11.8327 5.40902V8.07568' stroke='rgb(18%2c 22%2c 32)' stroke-width='0.833333' stroke-linecap='round' stroke-linejoin='round'/%3e%3c/svg%3e";

var img$j = "data:image/svg+xml,%3csvg width='30' height='21' viewBox='0 0 30 21' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3crect y='2.49292' width='28' height='18' rx='2' fill='%23EDCDCF'/%3e%3crect x='4' y='14.4929' width='20' height='2' rx='1' fill='%23E49C9E'/%3e%3crect x='4' y='6.49292' width='4' height='4' rx='1' fill='white'/%3e%3cg clip-path='url(%23clip0)'%3e%3cpath d='M24 0.99292C20.6865 0.99292 18 3.67941 18 6.99292C18 10.3068 20.6865 12.9929 24 12.9929C27.3139 12.9929 30 10.3072 30 6.99292C30 3.67941 27.3139 0.99292 24 0.99292Z' fill='%23E2574C'/%3e%3cpath d='M23.2441 4.21077C23.2441 3.84853 23.5693 3.62427 23.999 3.62427C24.4183 3.62427 24.7539 3.85713 24.7539 4.21077V7.53326C24.7539 7.88652 24.4183 8.11939 23.999 8.11939C23.5693 8.11939 23.2441 7.89588 23.2441 7.53326V4.21077Z' fill='white'/%3e%3cpath d='M23.2501 9.61713C23.2501 9.20393 23.5862 8.86791 23.999 8.86791C24.4119 8.86791 24.7475 9.20388 24.7475 9.61713C24.7475 10.0296 24.4119 10.3657 23.999 10.3657C23.5862 10.3657 23.2501 10.0296 23.2501 9.61713Z' fill='white'/%3e%3c/g%3e%3cdefs%3e%3cclipPath id='clip0'%3e%3crect width='12' height='12' fill='white' transform='translate(18 0.99292)'/%3e%3c/clipPath%3e%3c/defs%3e%3c/svg%3e";

var img$k = "data:image/svg+xml,%3csvg width='28' height='19' viewBox='0 0 28 19' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3crect y='0.74292' width='28' height='18' rx='2' fill='%23E6EAEE'/%3e%3crect x='4' y='12.7429' width='20' height='2' rx='1' fill='%23BEC0C5'/%3e%3crect x='4' y='4.74292' width='4' height='4' rx='1' fill='white'/%3e%3c/svg%3e";

var img$l = "data:image/svg+xml,%3csvg width='32' height='32' viewBox='0 0 32 32' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3crect x='32' y='32' width='32' height='32' rx='16' transform='rotate(-180 32 32)' fill='%23EFF2FD'/%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M21.7071 21.7071C21.3166 22.0976 20.6834 22.0976 20.2929 21.7071L15.2929 16.7071C14.9024 16.3166 14.9024 15.6834 15.2929 15.2929L20.2929 10.2929C20.6834 9.90237 21.3166 9.90237 21.7071 10.2929C22.0976 10.6834 22.0976 11.3166 21.7071 11.7071L17.4142 16L21.7071 20.2929C22.0976 20.6834 22.0976 21.3166 21.7071 21.7071Z' fill='%23858DA5' stroke='%23858DA5' stroke-linecap='round' stroke-linejoin='round'/%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M10.2929 21.7071C10.6834 22.0976 11.3166 22.0976 11.7071 21.7071L16.7071 16.7071C17.0976 16.3166 17.0976 15.6834 16.7071 15.2929L11.7071 10.2929C11.3166 9.90237 10.6834 9.90237 10.2929 10.2929C9.90237 10.6834 9.90237 11.3166 10.2929 11.7071L14.5858 16L10.2929 20.2929C9.90237 20.6834 9.90237 21.3166 10.2929 21.7071Z' fill='%23858DA5' stroke='%23858DA5' stroke-linecap='round' stroke-linejoin='round'/%3e%3c/svg%3e";

var useStyles$p = /*#__PURE__*/createUseStyles({
  inputWrapper: {
    borderRadius: 10,
    border: '1px solid #c7c7c7',
    marginBottom: 12,
    overflow: 'hidden',
    '& input': {
      border: 'none',
      padding: '14px 12px',
      height: 46,
      fontSize: 16,
      width: '100%',
      outline: 'none',
      fontWeight: 400,
      color: '#121620',
      '&:focus': {
        border: 'none'
      }
    },
    '& input::placeholder': {
      color: '#8E8E93 !important'
    }
  },
  inputErrorWrapper: {
    position: 'relative',
    marginBottom: 12
  },
  inputName: {
    marginTop: 16
  },
  cvvInput: {
    marginLeft: 12
  },
  errorText: {
    wordWrap: 'break-word',
    color: '#FF5758',
    fontSize: '12px',
    lineHeight: '16px',
    letterSpacing: '0.0008em',
    textAlign: 'left',
    margin: '4px 0 0 0'
  },
  cvvWrapper: {
    display: 'flex',
    justifyContent: 'space-between'
  },
  zipCodeInput: {
    '&::-webkit-inner-spin-button': {
      '-webkit-appearance': 'none',
      margin: 0
    }
  },
  form: {
    margin: '0 8px',
    maxWidth: 359,
    maxHeight: '90%',
    overflowY: 'auto',
    position: 'relative',
    background: "white",
    '& *': {
      boxSizing: 'border-box'
    },
    '& iframe': {
      height: '48px !important'
    },
    borderRadius: 16,
    padding: '64px 24px',
    boxSizing: 'border-box'
  },
  button: /*#__PURE__*/_extends({
    width: '100%',
    height: 48,
    borderRadius: 10,
    background: '#066FDE'
  }, alignment.center, {
    '&:hover': {
      background: '#066FDE'
    },
    '& p': {
      fontSize: 14,
      lineHeight: '18px'
    }
  }),
  buttonContent: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    '& img': {
      marginRight: 8,
      marginBottom: 3
    }
  },
  cardIconError: {
    position: 'absolute',
    top: 24,
    right: 13,
    transform: 'translate(0, -50%)',
    width: 29
  },
  cardIcon: {
    position: 'absolute',
    top: 25,
    right: 15,
    transform: 'translate(0, -50%)',
    width: 28
  },
  close: {
    position: 'absolute',
    top: 16,
    right: 26,
    cursor: 'pointer'
  },
  errorBlock: {
    marginTop: 16
  }
});

var CARD_TYPES = {
  'Visa': img$c,
  'Mastercard': img$d,
  'American Express': img$e,
  'Diners Club': img$g,
  'Discover': img$f
};
var CheckoutForm = function CheckoutForm(_ref) {
  var publicKey = _ref.publicKey,
      countryCode = _ref.countryCode,
      onSubmit = _ref.onSubmit,
      isUpdateForm = _ref.isUpdateForm,
      handleClose = _ref.handleClose,
      formText = _ref.formText,
      error = _ref.error;

  var _useStyles = useStyles$p(),
      inputWrapper = _useStyles.inputWrapper,
      inputName = _useStyles.inputName,
      inputErrorWrapper = _useStyles.inputErrorWrapper,
      form = _useStyles.form,
      buttonContent = _useStyles.buttonContent,
      cvvInput = _useStyles.cvvInput,
      errorText = _useStyles.errorText,
      close = _useStyles.close,
      cvvWrapper = _useStyles.cvvWrapper,
      zipCodeInput = _useStyles.zipCodeInput,
      button = _useStyles.button,
      cardIconError = _useStyles.cardIconError,
      cardIcon = _useStyles.cardIcon,
      errorBlock = _useStyles.errorBlock;

  var _useCheckoutForm = useCheckoutForm(countryCode, onSubmit),
      cardName = _useCheckoutForm.cardName,
      cardValidationChanged = _useCheckoutForm.cardValidationChanged,
      paymentMethodChanged = _useCheckoutForm.paymentMethodChanged,
      frameValidationChanged = _useCheckoutForm.frameValidationChanged,
      handlePostalCodeChange = _useCheckoutForm.handlePostalCodeChange,
      handleChangeName = _useCheckoutForm.handleChangeName,
      handleSubmit = _useCheckoutForm.handleSubmit,
      name = _useCheckoutForm.name,
      country = _useCheckoutForm.country,
      postalCode = _useCheckoutForm.postalCode,
      loading = _useCheckoutForm.loading,
      disabledBtn = _useCheckoutForm.disabledBtn,
      errorMsgCard = _useCheckoutForm.errorMsgCard,
      errorMsgDate = _useCheckoutForm.errorMsgDate,
      errorMsgCvv = _useCheckoutForm.errorMsgCvv,
      errorMsgCardEmpty = _useCheckoutForm.errorMsgCardEmpty,
      errorMsgDateEmpty = _useCheckoutForm.errorMsgDateEmpty,
      errorMsgCvvEmpty = _useCheckoutForm.errorMsgCvvEmpty,
      loadedScript = _useCheckoutForm.loadedScript;

  if (!loadedScript) return null;
  return React.createElement("div", {
    className: form
  }, React.createElement("img", {
    onClick: handleClose,
    className: close,
    src: img$l,
    alt: ""
  }), React.createElement(CardHeader, null), error && React.createElement(InfoBlock, {
    className: errorBlock,
    variant: "error",
    text: error
  }), React.createElement(Frames, {
    config: {
      publicKey: publicKey,
      localization: {
        cardNumberPlaceholder: 'Card Number',
        expiryMonthPlaceholder: 'MM',
        expiryYearPlaceholder: 'YY',
        cvvPlaceholder: 'CVV'
      },
      style: {
        base: base,
        placeholder: placeholder,
        invalid: invalid,
        focus: focus,
        valid: valid
      },
      cardholder: {
        name: name
      }
    },
    cardValidationChanged: cardValidationChanged,
    paymentMethodChanged: paymentMethodChanged,
    frameValidationChanged: frameValidationChanged,
    cardTokenized: function cardTokenized() {},
    cardTokenizationFailed: function cardTokenizationFailed(e) {
      return console.log(e);
    }
  }, React.createElement("div", null, React.createElement("div", {
    className: inputWrapper + " " + inputName
  }, React.createElement("input", {
    value: name,
    onChange: handleChangeName,
    placeholder: "Name on Card",
    type: 'text'
  }))), React.createElement("div", {
    className: inputErrorWrapper
  }, React.createElement(CardNumber, null), errorMsgCard && errorMsgCardEmpty ? React.createElement("img", {
    className: cardIconError,
    src: img$j,
    alt: ""
  }) //@ts-ignore
  : React.createElement("img", {
    className: cardIcon,
    src: CARD_TYPES[cardName] || img$k,
    alt: ""
  }), errorMsgCard && errorMsgCardEmpty && React.createElement("p", {
    className: errorText
  }, errorMsgCard)), React.createElement("div", {
    className: cvvWrapper
  }, React.createElement("div", {
    className: inputErrorWrapper
  }, React.createElement(ExpiryDate, null), errorMsgDate && errorMsgDateEmpty && React.createElement("p", {
    className: errorText
  }, errorMsgDate)), React.createElement("div", {
    className: cvvInput + " " + inputErrorWrapper
  }, React.createElement(Cvv, null), errorMsgCvv && errorMsgCvvEmpty && React.createElement("p", {
    className: errorText
  }, errorMsgCvv))), country === "US" && React.createElement("div", {
    className: inputWrapper
  }, React.createElement("input", {
    className: zipCodeInput,
    value: postalCode,
    onChange: handlePostalCodeChange,
    placeholder: "Billing Postcode",
    type: "number"
  })), formText && formText, React.createElement(PrimaryButton, {
    className: button,
    loading: loading,
    disabled: disabledBtn,
    onClick: handleSubmit,
    //@ts-ignore
    label: React.createElement("div", {
      className: buttonContent
    }, React.createElement("img", {
      src: disabledBtn ? img$i : img$h,
      alt: ""
    }), isUpdateForm ? 'Update' : 'Start 7-Day Trial')
  })));
};

var useStyles$q = /*#__PURE__*/createUseStyles({
  appleGooglePay: {
    borderRadius: 10,
    height: 48,
    marginBottom: 12
  }
});

var AppleGooglePay = function AppleGooglePay(_ref) {
  var price = _ref.price,
      currency = _ref.currency,
      isPaymentRequestShowed = _ref.isPaymentRequestShowed,
      setPaymentRequest = _ref.setPaymentRequest,
      setStripeResult = _ref.setStripeResult,
      onSubmit = _ref.onSubmit,
      paymentRequest = _ref.paymentRequest,
      setGpayLoaded = _ref.setGpayLoaded,
      setApayLoaded = _ref.setApayLoaded;
  var stripe = useStripe();

  var _useStyles = useStyles$q(),
      appleGooglePay = _useStyles.appleGooglePay;

  var submitPayment = function submitPayment(result) {
    return function (e) {
      if (result != null && result.applePay) {
        onSubmit({
          event: e,
          price: price,
          type: 'applePay'
        });
      }

      if (result != null && result.googlePay) {
        onSubmit({
          event: e,
          price: price,
          type: 'googlePay'
        });
      }
    };
  };

  var handleReady = function handleReady() {
    setApayLoaded(true);
    setGpayLoaded(true);
  };

  useEffect(function () {
    if (price !== undefined && stripe && currency) {
      var pr = stripe == null ? void 0 : stripe.paymentRequest({
        country: 'GB',
        currency: currency == null ? void 0 : currency.toLowerCase(),
        total: {
          label: 'Hint',
          amount: price
        },
        requestPayerName: true,
        requestPayerEmail: true
      });
      pr.canMakePayment().then(function (result) {
        if (result && (result.googlePay || result.applePay)) {
          setStripeResult(result);
          pr.on('token', submitPayment(result));
          setPaymentRequest(pr);
        } else {
          handleReady();
        }
      });
    }
  }, [stripe, price, currency]);
  if (!isPaymentRequestShowed) return null;
  return React.createElement(PaymentRequestButtonElement, {
    onReady: function onReady() {
      console.log('apple google pay ready');
      handleReady();
    },
    options: {
      paymentRequest: paymentRequest,
      style: {
        paymentRequestButton: {
          height: '48px'
        }
      }
    },
    className: appleGooglePay
  });
};

var REGION = {
  de: 'de',
  uk: 'uk',
  jp: 'jp',
  us: 'us'
};
var getScriptUrl = function getScriptUrl(isSandbox, region) {
  if (region === void 0) {
    region = REGION.us;
  }

  var sandbox = isSandbox ? 'sandbox/' : '';

  switch (region.toLowerCase()) {
    case 'de':
      return "https://static-eu.payments-amazon.com/OffAmazonPayments/de/" + sandbox + "lpa/js/Widgets.js";

    case 'uk':
      return "https://static-eu.payments-amazon.com/OffAmazonPayments/uk/" + sandbox + "lpa/js/Widgets.js";

    case 'jp':
      return "https://static-fe.payments-amazon.com/OffAmazonPayments/jp/" + sandbox + "lpa/js/Widgets.js";

    default:
      return "https://static-na.payments-amazon.com/OffAmazonPayments/us/" + sandbox + "js/Widgets.js";
  }
};
var appendScript = function appendScript(isSandbox, region, loadBtn) {
  if (region === void 0) {
    region = REGION.us;
  }

  var script = document.createElement('script');
  script.type = 'text/javascript';
  script.src = getScriptUrl(isSandbox, region);
  script.async = true;
  script.addEventListener('load', loadBtn);
  document.body.appendChild(script);
};

var useStyles$r = /*#__PURE__*/createUseStyles({
  amazonPayButton: {
    width: '100%',
    height: 48,
    position: 'absolute',
    top: 0,
    left: 0,
    overflow: 'hidden',
    zIndex: 2,
    opacity: 0
  }
});

var AMAZON_PAY_BUTTON_DIV_ID = 'AmazonPayButton';

var buttonLoad = function buttonLoad(_ref) {
  var onError = _ref.onError,
      onAuth = _ref.onAuth,
      sellerId = _ref.sellerId;
  return function () {
    // @ts-ignore
    window.OffAmazonPayments.Button(AMAZON_PAY_BUTTON_DIV_ID, sellerId, {
      authorization: function authorization() {
        // @ts-ignore
        window.amazon.Login.authorize({
          scope: 'profile payments:widget'
        }, onAuth);
      },
      onError: onError
    });
  };
};

var AmazonPaymentButton = function AmazonPaymentButton(_ref2) {
  var sellerId = _ref2.sellerId,
      clientId = _ref2.clientId,
      env = _ref2.env,
      onAuth = _ref2.onAuth,
      _ref2$onError = _ref2.onError,
      onError = _ref2$onError === void 0 ? function () {} : _ref2$onError;

  var _useStyles = useStyles$r(),
      amazonPayButton = _useStyles.amazonPayButton;

  var handleAmazonLoginReady = function handleAmazonLoginReady() {
    // @ts-ignore
    window.amazon.Login.setClientId(clientId);
  };

  useEffect(function () {
    //@ts-ignore
    window.onAmazonLoginReady = handleAmazonLoginReady;
  }, [handleAmazonLoginReady]);
  useEffect(function () {
    var isSandbox = env === 'development';
    var loadBtn = buttonLoad({
      onError: onError,
      onAuth: onAuth,
      sellerId: sellerId
    });
    appendScript(isSandbox, undefined, loadBtn);
  }, []);
  return React.createElement("div", {
    className: amazonPayButton,
    id: AMAZON_PAY_BUTTON_DIV_ID
  });
};

var img$m = "data:image/svg+xml,%3csvg width='105' height='20' viewBox='0 0 105 20' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cg clip-path='url(%23clip0)'%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M41.1044 15.6446C37.2547 18.4878 31.6739 19.9998 26.8688 19.9998C20.1334 19.9998 14.0677 17.507 9.47789 13.3597C9.1176 13.0339 9.4389 12.5893 9.8721 12.8413C14.8239 15.7252 20.9481 17.4629 27.2723 17.4629C31.5391 17.4629 36.2289 16.5762 40.5449 14.7444C41.1959 14.4686 41.7419 15.1737 41.1044 15.6446Z' fill='%23F79C34'/%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M42.705 13.8139C42.2116 13.1835 39.4504 13.5144 38.2093 13.6637C37.8338 13.7095 37.7753 13.3803 38.1135 13.1419C40.3177 11.5935 43.9283 12.0398 44.3479 12.559C44.771 13.0817 44.236 16.7055 42.1717 18.4338C41.8538 18.6994 41.552 18.5577 41.6928 18.2072C42.1582 17.0457 43.1984 14.446 42.705 13.8139Z' fill='%23F79C34'/%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M94.2869 15.3793C94.2869 15.1128 94.2869 14.8719 94.2869 14.6055C94.2869 14.3849 94.3945 14.2338 94.6243 14.2466C95.0524 14.3077 95.6586 14.3687 96.0892 14.2797C96.6504 14.1626 97.054 13.7646 97.2922 13.2182C97.6279 12.4495 97.85 11.8284 97.9907 11.422L93.7248 0.84507C93.6528 0.666044 93.6324 0.332598 93.9902 0.332598H95.4822C95.7662 0.332598 95.8824 0.512472 95.9459 0.689801L99.0386 9.2805L101.99 0.689801C102.051 0.513321 102.172 0.332598 102.453 0.332598H103.86C104.216 0.332598 104.195 0.665196 104.125 0.84507L99.894 11.7512C99.3463 13.2038 98.6164 15.5159 96.9743 15.9172C96.1503 16.1327 95.1109 16.0546 94.5005 15.7984C94.3454 15.722 94.2869 15.5159 94.2869 15.3793ZM76.7917 1.7682C79.1247 1.7682 79.7605 3.60512 79.7605 5.70762C79.7741 7.12455 79.513 8.38877 78.7805 9.1125C78.232 9.65467 77.6182 9.80231 76.695 9.80231C75.8736 9.80231 74.7927 9.37383 73.9856 8.77651V2.76345C74.8257 2.11777 75.8981 1.7682 76.7917 1.7682ZM73.6287 15.756H72.2197C72.023 15.756 71.8611 15.5956 71.8611 15.3979C71.8611 10.5014 71.8611 5.60495 71.8611 0.708468C71.8611 0.511624 72.0222 0.350416 72.2197 0.350416H73.2972C73.5244 0.350416 73.6796 0.514169 73.7075 0.708468L73.8211 1.47802C74.8308 0.581198 76.1313 0.00593925 77.3707 0.00593925C80.8397 0.00593925 81.9808 2.86696 81.9808 5.84168C81.9808 9.02427 80.2353 11.5824 77.2842 11.5824C76.0414 11.5824 74.88 11.1234 73.9856 10.3267V15.3988C73.9848 15.5956 73.8245 15.756 73.6287 15.756ZM92.2972 10.9554C92.2972 11.1522 92.1361 11.3143 91.9377 11.3143H90.8865C90.6593 11.3143 90.5042 11.1497 90.4762 10.9554L90.3702 10.2393C89.887 10.6482 89.2936 11.008 88.651 11.2583C87.4141 11.7385 85.9882 11.8183 84.7801 11.0759C83.9061 10.5388 83.4423 9.48922 83.4423 8.40658C83.4423 7.56915 83.7001 6.7385 84.2723 6.13524C85.0353 5.31139 86.1408 4.90667 87.4768 4.90667C88.283 4.90667 89.4377 5.0017 90.2778 5.2766V3.83591C90.2778 2.36976 89.6607 1.73511 88.0347 1.73511C86.7918 1.73511 85.8407 1.92347 84.5182 2.33497C84.3062 2.34176 84.1824 2.18055 84.1824 1.98371V1.1624C84.1824 0.965552 84.3503 0.774648 84.5326 0.716104C85.477 0.304599 86.8156 0.047514 88.239 0C90.0939 0 92.298 0.418293 92.298 3.27337V10.9554H92.2972ZM90.2761 8.85118V6.67572C89.5699 6.48227 88.4017 6.40251 87.9499 6.40251C87.2361 6.40251 86.4544 6.57135 86.0458 7.01086C85.7415 7.33328 85.6033 7.79654 85.6033 8.24453C85.6033 8.82318 85.8034 9.40438 86.2705 9.69116C86.8139 10.0602 87.6557 10.0153 88.4467 9.79043C89.208 9.57407 89.9209 9.19141 90.2761 8.85118ZM8.10966 11.5747C7.97402 11.6969 7.77819 11.7046 7.62559 11.6231C6.94399 11.0563 6.82191 10.7942 6.44975 10.2554C5.32392 11.4034 4.52703 11.747 3.06889 11.747C1.34285 11.7461 0 10.6796 0 8.54743C0 6.88104 0.901167 5.74834 2.18722 5.19345C3.29948 4.70389 4.85342 4.61565 6.04198 4.48244V4.21602C6.04198 3.72645 6.08097 3.1495 5.79358 2.72781C5.54349 2.3494 5.06366 2.19413 4.64233 2.19413C3.85985 2.19413 3.16384 2.59545 2.99428 3.4261C2.95868 3.61106 2.82388 3.79433 2.63738 3.80366L0.650231 3.58816C0.481527 3.54997 0.295868 3.41507 0.34419 3.15968C0.79435 0.779738 2.91799 0.0381809 4.84833 0.0178177H5.00008C5.98857 0.0305447 7.25003 0.301205 8.0181 1.03937C9.01507 1.97268 8.91927 3.21653 8.91927 4.57153V7.76854C8.91927 8.7307 9.31856 9.15238 9.69327 9.66995C9.82383 9.85746 9.85435 10.0789 9.68649 10.2164C9.2677 10.5676 8.52337 11.2142 8.1139 11.579L8.10966 11.5747ZM6.04198 6.57051C6.04198 7.36976 6.06147 8.03665 5.65794 8.74767C5.33325 9.32462 4.81527 9.68013 4.23879 9.68013C3.45292 9.68013 2.99259 9.08026 2.99259 8.19192C2.99259 6.44324 4.55925 6.12591 6.04282 6.12591V6.57051H6.04198ZM34.9912 11.5747C34.8556 11.6969 34.6606 11.7046 34.5072 11.6231C33.8264 11.0563 33.7043 10.7942 33.3313 10.2554C32.2055 11.4034 31.4086 11.747 29.9505 11.747C28.2244 11.747 26.8816 10.6805 26.8816 8.54828C26.8816 6.88189 27.7836 5.74919 29.0688 5.19345C30.1819 4.70473 31.735 4.61565 32.9244 4.48244V4.21602C32.9244 3.72645 32.9626 3.1495 32.6752 2.72781C32.4259 2.3494 31.9469 2.19413 31.5248 2.19413C30.7423 2.19413 30.048 2.59545 29.8767 3.4261C29.8411 3.61106 29.7063 3.79433 29.5215 3.80366L27.5335 3.58816C27.3657 3.54997 27.18 3.41507 27.2275 3.15883C27.6785 0.77889 29.8021 0.0373324 31.7316 0.0169693H31.8842C32.8718 0.0296962 34.1333 0.300356 34.9022 1.03852C35.9 1.97183 35.8034 3.21568 35.8034 4.57068V7.76769C35.8034 8.72985 36.2027 9.15154 36.5774 9.6691C36.7088 9.85661 36.7376 10.0781 36.5706 10.2155C36.1518 10.5668 35.4075 11.2133 34.9989 11.5781L34.9912 11.5747ZM32.9244 6.57051C32.9244 7.36976 32.9431 8.03665 32.5404 8.74767C32.214 9.32462 31.696 9.68013 31.1212 9.68013C30.3354 9.68013 29.8742 9.08026 29.8742 8.19192C29.8742 6.44324 31.4408 6.12591 32.9244 6.12591V6.57051ZM60.2468 11.6002H58.2037C57.9986 11.5875 57.8358 11.4246 57.8358 11.2226L57.8324 0.685559C57.8502 0.492109 58.0206 0.341083 58.2275 0.341083H60.129C60.3087 0.350416 60.4562 0.472595 60.4935 0.6355V2.24673H60.5325C61.1073 0.805193 61.9101 0.118785 63.3267 0.118785C64.2457 0.118785 65.146 0.451383 65.7191 1.36009C66.2557 2.20261 66.2557 3.6204 66.2557 4.64025V11.2693C66.2337 11.4568 66.065 11.6011 65.8624 11.6011H63.8066C63.6167 11.5892 63.4641 11.4492 63.4412 11.2693V5.55065C63.4412 4.39844 63.5751 2.71254 62.1585 2.71254C61.6609 2.71254 61.2014 3.04514 60.9725 3.55506C60.6843 4.1982 60.6461 4.84134 60.6461 5.55065V11.2226C60.6427 11.4314 60.4655 11.6002 60.2468 11.6002ZM51.6285 2.26879C50.117 2.26879 50.0212 4.32971 50.0212 5.61514C50.0212 6.90056 50.0025 9.64958 51.6107 9.64958C53.1994 9.64958 53.2766 7.43339 53.2766 6.08094C53.2766 5.19515 53.2375 4.13032 52.9697 3.2878C52.7399 2.55642 52.2796 2.26879 51.6285 2.26879ZM51.6107 0.118785C54.6542 0.118785 56.2997 2.73545 56.2997 6.05973C56.2997 9.27287 54.4812 11.8225 51.6107 11.8225C48.6241 11.8225 46.9972 9.20669 46.9972 5.94943C46.9972 2.66757 48.6427 0.118785 51.6107 0.118785ZM13.71 11.6002H11.6601C11.4651 11.5875 11.3083 11.4407 11.2921 11.254L11.2938 0.719498C11.2938 0.509079 11.471 0.341083 11.6897 0.341083H13.5997C13.799 0.351264 13.9592 0.502291 13.9719 0.694892V2.07025H14.0101C14.5077 0.740709 15.4453 0.119633 16.7093 0.119633C17.992 0.119633 18.7957 0.740709 19.3704 2.07025C19.8681 0.740709 20.9973 0.119633 22.2028 0.119633C23.0641 0.119633 24.0026 0.474292 24.5757 1.2727C25.2268 2.15934 25.0937 3.44476 25.0937 4.57492L25.0911 11.2218C25.0911 11.4314 24.9148 11.6002 24.6961 11.6002H22.6479C22.441 11.5875 22.2791 11.4246 22.2791 11.2226V5.63804C22.2791 5.19515 22.3172 4.08705 22.2215 3.66621C22.068 2.95605 21.6094 2.75666 21.0168 2.75666C20.5183 2.75666 20.0012 3.08926 19.7909 3.62125C19.5807 4.15408 19.6002 5.03988 19.6002 5.63889V11.2226C19.6002 11.4322 19.423 11.6011 19.2043 11.6011H17.1561C16.9501 11.5883 16.7873 11.4254 16.7873 11.2235L16.7856 5.63889C16.7856 4.46377 16.9772 2.7363 15.5225 2.7363C14.0482 2.7363 14.1059 4.41965 14.1059 5.63889L14.105 11.2226C14.1059 11.4314 13.9287 11.6002 13.71 11.6002ZM38.2975 2.19922V0.694044C38.2983 0.464958 38.4713 0.312235 38.6781 0.313083L45.4187 0.312235C45.634 0.312235 45.8078 0.469201 45.8078 0.692347V1.98286C45.8053 2.19922 45.623 2.48176 45.3 2.9306L41.8081 7.91956C43.1043 7.88987 44.4751 8.08417 45.6527 8.74597C45.918 8.8953 45.9892 9.11675 46.0104 9.33311V10.9392C46.0104 11.1615 45.7679 11.4169 45.5136 11.2837C43.44 10.196 40.6865 10.0772 38.3924 11.2973C38.1585 11.4212 37.9135 11.1692 37.9135 10.9477V9.42135C37.9135 9.17784 37.9186 8.75954 38.1644 8.38707L42.2091 2.57848H38.6866C38.4713 2.57848 38.2983 2.42491 38.2975 2.19922Z' fill='white'/%3e%3c/g%3e%3cdefs%3e%3cclipPath id='clip0'%3e%3crect width='104.167' height='20' fill='white'/%3e%3c/clipPath%3e%3c/defs%3e%3c/svg%3e";

var useStyles$s = /*#__PURE__*/createUseStyles({
  amazonButton: {
    borderRadius: 10,
    position: 'relative',
    minHeight: 48,
    cursor: 'pointer',
    marginBottom: 18
  },
  amazonButtonBack: {
    width: '100%',
    height: 48,
    borderRadius: 10,
    position: 'absolute',
    top: 0,
    left: 0,
    background: '#11273B',
    zIndex: 1,
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    border: 'none'
  }
});

var AmazonButton = function AmazonButton(props) {
  var _useStyles = useStyles$s(),
      amazonButton = _useStyles.amazonButton,
      amazonButtonBack = _useStyles.amazonButtonBack;

  return React.createElement("div", {
    className: amazonButton
  }, React.createElement(AmazonPaymentButton, Object.assign({}, props)), React.createElement("button", {
    className: amazonButtonBack
  }, React.createElement("img", {
    src: img$m,
    alt: ''
  })));
};

var useStyles$t = /*#__PURE__*/createUseStyles({
  payPal: {
    marginBottom: 12
  }
});

var Content = function Content(_ref) {
  var onSubmit = _ref.onSubmit,
      braintreeAuthorization = _ref.braintreeAuthorization,
      setPayPalLoaded = _ref.setPayPalLoaded;

  var _useStyles = useStyles$t(),
      payPal = _useStyles.payPal;

  useEffect(function () {
    var _window$braintree;

    //@ts-ignore
    (_window$braintree = window.braintree) == null ? void 0 : _window$braintree.client.create({
      authorization: braintreeAuthorization
    }, function (clientErr, clientInstance) {
      var _window$braintree2;

      if (clientErr) {
        console.error('Error creating client:', clientErr);
        return;
      } //@ts-ignore


      (_window$braintree2 = window.braintree) == null ? void 0 : _window$braintree2.paypalCheckout.create({
        client: clientInstance
      }, function (_, paypalCheckoutInstance) {
        paypalCheckoutInstance.loadPayPalSDK({
          currency: 'USD',
          intent: 'capture',
          vault: true
        }, function () {
          var _window$paypal;

          //@ts-ignore
          (_window$paypal = window.paypal) == null ? void 0 : _window$paypal.Buttons({
            style: {
              layout: 'vertical',
              height: 48
            },
            //@ts-ignore
            fundingSource: window.paypal.FUNDING.PAYPAL,
            createBillingAgreement: function createBillingAgreement() {
              return paypalCheckoutInstance.createPayment({
                flow: 'vault',
                enableShippingAddress: true
              });
            },
            onApprove: function onApprove(data) {
              return paypalCheckoutInstance.tokenizePayment(data, function (_, payload) {
                return onSubmit(_extends({
                  type: 'payPal'
                }, payload));
              });
            },
            onCancel: function onCancel(data) {
              //@ts-ignore
              console.log('PayPal payment canceled', JSON.stringify(data, 0, 2));
            },
            onError: function onError(err) {
              console.error('PayPal error', err);
            }
          }).render('#paypal-button').then(function () {
            console.log('paypal ready');
            setPayPalLoaded(true);
          });
        });
      });
    });
  }, []);
  return React.createElement("div", {
    className: payPal,
    id: "paypal-button"
  });
};

var scriptLoader = function scriptLoader(cb) {
  var script = document.createElement('script');
  script.src = 'https://js.braintreegateway.com/web/3.81.0/js/client.min.js';

  script.onload = function () {
    var script = document.createElement('script');
    script.src = 'https://js.braintreegateway.com/web/3.81.0/js/paypal-checkout.min.js';

    script.onload = function () {
      return cb(true);
    };

    document.head.appendChild(script);
  };

  document.head.appendChild(script);
};

var PayPal = function PayPal(props) {
  var _useState = useState(false),
      scriptLoaded = _useState[0],
      setScriptLoaded = _useState[1];

  useLayoutEffect(function () {
    scriptLoader(setScriptLoaded);
  }, []);
  if (!scriptLoaded) return null;
  return React.createElement(Content, Object.assign({}, props));
};

var useStyles$u = /*#__PURE__*/createUseStyles({
  divider: {
    position: 'relative',
    height: 1,
    width: '100%',
    background: '#C7C7C7',
    margin: '19px auto 19px auto',
    '&:after': {
      content: '"OR"',
      position: 'absolute',
      top: '50%',
      left: '50%',
      transform: 'translate(-50%, -50%)',
      padding: '0 10px',
      background: 'white',
      fontSize: 14
    }
  }
});

var Divider = function Divider() {
  var _useStyles = useStyles$u(),
      divider = _useStyles.divider;

  return React.createElement("div", {
    className: divider
  });
};

var img$n = "data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' style='margin: auto%3b display: block%3b' width='118px' height='118px' viewBox='0 0 100 100' preserveAspectRatio='xMidYMid'%3e %3ccircle cx='92' cy='50' fill='%23C7C7C7' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.9090909090909091s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23C7C7C7%3b%23C7C7C7%3bwhite%3b%23C7C7C7%3b%23C7C7C7' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.9090909090909091s'%3e%3c/animate%3e %3c/circle%3e%3ccircle cx='85.33264837890961' cy='72.7069143331351' fill='%23C7C7C7' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.8181818181818182s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23C7C7C7%3b%23C7C7C7%3bwhite%3b%23C7C7C7%3b%23C7C7C7' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.8181818181818182s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='67.44743054607923' cy='88.20454380488977' fill='%23C7C7C7' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.7272727272727273s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23C7C7C7%3b%23C7C7C7%3bwhite%3b%23C7C7C7%3b%23C7C7C7' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.7272727272727273s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='44.02277679252203' cy='91.57250055899918' fill='%23C7C7C7' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.6363636363636364s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23C7C7C7%3b%23C7C7C7%3bwhite%3b%23C7C7C7%3b%23C7C7C7' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.6363636363636364s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='22.49584917429803' cy='81.74148212287885' fill='%23C7C7C7' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.5454545454545454s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23C7C7C7%3b%23C7C7C7%3bwhite%3b%23C7C7C7%3b%23C7C7C7' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.5454545454545454s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='9.701295108191111' cy='61.83276738734005' fill='%23C7C7C7' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.45454545454545453s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23C7C7C7%3b%23C7C7C7%3bwhite%3b%23C7C7C7%3b%23C7C7C7' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.45454545454545453s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='9.701295108191104' cy='38.167232612659966' fill='%23C7C7C7' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.36363636363636365s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23C7C7C7%3b%23C7C7C7%3bwhite%3b%23C7C7C7%3b%23C7C7C7' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.36363636363636365s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='22.495849174298023' cy='18.258517877121157' fill='%23C7C7C7' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.2727272727272727s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23C7C7C7%3b%23C7C7C7%3bwhite%3b%23C7C7C7%3b%23C7C7C7' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.2727272727272727s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='44.02277679252202' cy='8.427499441000826' fill='%23C7C7C7' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.18181818181818182s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23C7C7C7%3b%23C7C7C7%3bwhite%3b%23C7C7C7%3b%23C7C7C7' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.18181818181818182s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='67.44743054607922' cy='11.79545619511022' fill='%23C7C7C7' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.09090909090909091s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23C7C7C7%3b%23C7C7C7%3bwhite%3b%23C7C7C7%3b%23C7C7C7' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.09090909090909091s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='85.33264837890961' cy='27.293085666864908' fill='%23C7C7C7' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='0s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23C7C7C7%3b%23C7C7C7%3bwhite%3b%23C7C7C7%3b%23C7C7C7' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='0s'%3e%3c/animate%3e%3c/circle%3e%3c/svg%3e";

var useStyles$v = /*#__PURE__*/createUseStyles({
  loaderWrapper: {
    height: 150,
    margin: 0,
    marginBottom: 18,
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center'
  },
  loader: {
    width: 50,
    height: 50
  }
});

var LoaderBox = function LoaderBox() {
  var _useStyles = useStyles$v(),
      loader = _useStyles.loader,
      loaderWrapper = _useStyles.loaderWrapper;

  return React.createElement("div", {
    className: loaderWrapper
  }, React.createElement("img", {
    className: loader,
    src: img$n,
    alt: "loader"
  }));
};

var img$o = "data:image/svg+xml,%3csvg width='22' height='17' viewBox='0 0 22 17' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3crect y='0.637451' width='22' height='16' rx='2' fill='white'/%3e%3crect y='3.30408' width='22' height='2.66667' fill='%239FB8FF'/%3e%3crect x='2.5' y='8' width='17' height='2' rx='1' fill='%23CEDBFF'/%3e%3c/svg%3e";

var useStyles$w = /*#__PURE__*/createUseStyles({
  wrapper: {
    display: 'none'
  },
  active: {
    display: 'block'
  },
  button: /*#__PURE__*/_extends({
    width: '100%',
    height: 48,
    borderRadius: 10,
    background: '#066FDE'
  }, alignment.center, {
    '&:hover': {
      background: '#066FDE'
    },
    '& p': {
      fontSize: 14,
      lineHeight: '18px'
    }
  }),
  buttonContent: {
    display: 'flex',
    alignItems: 'center'
  },
  cardIcon: {
    marginRight: 8
  },
  hiddenWindow: {
    display: 'none'
  },
  errorBlock: {
    marginBottom: 14
  }
});

var Paywall = function Paywall(_ref) {
  var onAmazonButtonClicked = _ref.onAmazonButtonClicked,
      accessPaymentsKeys = _ref.accessPaymentsKeys,
      countryCode = _ref.countryCode,
      onSubmit = _ref.onSubmit,
      stripeProp = _ref.stripeProp,
      isApplePayActive = _ref.isApplePayActive,
      isGooglePayActive = _ref.isGooglePayActive,
      isPaypalActive = _ref.isPaypalActive,
      isAmazonActive = _ref.isAmazonActive,
      env = _ref.env,
      formText = _ref.formText,
      _ref$onComponentReady = _ref.onComponentReady,
      onComponentReady = _ref$onComponentReady === void 0 ? function () {} : _ref$onComponentReady,
      cardError = _ref.cardError,
      error = _ref.error,
      loading = _ref.loading,
      _ref$forceReadyCompon = _ref.forceReadyComponentTime,
      forceReadyComponentTime = _ref$forceReadyCompon === void 0 ? 4000 : _ref$forceReadyCompon,
      _ref$isUpdateForm = _ref.isUpdateForm,
      isUpdateForm = _ref$isUpdateForm === void 0 ? false : _ref$isUpdateForm,
      _ref$isModalCheckoutO = _ref.isModalCheckoutOpened,
      isModalCheckoutOpened = _ref$isModalCheckoutO === void 0 ? false : _ref$isModalCheckoutO,
      _ref$modalCheckoutWin = _ref.modalCheckoutWindowTriggered,
      modalCheckoutWindowTriggered = _ref$modalCheckoutWin === void 0 ? function () {} : _ref$modalCheckoutWin,
      _ref$buttonWrapperCla = _ref.buttonWrapperClass,
      buttonWrapperClass = _ref$buttonWrapperCla === void 0 ? '' : _ref$buttonWrapperCla,
      _ref$errorBlockClass = _ref.errorBlockClass,
      errorBlockClass = _ref$errorBlockClass === void 0 ? '' : _ref$errorBlockClass;

  var _useStyles = useStyles$w(),
      button = _useStyles.button,
      buttonContent = _useStyles.buttonContent,
      cardIcon = _useStyles.cardIcon,
      hiddenWindow = _useStyles.hiddenWindow,
      wrapper = _useStyles.wrapper,
      active = _useStyles.active,
      errorBlock = _useStyles.errorBlock;

  var _useState = useState(false),
      open = _useState[0],
      setOpen = _useState[1];

  var _useState2 = useState(null),
      paymentRequest = _useState2[0],
      setPaymentRequest = _useState2[1];

  var _useState3 = useState(null),
      stripeResult = _useState3[0],
      setStripeResult = _useState3[1];

  var _useState4 = useState(!isGooglePayActive),
      gPayLoaded = _useState4[0],
      setGpayLoaded = _useState4[1];

  var _useState5 = useState(!isApplePayActive),
      aPayLoaded = _useState5[0],
      setApayLoaded = _useState5[1];

  var _useState6 = useState(!isPaypalActive),
      pPalLoaded = _useState6[0],
      setPayPalLoaded = _useState6[1];

  var toggleModal = function toggleModal() {
    setOpen(!open);
    modalCheckoutWindowTriggered(!open);
  };

  var checkoutPayKey = accessPaymentsKeys.checkoutPayKey,
      stripePromise = accessPaymentsKeys.stripePromise,
      braintreeAuthorization = accessPaymentsKeys.braintreeAuthorization,
      amazonClientId = accessPaymentsKeys.amazonClientId,
      amazonSellerId = accessPaymentsKeys.amazonSellerId;
  var isAppleGooglePayShowed = isApplePayActive || isGooglePayActive;
  var isPaymentRequestShowed = !!(stripeResult != null && stripeResult.googlePay && paymentRequest) || !!(stripeResult != null && stripeResult.applePay && paymentRequest);
  var isDividerShowed = isAppleGooglePayShowed && isPaymentRequestShowed || isPaypalActive || isAmazonActive;
  useEffect(function () {
    var isComponentReady = gPayLoaded && aPayLoaded && pPalLoaded;

    if (isComponentReady && onComponentReady) {
      onComponentReady();
    }
  }, [gPayLoaded, aPayLoaded, pPalLoaded]);
  useEffect(function () {
    setTimeout(function () {
      setApayLoaded(true);
      setGpayLoaded(true);
      setPayPalLoaded(true);
    }, forceReadyComponentTime);
  }, []);
  useEffect(function () {
    return setOpen(isModalCheckoutOpened);
  }, [isModalCheckoutOpened]);
  var isComponentReady = gPayLoaded && aPayLoaded && pPalLoaded;
  var wrapperClass = wrapper + " " + (isComponentReady ? active : '') + " " + buttonWrapperClass;
  if (loading) return React.createElement(LoaderBox, null);
  return React.createElement(React.Fragment, null, !isComponentReady && React.createElement(LoaderBox, null), error && isComponentReady && React.createElement(InfoBlock, {
    className: errorBlock + " " + errorBlockClass,
    text: error,
    variant: "error"
  }), React.createElement("div", {
    className: wrapperClass
  }, isAppleGooglePayShowed && stripePromise && React.createElement(Elements, {
    stripe: stripePromise
  }, React.createElement(AppleGooglePay, Object.assign({
    setGpayLoaded: setGpayLoaded,
    setApayLoaded: setApayLoaded,
    paymentRequest: paymentRequest,
    onSubmit: onSubmit,
    setPaymentRequest: setPaymentRequest,
    setStripeResult: setStripeResult,
    isPaymentRequestShowed: isPaymentRequestShowed
  }, stripeProp))), isPaypalActive && React.createElement(PayPal, {
    setPayPalLoaded: setPayPalLoaded,
    braintreeAuthorization: braintreeAuthorization,
    onSubmit: onSubmit
  }), isAmazonActive && React.createElement(AmazonButton, {
    onAuth: onAmazonButtonClicked,
    clientId: amazonClientId,
    sellerId: amazonSellerId,
    env: env
  }), isDividerShowed && React.createElement(Divider, null), React.createElement(PrimaryButton, {
    onClick: toggleModal,
    className: button,
    //@ts-ignore
    label: React.createElement("div", {
      className: buttonContent
    }, React.createElement("img", {
      className: cardIcon,
      src: img$o,
      alt: ""
    }), "Credit / Debit Card")
  }), React.createElement(ModalWindow, {
    open: open && isComponentReady,
    rootClassName: !open || !isComponentReady ? hiddenWindow : ''
  }, React.createElement(CheckoutForm, {
    isUpdateForm: isUpdateForm,
    error: cardError,
    formText: formText,
    handleClose: toggleModal,
    onSubmit: onSubmit,
    countryCode: countryCode,
    publicKey: checkoutPayKey
  }))));
};

var AMAZON_ADDRESS_BOOK_DIV_ID = 'addressBookWidgetDiv';
var AddressBook = function AddressBook(props) {
  var sellerId = props.sellerId,
      agreementType = props.agreementType,
      onAddressSelect = props.onAddressSelect,
      onReady = props.onReady,
      onError = props.onError,
      setOro = props.setOro;
  useEffect(function () {
    // @ts-ignore
    new window.OffAmazonPayments.Widgets.AddressBook({
      onReady: onReady,
      onAddressSelect: onAddressSelect,
      onError: onError,
      sellerId: sellerId,
      agreementType: agreementType,
      onOrderReferenceCreate: function onOrderReferenceCreate(orderReference) {
        setOro(orderReference.getAmazonOrderReferenceId());
      },
      design: {
        designMode: 'responsive'
      }
    }).bind(AMAZON_ADDRESS_BOOK_DIV_ID);
  }, []);
  return React.createElement("div", {
    style: {
      height: 228,
      display: 'none'
    },
    id: AMAZON_ADDRESS_BOOK_DIV_ID
  });
};

var AMAZON_WALLET_WIDGET_DIV_ID = 'walletWidgetDiv';
var WalletWidget = function WalletWidget(props) {
  var onReady = props.onReady,
      onError = props.onError,
      onPaymentSelect = props.onPaymentSelect,
      sellerId = props.sellerId,
      agreementType = props.agreementType,
      oro = props.oro,
      error = props.error;
  useEffect(function () {
    //@ts-ignore
    new window.OffAmazonPayments.Widgets.Wallet({
      sellerId: sellerId,
      design: {
        designMode: 'responsive'
      },
      onReady: onReady,
      agreementType: agreementType,
      onPaymentSelect: onPaymentSelect,
      amazonOrderReferenceId: oro,
      onError: onError
    }).bind(AMAZON_WALLET_WIDGET_DIV_ID);
  }, [oro]);
  return React.createElement("div", {
    style: {
      height: 228,
      display: error ? 'block' : 'none',
      marginBottom: 16
    },
    id: AMAZON_WALLET_WIDGET_DIV_ID
  });
};

var AMAZON_CONSENT_WIDGET_DIV_ID = 'consentWidgetDiv';
var toBoolean = function toBoolean(value) {
  if (typeof value === 'string') {
    if (value === 'true') {
      return true;
    }

    if (value === 'false') {
      return false;
    }
  }

  return !!value;
};
var ConsentWidget = function ConsentWidget(_ref) {
  var sellerId = _ref.sellerId,
      onConsent = _ref.onConsent,
      onError = _ref.onError,
      amazonBillingAgreementId = _ref.amazonBillingAgreementId;

  var handleConsent = function handleConsent(consent) {
    onConsent(toBoolean(consent.getConsentStatus()));
  };

  useEffect(function () {
    //@ts-ignore
    new window.OffAmazonPayments.Widgets.Consent({
      sellerId: sellerId,
      amazonBillingAgreementId: amazonBillingAgreementId,
      design: {
        designMode: 'responsive'
      },
      onConsent: handleConsent,
      onError: onError
    }).bind(AMAZON_CONSENT_WIDGET_DIV_ID);
  }, []);
  return React.createElement("div", {
    id: AMAZON_CONSENT_WIDGET_DIV_ID,
    style: {
      height: 152,
      marginTop: 12,
      marginBottom: 18
    }
  });
};

var useStyles$x = /*#__PURE__*/createUseStyles({
  button: /*#__PURE__*/_extends({
    width: '100%',
    height: 48,
    borderRadius: 10,
    background: '#066FDE'
  }, alignment.center, {
    '&:hover': {
      background: '#066FDE'
    },
    '& p': {
      fontSize: 14,
      lineHeight: '18px'
    }
  }),
  buttonContent: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    '& img': {
      marginRight: 8,
      marginBottom: 3
    }
  },
  checkboxLabel: {
    padding: '7px 16px 6px 17px',
    color: '#695743',
    fontSize: 14,
    lineHeight: '18px',
    background: '#FDF7E6',
    border: '1px solid #F6CA65',
    borderRadius: 8,
    marginBottom: 18
  }
});

var AmazonPayment = function AmazonPayment(_ref) {
  var sellerId = _ref.sellerId,
      onSubmit = _ref.onSubmit,
      _ref$isUpdateForm = _ref.isUpdateForm,
      isUpdateForm = _ref$isUpdateForm === void 0 ? false : _ref$isUpdateForm;

  var _useStyles = useStyles$x(),
      button = _useStyles.button,
      buttonContent = _useStyles.buttonContent,
      checkboxLabel = _useStyles.checkboxLabel;

  var _useState = useState(''),
      oro = _useState[0],
      setOro = _useState[1];

  var _useState2 = useState(false),
      additionalDisable = _useState2[0],
      setAdditionalDisable = _useState2[1];

  var _useState3 = useState(false),
      loading = _useState3[0],
      setLoading = _useState3[1];

  var _useState4 = useState(false),
      consent = _useState4[0],
      setConsent = _useState4[1];

  var _useState5 = useState(''),
      billingId = _useState5[0],
      setBillingId = _useState5[1];

  var handleWalletReady = function handleWalletReady(agreement) {
    setBillingId(agreement.getAmazonBillingAgreementId());
  };

  var onConsent = function onConsent(consent) {
    setConsent(consent);
    setAdditionalDisable(false);
  };

  var handleSubmit = function handleSubmit() {
    if (!consent || additionalDisable) return;
    setLoading(true);
    onSubmit({
      billingId: billingId,
      type: 'amazonPay'
    }).then(function (_temp) {
      var _ref2 = _temp === void 0 ? {} : _temp,
          error = _ref2.error;

      if (error) {
        var isError = error.indexOf('InvalidPaymentMethod') > -1 || error.indexOf('TransactionTimedOut') > -1 || error.indexOf('AmazonRejected') > -1 || error.indexOf('ProcessingFailure') > -1;

        if (isError) {
          setAdditionalDisable(true);
        }
      }

      setLoading(false);
    });
  };

  var disabledBtn = !consent && additionalDisable || loading;
  return React.createElement("div", null, !consent && React.createElement("div", {
    className: checkboxLabel
  }, "Click on the checkbox below to continue."), !billingId && React.createElement(LoaderBox, null), React.createElement(AddressBook, {
    sellerId: sellerId,
    setOro: setOro,
    agreementType: "BillingAgreement"
  }), oro && !loading && React.createElement(WalletWidget, {
    oro: oro,
    sellerId: sellerId,
    agreementType: "BillingAgreement",
    onReady: handleWalletReady,
    onPaymentSelect: function onPaymentSelect() {
      return setAdditionalDisable(false);
    }
  }), billingId && React.createElement(ConsentWidget, {
    sellerId: sellerId,
    amazonBillingAgreementId: billingId,
    onConsent: onConsent
  }), React.createElement(PrimaryButton, {
    disabled: disabledBtn,
    loading: loading,
    onClick: handleSubmit,
    className: button,
    //@ts-ignore
    label: React.createElement("div", {
      className: buttonContent
    }, React.createElement("img", {
      src: disabledBtn ? img$i : img$h,
      alt: ""
    }), isUpdateForm ? 'Update' : 'Start 7-Day trial')
  }));
};

var generateUniqueID = function generateUniqueID(length) {
  if (length === void 0) {
    length = 32;
  }

  var chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_';
  var result = [];
  var charlen = chars.length;

  for (var i = 0; i < length; i++) {
    result[i] = chars.charAt(Math.floor(Math.random() * charlen));
  }

  return result.join('');
};

var useLoadKountSessionScript = function useLoadKountSessionScript() {
  useEffect(function () {
    var uniqueId = generateUniqueID();
    localStorageService.setItem('kount_session_id', uniqueId);
    var kountScript = document.createElement('script');
    kountScript.src = "https://tst.kaptcha.com/collect/sdk?m=100261&s=" + uniqueId;
    kountScript.async = false;
    document.body.appendChild(kountScript);
  }, []);
};

export { AM_TIME, AmazonPayment, AnimationWrapper, CheckButton, CheckButtonPrimary, DateOfBirth, DestinationService, Header, InfoBlock, Input, ModalWindow, PM_TIME, Paywall, PreloadImg, PriceBlock, PriceBlockHint, PrimaryButton, ProgressBar, ProgressBarThin, ProgressStepper, Select, SelectButton, SimpleButton, SliderPage, Tab, TextNormalizer, ThemeProvider, TimeOfBirth, Typography, TypographyVariants, ValidatedInput, localStorageService, storageListener, useAccessPageChecking, useCurrencyPricing, useLoadKountSessionScript, useLocalStorage, useMultiClickProtector, versionWatcher };
//# sourceMappingURL=ruby-web-common.esm.js.map
